/*****************************************************************************
 *  Rohde&Schwarz EMI Test Receiver Tester instrument driver
 *  WLAN Signaling
 *  VXIpnp Instrument Driver
 *****************************************************************************/

#ifndef __RSEMI_HEADER
#define __RSEMI_HEADER

#include "rsidr_core.h"
#include "rsemi_attributes.h"
#include "rsemi_utility.h"

#include <float.h>
#include <math.h> 

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define RSEMI_CLASS_DRIVER_DESCRIPTION           ""
#define RSEMI_CLASS_DRIVER_PREFIX                ""
#define RSEMI_CLASS_DRIVER_VENDOR                ""
#define RSEMI_CLASS_DRIVER_REVISION              ""
#define RSEMI_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSEMI_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSEMI_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSEMI_SPECIFIC_DRIVER_PREFIX             "RSEMI"
#define RSEMI_SPECIFIC_DRIVER_LOCATOR            ""
#define RSEMI_SPECIFIC_DRIVER_VENDOR             ""
#define RSEMI_MAJOR_VERSION                      2L    /* Instrument driver major version          */
#define RSEMI_MINOR_VERSION                      28L   /* Instrument driver minor version          */
#define RSEMI_MINOR_MINOR_VERSION                0L    /* Instrument driver minor minor version    */

/* Driver Capabilities */          

#define RSEMI_SUPPORTED_INSTRUMENT_MODELS        ""    /* Instrument driver supported model(s)     */
#define RSEMI_GROUP_CAPABILITIES                 ""
#define RSEMI_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *------------------------------ Useful Macros -----------------------------*
 ****************************************************************************/

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/

#define RSEMI_SIMULATION_ID_QUERY      "Rohde&Schwarz,EMI,123456/789,1.0"  /* Default definition of ID Query Response for simulation */
#define RSEMI_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSEMI_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSEMI_IO_BUFFER_SIZE           1024L   /* I/O buffer size */
#define RSEMI_OPC_TIMEOUT              5000L   /* Maximum time to wait for OPC in milliseconds */
/*
bit - meaning
-------------
0 - Unused
1 - Unused
_2_ - Error queue not empty
3 - Questionable status sum
_4_ - Message available
_5_ - ESB (see ESE mask)
6 - Master status summary
7 - Operation status sum
*/
#define IEEE_488_2_SRE_MASK             0x24   /* 488.2 Event Status Register (STB) Bits */
#define IEEE_488_2_ERROR_MASK           0x4    /* 488.2 Error queue not empty bit mask */
/*
bit - meaning
-------------
_0_ - Operation Complete
1 - Unused
_2_ - Query Error
_3_ - Device-dependent Error
_4_ - Execution Error
_5_ - Command Error
6 - User Request
7 - Power On
*/
#define IEEE_488_2_ESE_MASK               0x3D    /* 488.2 Event Status Register (ESE) Bits */

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSEMI_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSEMI_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSEMI_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSEMI_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSEMI_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSEMI_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSEMI_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSEMI_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSEMI_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSEMI_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSEMI_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSEMI_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSEMI_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSEMI_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSEMI_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */   
#define RSEMI_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSEMI_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSEMI_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSEMI_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSEMI_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSEMI_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSEMI_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSEMI_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSEMI_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSEMI_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSEMI_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSEMI_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSEMI_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSEMI_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSEMI_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSEMI_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

    /*- Instrument-Specific Attributes ----------*/
//#define RSEMI_ATTR_ID_QUERY_RESPONSE                                     (RS_SPECIFIC_PUBLIC_ATTR_BASE + 1L)                     /* ViString (Read Only)              */

/* BEGIN GENERATE */
#define RSEMI_ATTR_SAN_NUM_OF_SWEEPS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 268
#define RSEMI_ATTR_SAN_SWEEP_MODE_CONTINUOUS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 275
#define RSEMI_ATTR_VERTICAL_SCALE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 282
#define RSEMI_ATTR_SAN_NUMBER_OF_SWEEPS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1608
#define RSEMI_ATTR_SAN_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 294
#define RSEMI_ATTR_GET_INSTR_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 295
#define RSEMI_ATTR_AVG_STATE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 313
#define RSEMI_ATTR_AVG_TYPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 314
#define RSEMI_ATTR_AVG_COUNT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 315
#define RSEMI_ATTR_PRESET_MEASUREMENT_CHANNEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1050
#define RSEMI_ATTR_SELECT_MEASUREMENT_CHANNEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1051
#define RSEMI_ATTR_DUPLICATE_MEASUREMENT_CHANNEL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1052
#define RSEMI_ATTR_DELETE_MEASUREMENT_CHANNEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1056
#define RSEMI_ATTR_CALIBRATION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 349
#define RSEMI_ATTR_CALIBRATION_ABORT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350
#define RSEMI_ATTR_CALIBRATION_RESULT_QUERY                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351
#define RSEMI_ATTR_CALIBRATION_STATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352
#define RSEMI_ATTR_AUTO_ADJUST_ALL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 372
#define RSEMI_ATTR_AUTO_ADJUST_FREQ                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 373
#define RSEMI_ATTR_AUTO_ADJUST_LEVEL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 374
#define RSEMI_ATTR_AUTO_ADJUST_LEVEL_MEAS_TIME                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 375
#define RSEMI_ATTR_AUTO_ADJUST_LEVEL_MEAS_TIME_MODE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 376
#define RSEMI_ATTR_AUTO_ADJUST_LEVEL_MEAS_TIME_FSWT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1322
#define RSEMI_ATTR_AUTO_ADJUST_LEVEL_MEAS_TIME_MODE_FSWT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1323
#define RSEMI_ATTR_AUTO_ADJUST_HYSTERSIS_LOWER                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1058
#define RSEMI_ATTR_AUTO_ADJUST_HYSTERSIS_UPPER                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1059
#define RSEMI_ATTR_AUTO_ADJUST_TRIGGER_STATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 378
#define RSEMI_ATTR_AUTO_ADJUST_HYSTERSIS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 377
#define RSEMI_ATTR_SPECTRUM_DISPLAY_CREATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 381
#define RSEMI_ATTR_SPECTRUM_DISPLAY_SELECT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 382
#define RSEMI_ATTR_SPECTRUM_DISPLAY_DELETE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 383
#define RSEMI_ATTR_NOISE_SOURCE_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 293
#define RSEMI_ATTR_IF_OUTPUT_SOURCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 291
#define RSEMI_ATTR_SIGNAL_OUTPUT_LINK                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1324
#define RSEMI_ATTR_IF_OUTPUT_FREQUENCY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1063
#define RSEMI_ATTR_IF_OUTPUT_SIDEBAND                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1064
#define RSEMI_ATTR_SIGNAL_OUTPUT_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1325
#define RSEMI_ATTR_SIGNAL_OUTPUT_GAIN_MODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1326
#define RSEMI_ATTR_SIGNAL_OUTPUT_GAIN_VALUE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1327
#define RSEMI_ATTR_SIGNAL_OUTPUT_COUPLING                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1328
#define RSEMI_ATTR_SIGNAL_OUTPUT_SCALE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1329
#define RSEMI_ATTR_SIGNAL_OUTPUT_AC_CUTOFF_FREQUENCY                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1330
#define RSEMI_ATTR_SIGNAL_OUTPUT_LOW_PASS_FILTER_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1331
#define RSEMI_ATTR_SIGNAL_OUTPUT_LOW_PASS_FILTER_FREQUENCY                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1332
#define RSEMI_ATTR_SIGNAL_OUTPUT_PHONES_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1333
#define RSEMI_ATTR_SIGNAL_OUTPUT_PROBE_POWER_ENABLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1335
#define RSEMI_ATTR_SIGNAL_OUTPUT_TRIGGER_DIRECTION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1336
#define RSEMI_ATTR_SIGNAL_OUTPUT_TRIGGER_LEVEL                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1337
#define RSEMI_ATTR_SIGNAL_OUTPUT_TRIGGER_TYPE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1338
#define RSEMI_ATTR_SIGNAL_OUTPUT_TRIGGER_PULSE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1339
#define RSEMI_ATTR_SIGNAL_OUTPUT_TRIGGER_PULSE_LENGTH                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1340
#define RSEMI_ATTR_SAN_FREQUENCY_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 266
#define RSEMI_ATTR_FREQUENCY_OFFSET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 258
#define RSEMI_ATTR_FREQUENCY_START                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 256
#define RSEMI_ATTR_FREQUENCY_START_MIN_MAX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1628
#define RSEMI_ATTR_FREQUENCY_START_GET_MIN                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1629
#define RSEMI_ATTR_FREQUENCY_START_GET_MAX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1630
#define RSEMI_ATTR_FREQUENCY_STOP                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 257
#define RSEMI_ATTR_FREQUENCY_STOP_MIN_MAX                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1631
#define RSEMI_ATTR_FREQUENCY_STOP_GET_MIN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1632
#define RSEMI_ATTR_FREQUENCY_STOP_GET_MAX                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1633
#define RSEMI_ATTR_FREQUENCY_CENTER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 259
#define RSEMI_ATTR_CENTER_FREQUENCY_STEP                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 260
#define RSEMI_ATTR_FREQUENCY_STEP_AUTO                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 261
#define RSEMI_ATTR_FREQUENCY_CENTER_LINK                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 262
#define RSEMI_ATTR_FREQUENCY_CENTER_LINK_FACTOR                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 263
#define RSEMI_ATTR_FREQUENCY_SPAN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 264
#define RSEMI_ATTR_FREQUENCY_SPAN_FULL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 265
#define RSEMI_ATTR_HORIZONTAL_SCALE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 290
#define RSEMI_ATTR_SAN_MARKER_AMPLITUDE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 384
#define RSEMI_ATTR_SAN_MARKER_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 385
#define RSEMI_ATTR_SAN_MARKER_POSITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 386
#define RSEMI_ATTR_ASSIGN_MARKER_TRACE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 387
#define RSEMI_ATTR_SAN_MARKER_AOFF                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 389
#define RSEMI_ATTR_MARKER_LOEX                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 390
#define RSEMI_ATTR_MARKER_STEP_SIZE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 395
#define RSEMI_ATTR_MARKER_PROBABILITY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 396
#define RSEMI_ATTR_SIGNAL_TRACK_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 391
#define RSEMI_ATTR_SIGNAL_TRACK_BWID                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 392
#define RSEMI_ATTR_SIGNAL_TRACK_BWID_MIN_MAX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1622
#define RSEMI_ATTR_SIGNAL_TRACK_BWID_GET_MIN                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1623
#define RSEMI_ATTR_SIGNAL_TRACK_BWID_GET_MAX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1624
#define RSEMI_ATTR_SIGNAL_TRACK_THRESHOLD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 393
#define RSEMI_ATTR_SIGNAL_TRACK_TRACE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 394
#define RSEMI_ATTR_SAN_MARKER_SEARCH_MIN_RIGHT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 397
#define RSEMI_ATTR_SAN_MARKER_SEARCH_MIN_LEFT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 398
#define RSEMI_ATTR_SAN_MARKER_SEARCH_PEAK                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 399
#define RSEMI_ATTR_SAN_MARKER_SEARCH_PEAK_NEXT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 400
#define RSEMI_ATTR_SAN_MARKER_SEARCH_PEAK_RIGHT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 401
#define RSEMI_ATTR_SAN_MARKER_SEARCH_PEAK_LEFT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 402
#define RSEMI_ATTR_SAN_MARKER_SEARCH_MIN                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 403
#define RSEMI_ATTR_SAN_MARKER_SEARCH_MIN_NEXT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 404
#define RSEMI_ATTR_MARKER_SEARCH_PEAK_AUTO                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 405
#define RSEMI_ATTR_MARKER_SEARCH_MIN_AUTO                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 406
#define RSEMI_ATTR_MARKER_THRESHOLD_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 407
#define RSEMI_ATTR_MARKER_THRESHOLD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 408
#define RSEMI_ATTR_PEAK_EXCURSION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 409
#define RSEMI_ATTR_SAN_MARKER_SEARCH_LIMITS_STATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 410
#define RSEMI_ATTR_SAN_MARKER_SEARCH_LIMITS_LEFT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 411
#define RSEMI_ATTR_SAN_MARKER_SEARCH_LIMITS_RIGHT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 412
#define RSEMI_ATTR_MARKER_SEARCH_LIMITS_ZOOM                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 413
#define RSEMI_ATTR_MARKER_FREQUENCY_COUNTER_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 712
#define RSEMI_ATTR_MARKER_FREQUENCY_COUNTER_RESOLUTION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 713
#define RSEMI_ATTR_MARKER_COUNT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 714
#define RSEMI_ATTR_MARKER_NOISE_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 707
#define RSEMI_ATTR_MARKER_NOISE_RESULT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 708
#define RSEMI_ATTR_MARKER_DEMOD_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 420
#define RSEMI_ATTR_MARKER_DEMOD_TYPE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 421
#define RSEMI_ATTR_MARKER_DEMOD_HOLDOFF                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 422
#define RSEMI_ATTR_MARKER_DEMOD_CONT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 423
#define RSEMI_ATTR_MARKER_PEAK_LIST_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 442
#define RSEMI_ATTR_MARKER_STORE_PEAK_LIST                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 440
#define RSEMI_ATTR_MARKER_PEAK_LIST_ANNOTATION_STATE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 428
#define RSEMI_ATTR_MARKER_PEAK_LIST_ANNOTATION_LABEL                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 426
#define RSEMI_ATTR_MARKER_PEAK_LIST_COUNT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 414
#define RSEMI_ATTR_MARKER_PEAK_LIST_FOUND                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 415
#define RSEMI_ATTR_MARKER_PEAK_LIST_SORT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 416
#define RSEMI_ATTR_MARKER_PEAK_LIST_SIZE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 417
#define RSEMI_ATTR_MARKER_PEAK_LIST_AUTO                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 418
#define RSEMI_ATTR_MARKER_PEAK_LIST_PEAK_LABELS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 443
#define RSEMI_ATTR_MARKER_PEAK_LIST_MAXIMUM_PEAKS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 444
#define RSEMI_ATTR_MARKER_REF_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 435
#define RSEMI_ATTR_MARKER_REF_LEVEL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 436
#define RSEMI_ATTR_MARKER_REF_LEVEL_OFFSET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 437
#define RSEMI_ATTR_MARKER_REF_FREQ                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 438
#define RSEMI_ATTR_MARKER_REF_PEAK                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 439
#define RSEMI_ATTR_SAN_MARKER_ZOOM                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 419
#define RSEMI_ATTR_SAN_MARKER_TO_CENTER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 429
#define RSEMI_ATTR_SAN_MARKER_TO_STEP                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 430
#define RSEMI_ATTR_MARKER_TO_REFERENCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 431
#define RSEMI_ATTR_SAN_MARKER_LINK                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 432
#define RSEMI_ATTR_MARKER_LINK_ALL_MARKERS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 434
#define RSEMI_ATTR_MARKER_LINK_TO_MARKER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1069
#define RSEMI_ATTR_MARKER_BAND_POWER_STATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 445
#define RSEMI_ATTR_MARKER_BAND_POWER_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 446
#define RSEMI_ATTR_MARKER_BAND_POWER_SPAN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 447
#define RSEMI_ATTR_QUERY_MARKER_BAND_POWER_RESULT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 448
#define RSEMI_ATTR_DELTA_MARKER_BAND_POWER_STATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 449
#define RSEMI_ATTR_DELTA_MARKER_BAND_POWER_MODE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 450
#define RSEMI_ATTR_DELTA_MARKER_BAND_POWER_SPAN                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 451
#define RSEMI_ATTR_QUERY_DELTA_MARKER_BAND_POWER_RESULT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 452
#define RSEMI_ATTR_REF_MARKER_PEAK                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1249
#define RSEMI_ATTR_REF_MARKER_PEAK_NEXT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1250
#define RSEMI_ATTR_REF_MARKER_PEAK_NEXT_RIGHT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1251
#define RSEMI_ATTR_REF_MARKER_PEAK_NEXT_LEFT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1252
#define RSEMI_ATTR_REF_MARKER_MIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1253
#define RSEMI_ATTR_REF_MARKER_MIN_NEXT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1254
#define RSEMI_ATTR_REF_MARKER_MIN_NEXT_RIGHT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1255
#define RSEMI_ATTR_REF_MARKER_MIN_NEXT_LEFT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1256
#define RSEMI_ATTR_REFERENCE_MARKER_PEAK                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 462
#define RSEMI_ATTR_REFERENCE_MARKER_PEAK_NEXT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 463
#define RSEMI_ATTR_REFERENCE_MARKER_PEAK_NEXT_RIGHT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 464
#define RSEMI_ATTR_REFERENCE_MARKER_PEAK_NEXT_LEFT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 465
#define RSEMI_ATTR_REFERENCE_MARKER_MIN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 466
#define RSEMI_ATTR_REFERENCE_MARKER_MIN_NEXT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 467
#define RSEMI_ATTR_REFERENCE_MARKER_MIN_NEXT_RIGHT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 468
#define RSEMI_ATTR_REFERENCE_MARKER_MIN_NEXT_LEFT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 469
#define RSEMI_ATTR_REF_MARKER_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1258
#define RSEMI_ATTR_REF_MARKER_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1259
#define RSEMI_ATTR_REF_MARKER_POSITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1260
#define RSEMI_ATTR_REF_MARKER_REL_POSITION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1261
#define RSEMI_ATTR_REF_MARKER_AMPLITUDE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1262
#define RSEMI_ATTR_REF_MARKER_TRACE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1263
#define RSEMI_ATTR_DMARKER_REFERENCE_MARKER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1264
#define RSEMI_ATTR_REF_MARKER_AOFF                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1265
#define RSEMI_ATTR_DELTA_MARKER_LINK_TO_MARKER                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1342
#define RSEMI_ATTR_REFERENCE_MARKER_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 453
#define RSEMI_ATTR_REFERENCE_MARKER_MODE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 454
#define RSEMI_ATTR_REFERENCE_MARKER_POSITION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 455
#define RSEMI_ATTR_REFERENCE_MARKER_REL_POSITION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 456
#define RSEMI_ATTR_REFERENCE_MARKER_AMPLITUDE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 457
#define RSEMI_ATTR_REFERENCE_MARKER_TRACE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 458
#define RSEMI_ATTR_DELTA_MARKER_REFERENCE_MARKER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 459
#define RSEMI_ATTR_REFERENCE_MARKER_AOFF                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 461
#define RSEMI_ATTR_SAN_RESOLUTION_BANDWIDTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 271
#define RSEMI_ATTR_SAN_RESOLUTION_BANDWIDTH_AUTO                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 272
#define RSEMI_ATTR_RESOLUTION_BANDWIDTH_RATIO                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 273
#define RSEMI_ATTR_RESOLUTION_BANDWIDTH_RATIO_MIN_MAX                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1618
#define RSEMI_ATTR_RESOLUTION_BANDWIDTH_RATIO_GET_MIN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1619
#define RSEMI_ATTR_RESOLUTION_BANDWIDTH_RATIO_GET_MAX                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1620
#define RSEMI_ATTR_SAN_RESOLUTION_BANDWIDTH_FILTER_TYPE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 316
#define RSEMI_ATTR_SWEEP_TIME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 276
#define RSEMI_ATTR_SWEEP_TIME_AUTO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 277
#define RSEMI_ATTR_SWEEP_DURATION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1070
#define RSEMI_ATTR_SWEEP_MODE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 274
#define RSEMI_ATTR_SWEEP_POINTS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 278
#define RSEMI_ATTR_SWEEP_OPTIMIZATION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1071
#define RSEMI_ATTR_SWEEP_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 280
#define RSEMI_ATTR_SWEEP_COUNT_CURRENT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 281
#define RSEMI_ATTR_VIDEO_BANDWIDTH                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 283
#define RSEMI_ATTR_VIDEO_BANDWIDTH_AUTO                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 284
#define RSEMI_ATTR_VIDEO_BANDWIDTH_RATIO                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 285
#define RSEMI_ATTR_VIDEO_BANDWIDTH_TYPE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 317
#define RSEMI_ATTR_FFT_FILTER_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 286
#define RSEMI_ATTR_ROSC_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 471
#define RSEMI_ATTR_ROSC_SOURCE_EAUTO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 472
#define RSEMI_ATTR_ROSC_FREQUENCY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 473
#define RSEMI_ATTR_ROSC_LOOP_BANDWIDTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1343
#define RSEMI_ATTR_ROSC_O100_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1344
#define RSEMI_ATTR_ROSC_O640_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1345
#define RSEMI_ATTR_ROSC_SYNC_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1346
#define RSEMI_ATTR_ROSC_TUNING_RANGE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1347
#define RSEMI_ATTR_TRACE_STATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 339
#define RSEMI_ATTR_TRACE_RESET_BEHAVIOR                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 340
#define RSEMI_ATTR_TRACE_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 341
#define RSEMI_ATTR_DETECTOR_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345
#define RSEMI_ATTR_DETECTOR_TYPE_AUTO                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346
#define RSEMI_ATTR_TRACE_EXPORT_ALL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1078
#define RSEMI_ATTR_TRACE_EXPORT_HEADER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1348
#define RSEMI_ATTR_TRACE_MATH_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 342
#define RSEMI_ATTR_TRACE_MATH_POSITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 343
#define RSEMI_ATTR_TRACE_MATH_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 344
#define RSEMI_ATTR_TRIGGER_SOURCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 475
#define RSEMI_ATTR_TRIGGER_DELAY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 476
#define RSEMI_ATTR_TRIGGER_SLOPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 477
#define RSEMI_ATTR_TRIGGER_DROPOUT_TIME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1084
#define RSEMI_ATTR_TRIGGER_IQP_LEVEL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1085
#define RSEMI_ATTR_TRIGGER_RFP_LEVEL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 942
#define RSEMI_ATTR_TRIGGER_RFP_HOLDOFF                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 481
#define RSEMI_ATTR_TRIGGER_POSITION_IN_SAMPLE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 949
#define RSEMI_ATTR_TRIGGER_DIRECTION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1086
#define RSEMI_ATTR_TRIGGER_OUTPUT_TYPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1087
#define RSEMI_ATTR_TRIGGER_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1088
#define RSEMI_ATTR_TRIGGER_PULSE_LENGTH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1089
#define RSEMI_ATTR_TRIGGER_PULSE_GENERATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1090
#define RSEMI_ATTR_EXTERNAL_TRIGGER_LEVEL_PORT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1091
#define RSEMI_ATTR_EXTERNAL_GATE_TRACE_STATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 496
#define RSEMI_ATTR_EXTERNAL_GATE_TRACE_START                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 497
#define RSEMI_ATTR_EXTERNAL_GATE_TRACE_STOP                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 498
#define RSEMI_ATTR_EXTERNAL_GATE_TRACE_PERIOD_LENGTH                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 499
#define RSEMI_ATTR_EXTERNAL_GATE_TRACE_COMMENT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 500
#define RSEMI_ATTR_EXTERNAL_GATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 490
#define RSEMI_ATTR_EXTERNAL_GATE_HOLD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 491
#define RSEMI_ATTR_EXTERNAL_GATE_TRIGGER_TYPE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 492
#define RSEMI_ATTR_EXTERNAL_GATE_POLARITY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 493
#define RSEMI_ATTR_EXTERNAL_GATE_LENGTH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 494
#define RSEMI_ATTR_EXTERNAL_GATE_SIGNAL_SOURCE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 495
#define RSEMI_ATTR_EXTERNAL_TRIGGER_LEVEL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 487
#define RSEMI_ATTR_VIDEO_TRIGGER_LEVEL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 501
#define RSEMI_ATTR_TRIGGER_IFP_LEVEL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 502
#define RSEMI_ATTR_TRIGGER_IFP_OFFSET                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 503
#define RSEMI_ATTR_TRIGGER_IFP_HYSTERESIS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 504
#define RSEMI_ATTR_TRIGGER_IFP_COUPLING                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1684
#define RSEMI_ATTR_TRIGGER_TIME_INTERVAL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 505
#define RSEMI_ATTR_EXTERNAL_MIXER_CONVERSION_LOSS_LOW                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 523
#define RSEMI_ATTR_EXTERNAL_MIXER_CONVERSION_LOSS_TABLE_LOW                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 532
#define RSEMI_ATTR_EXTERNAL_MIXER_CONVERSION_LOSS_HIGH                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 530
#define RSEMI_ATTR_EXTERNAL_MIXER_CONVERSION_LOSS_TABLE_HIGH                RS_SPECIFIC_PUBLIC_ATTR_BASE + 531
#define RSEMI_ATTR_CVL_NAME                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 330
#define RSEMI_ATTR_CVL_MIXER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 331
#define RSEMI_ATTR_CVL_MIXER_SNUM                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 332
#define RSEMI_ATTR_CVL_BAND                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 333
#define RSEMI_ATTR_CVL_HARM                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 334
#define RSEMI_ATTR_CVL_PORT_MIXER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 335
#define RSEMI_ATTR_CVL_BIAS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 336
#define RSEMI_ATTR_CVL_COMMENT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 337
#define RSEMI_ATTR_CVL_CLEAR                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 338
#define RSEMI_ATTR_CVL_CATALOG                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1107
#define RSEMI_ATTR_EXTERNAL_MIXER_HARMONIC_TYPE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 528
#define RSEMI_ATTR_EXTERNAL_MIXER_HIGH_HARMONIC_STATE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 541
#define RSEMI_ATTR_EXTERNAL_MIXER_HARMONIC                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 526
#define RSEMI_ATTR_EXTERNAL_MIXER_HIGH_HARMONIC                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 542
#define RSEMI_ATTR_EXTERNAL_MIXER_BIAS_LOW                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 533
#define RSEMI_ATTR_EXTERNAL_MIXER_BIAS_HIGH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 534
#define RSEMI_ATTR_EXTERNAL_MIXER_SIGNAL_ID_MODE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 522
#define RSEMI_ATTR_EXTERNAL_MIXER_LO_POWER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 524
#define RSEMI_ATTR_EXTERNAL_MIXER_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 525
#define RSEMI_ATTR_EXTERNAL_MIXER_NUMBER_OF_PORTS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 527
#define RSEMI_ATTR_EXTERNAL_MIXER_HARMONIC_BAND                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 529
#define RSEMI_ATTR_EXTERNAL_MIXER_THRESHOLD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 535
#define RSEMI_ATTR_GET_EXTERNAL_MIXER_RF_FREQUENCY_START                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 536
#define RSEMI_ATTR_GET_EXTERNAL_MIXER_RF_FREQUENCY_STOP                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 537
#define RSEMI_ATTR_EXTERNAL_MIXER_HANDOVER_FREQUENCY                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 538
#define RSEMI_ATTR_EXTERNAL_MIXER_RF_OVERRANGE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 539
#define RSEMI_ATTR_EXTERNAL_MIXER_PRESET_BAND                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 540
#define RSEMI_ATTR_AMPLITUDE_UNITS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 252
#define RSEMI_ATTR_ATTENUATION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 253
#define RSEMI_ATTR_ATTENUATION_MIN_MAX                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1634
#define RSEMI_ATTR_ATTENUATION_UP_DOWN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1635
#define RSEMI_ATTR_ATTENUATION_GET_MIN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1636
#define RSEMI_ATTR_ATTENUATION_GET_MAX                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1637
#define RSEMI_ATTR_ATTENUATION_AUTO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 254
#define RSEMI_ATTR_ATTENUATION_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 255
#define RSEMI_ATTR_ATTENUATION_IF_AUTO                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1674
#define RSEMI_ATTR_ATTENUATION_IF                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1675
#define RSEMI_ATTR_ATTENUATION_LIMITER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1676
#define RSEMI_ATTR_REFERENCE_LEVEL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 269
#define RSEMI_ATTR_REFERENCE_LEVEL_OFFSET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 270
#define RSEMI_ATTR_AMPL_RF_COUPLING                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 543
#define RSEMI_ATTR_AMPL_EATT_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 544
#define RSEMI_ATTR_AMPL_EATT_AUTO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 545
#define RSEMI_ATTR_AMPL_EATT_VALUE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 546
#define RSEMI_ATTR_NOISE_INP_PRES_STAT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 549
#define RSEMI_ATTR_INP_PRESELECTOR_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1349
#define RSEMI_ATTR_INP_PRESELECTOR_FILTER_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1350
#define RSEMI_ATTR_INP_PRESELECTOR_FILTER_TYPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1351
#define RSEMI_ATTR_INP_PRESELECTOR_FILTER_LPAS_FREQ                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1352
#define RSEMI_ATTR_INP_PRESELECTOR_FILTER_HPAS_FREQ                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1353
#define RSEMI_ATTR_INP_PRESELECTOR_FILTER_SPLIT_STATE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1677
#define RSEMI_ATTR_AMPL_PREAMPLIFIER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 550
#define RSEMI_ATTR_AMPL_PREAMPLIFIER_LEVEL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1108
#define RSEMI_ATTR_AMPL_LNA_PREAMPLIFIER_AUTO                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1678
#define RSEMI_ATTR_AMPL_LNA_PREAMPLIFIER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1679
#define RSEMI_ATTR_AMPL_PROTECTION_RESET                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1109
#define RSEMI_ATTR_AMPL_PROTECTION_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1355
#define RSEMI_ATTR_AMPL_YIG_FILTER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 553
#define RSEMI_ATTR_AMPL_HIGHPASS_FILTER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1110
#define RSEMI_ATTR_AMPL_RF_INPUT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1111
#define RSEMI_ATTR_SAN_INPUT_IMPEDANCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 267
#define RSEMI_ATTR_DIRECT_PATH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1685
#define RSEMI_ATTR_INP_PRESELECTOR_NOTCH_FILTER_STATE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1718
#define RSEMI_LIMIT_STATE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 555
#define RSEMI_LIMIT_CLEAR                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 556
#define RSEMI_SAN_LIMIT_ASSIGN_TRACE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 557
#define RSEMI_LIMIT_UNITS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 558
#define RSEMI_SAN_LIMIT_COMMENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 559
#define RSEMI_SAN_LIMIT_COPY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 560
#define RSEMI_SAN_LIMIT_NAME                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 561
#define RSEMI_SAN_LIMIT_DELETE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 562
#define RSEMI_ATTR_LIMIT_LINE_ACTIVE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1114
#define RSEMI_LIMIT_CHECK_RESULT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 706
#define RSEMI_SAN_LIMIT_CONTROL_DOMAIN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 564
#define RSEMI_LIMIT_CONTROL_SPACING                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 565
#define RSEMI_LIMIT_CONTROL_SCALING                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 566
#define RSEMI_LIMIT_CONTROL_OFFSET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 567
#define RSEMI_LIMIT_CONTROL_SHIFT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 568
#define RSEMI_LIMIT_LOWER_STATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 569
#define RSEMI_LIMIT_LOWER_SCALING                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 570
#define RSEMI_LIMIT_LOWER_SPACING                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 571
#define RSEMI_LIMIT_LOWER_MARGIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 572
#define RSEMI_LIMIT_LOWER_THRESHOLD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 573
#define RSEMI_LIMIT_LOWER_OFFSET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 574
#define RSEMI_LIMIT_LOWER_SHIFT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 575
#define RSEMI_LIMIT_UPPER_STATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 576
#define RSEMI_LIMIT_UPPER_SCALING                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 577
#define RSEMI_LIMIT_UPPER_SPACING                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 578
#define RSEMI_LIMIT_UPPER_MARGIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 579
#define RSEMI_LIMIT_UPPER_THRESHOLD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 580
#define RSEMI_LIMIT_UPPER_OFFSET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 581
#define RSEMI_LIMIT_UPPER_SHIFT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 582
#define RSEMI_ATTR_DLINE_STATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 585
#define RSEMI_ATTR_DLINE_POSITION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 586
#define RSEMI_ATTR_FLINE_STATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 587
#define RSEMI_ATTR_FLINE_POSITION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 588
#define RSEMI_ATTR_TLINE_STATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 589
#define RSEMI_ATTR_TLINE_POSITION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 590
#define RSEMI_ATTR_THRLINE_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 583
#define RSEMI_ATTR_THRLINE_POSITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 584
#define RSEMI_ATTR_DISP_REF_VALUE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 591
#define RSEMI_ATTR_DISP_REF_POSITION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 592
#define RSEMI_ATTR_DISP_FP_KEYS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 593
#define RSEMI_ATTR_SELECT_WINDOW                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 594
#define RSEMI_ATTR_DISP_CHANNEL_BAR_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1116
#define RSEMI_ATTR_DISP_MULTIVIEW_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1357
#define RSEMI_ATTR_DISP_FREQ_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 595
#define RSEMI_ATTR_DISP_LOGO_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 596
#define RSEMI_ATTR_DISP_TIME_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 597
#define RSEMI_ATTR_DISP_COMMENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 598
#define RSEMI_ATTR_DISP_COMMENT_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 599
#define RSEMI_ATTR_DISP_FORMAT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1117
#define RSEMI_ATTR_DISP_WINDOW_SIZE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 603
#define RSEMI_ATTR_DISP_LOG_RANGE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 606
#define RSEMI_ATTR_DISP_AMPLITUDE_GRID_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 607
#define RSEMI_ATTR_DISP_UPDATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 609
#define RSEMI_ATTR_QUERY_SELECT_SUBWINDOW                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 611
#define RSEMI_ATTR_DISP_UNIT_POWER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1266
#define RSEMI_ATTR_DISP_TRACE_Y_AUTO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1118
#define RSEMI_ATTR_DISP_Y_AXIS_SCALING                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 616
#define RSEMI_ATTR_DISP_REF_VALUE_AUTO                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 614
#define RSEMI_ATTR_DISPLAY_INPUT_STATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1751
#define RSEMI_ATTR_DISP_STATUS_BAR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 617
#define RSEMI_ATTR_DISP_SOFTKEY_BAR                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 618
#define RSEMI_ATTR_DISP_TOOL_BAR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 619
#define RSEMI_ATTR_DISP_TOUCHSCREEN_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 620
#define RSEMI_ATTR_DISP_THEME_CATALOG                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1119
#define RSEMI_ATTR_DISP_SELECT_THEME                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 621
#define RSEMI_ATTR_DISPLAY_MARKER_INFO                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1686
#define RSEMI_ATTR_DISPLAY_ZOOM_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 624
#define RSEMI_ATTR_DISPLAY_CONDUCTANCES                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1687
#define RSEMI_ATTR_QUERY_ACTIVE_MEASUREMENT_WINDOW                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 631
#define RSEMI_ATTR_UNIT_POWER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 613
#define RSEMI_ATTR_DISPLAY_MULTIPLE_ZOOM_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1122
#define RSEMI_ATTR_LAYOUT_WINDOW_REMOVE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1125
#define RSEMI_ATTR_LAYOUT_WINDOW_LIST                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1127
#define RSEMI_ATTR_LAYOUT_QUERY_WINDOW_TYPE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1130
#define RSEMI_ATTR_LAYOUT_QUERY_WINDOW_NAME                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1131
#define RSEMI_ATTR_DISP_COL_PRESET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 604
#define RSEMI_ATTR_DISP_COL_PREDEFINED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 605
#define RSEMI_ATTR_DISPLAY_FOCUS_AREA                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 612
#define RSEMI_ATTR_DISPLAY_SUBWINDOW_SIZE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1613
#define RSEMI_ATTR_AUDIO_OUTPUT_MAXIMUM_VOLUME                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1358
#define RSEMI_ATTR_AUDIO_OUTPUT_MUTE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1359
#define RSEMI_ATTR_SYST_SPEAKER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 951
#define RSEMI_ATTR_APPL_SETUP_REC                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 952
#define RSEMI_ATTR_REMOTE_LOGGING_STATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 955
#define RSEMI_ATTR_SYSTEM_SHUTDOWN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 956
#define RSEMI_ATTR_FRONTEND_TEMPERATURE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1360
#define RSEMI_ATTR_SYST_PREAMPLIFIER_OPTION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1361
#define RSEMI_ATTR_SECURE_USER_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1362
#define RSEMI_ATTR_COUPLING_ATTENUATION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1017
#define RSEMI_ATTR_COUPLING_BANDWIDTH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1018
#define RSEMI_ATTR_COUPLING_CENTER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1019
#define RSEMI_ATTR_COUPLING_DEMODULATION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1020
#define RSEMI_ATTR_COUPLING_GAIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1021
#define RSEMI_ATTR_COUPLING_LIMIT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1022
#define RSEMI_ATTR_COUPLING_MARKER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1023
#define RSEMI_ATTR_COUPLING_PRESELECTOR                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1024
#define RSEMI_ATTR_COUPLING_SPAN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1025
#define RSEMI_ATTR_MEAS_ABORT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 300
#define RSEMI_ATTR_INIT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 301
#define RSEMI_ATTR_INIT_WITHOUT_OPC                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 302
#define RSEMI_ATTR_INIT_CONMEAS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 303
#define RSEMI_ATTR_INIT_SW_TRIGGER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 304
#define RSEMI_ATTR_INIT_SPURIOUS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 305
#define RSEMI_ATTR_INIT_SEM_MEAS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 306
#define RSEMI_ATTR_INIT_SEQUENCER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1137
#define RSEMI_ATTR_ABORT_SEQUENCER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1138
#define RSEMI_ATTR_REFRESH_SEQUENCER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1139
#define RSEMI_ATTR_SEQUENCER_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1140
#define RSEMI_ATTR_SEQUENCER_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1141
#define RSEMI_ATTR_REFERENCE_MARKER_PNO_STATE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 709
#define RSEMI_ATTR_REFERENCE_MARKER_PNO_RESULT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 710
#define RSEMI_ATTR_REFERENCE_MARKER_PNO_AUTO                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 711
#define RSEMI_ATTR_MARKER_NDB_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 715
#define RSEMI_ATTR_MARKER_NDB_VAL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 716
#define RSEMI_ATTR_MARKER_NDB_RESULT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 717
#define RSEMI_ATTR_MARKER_NDB_Q_FACTOR                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 718
#define RSEMI_ATTR_LIST_POW_STATE_OFF                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 720
#define RSEMI_ATTR_MEAS_TDOM_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 721
#define RSEMI_ATTR_MEAS_TDOM_PEAK                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 722
#define RSEMI_ATTR_MEAS_TDOM_RMS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 723
#define RSEMI_ATTR_MEAS_TDOM_MEAN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 724
#define RSEMI_ATTR_MEAS_TDOM_SDEV                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 725
#define RSEMI_ATTR_MEAS_TDOM_AVG                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 726
#define RSEMI_ATTR_MEAS_TDOM_MAX_HOLD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 727
#define RSEMI_ATTR_MEAS_TDOM_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 728
#define RSEMI_ATTR_MEAS_TDOM_AOFF                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 729
#define RSEMI_ATTR_MEAS_TDOM_SET_REFERENCE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 730
#define RSEMI_ATTR_MEAS_TDOM_PEAK_RESULT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 731
#define RSEMI_ATTR_MEAS_TDOM_RMS_RESULT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 732
#define RSEMI_ATTR_MEAS_TDOM_MEAN_RESULT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 733
#define RSEMI_ATTR_MEAS_TDOM_SDEV_RESULT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 734
#define RSEMI_ATTR_MEAS_TDOM_AVG_PEAK_RESULT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 735
#define RSEMI_ATTR_MEAS_TDOM_AVG_RMS_RESULT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 736
#define RSEMI_ATTR_MEAS_TDOM_AVG_MEAN_RESULT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 737
#define RSEMI_ATTR_MEAS_TDOM_AVG_SDEV_RESULT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 738
#define RSEMI_ATTR_MEAS_TDOM_PEAK_HOLD_RESULT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 739
#define RSEMI_ATTR_MEAS_TDOM_PEAK_HOLD_RMS_RESULT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 740
#define RSEMI_ATTR_MEAS_TDOM_PEAK_HOLD_MEAN_RESULT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 741
#define RSEMI_ATTR_MEAS_TDOM_PEAK_HOLD_SDEV_RESULT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 742
#define RSEMI_ATTR_MEAS_POW_SELECT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 743
#define RSEMI_ATTR_MEAS_POW_SET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1688
#define RSEMI_ATTR_MEAS_POW_OFF                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 744
#define RSEMI_ATTR_MEAS_POW_ADJ_NUM                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 745
#define RSEMI_ATTR_MEAS_POW_ADJ_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 746
#define RSEMI_ATTR_MEAS_POW_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 747
#define RSEMI_ATTR_MEAS_POW_RESULT_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 748
#define RSEMI_ATTR_MEAS_POW_ADJ_CHANNEL_SPACING                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 750
#define RSEMI_ATTR_MEAS_POW_ADJ_CHANNEL_NAME                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 754
#define RSEMI_ATTR_MEAS_POW_ADJ_CHANNEL_BANDWIDTH                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 756
#define RSEMI_ATTR_MEAS_POW_NOISE_CORR                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 758
#define RSEMI_ATTR_MEAS_POW_NOISE_CORR_AUTO                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 759
#define RSEMI_ATTR_MEAS_POW_TRACE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 760
#define RSEMI_ATTR_MEAS_POW_STANDARD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 761
#define RSEMI_ATTR_MEAS_POW_USER_STANDARD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1365
#define RSEMI_ATTR_MEAS_POW_STANDARD_CATALOG                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1149
#define RSEMI_ATTR_MEAS_POW_REF_VALUE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 762
#define RSEMI_ATTR_MEAS_POW_ADJ_PRESET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 763
#define RSEMI_ATTR_MEAS_POW_CARR_SIG_NUM                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 776
#define RSEMI_ATTR_MEAS_POW_REF_CHAN_SEL_AUTO                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 777
#define RSEMI_ATTR_MEAS_POW_ADJ_REF_TXCHANNEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 778
#define RSEMI_ATTR_MEAS_POW_BANDWIDTH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 779
#define RSEMI_ATTR_SEM_WEIGHT_FILTER_ALL_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 934
#define RSEMI_ATTR_SEM_WEIGHT_FILTER_ALL_ALPHA                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 935
#define RSEMI_ATTR_SEM_WEIGHT_FILTER_ACH_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 936
#define RSEMI_ATTR_SEM_WEIGHT_FILTER_ACH_ALPHA                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 937
#define RSEMI_ATTR_MEAS_POW_CHANNEL_BANDWIDTH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 752
#define RSEMI_ATTR_MSR_NUMBER_OF_SUBBLOCKS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1366
#define RSEMI_ATTR_MSR_GAP_CHANNEL_SPACING                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1367
#define RSEMI_ATTR_MSR_GAP_CHANNEL_BANDWIDTHS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1368
#define RSEMI_ATTR_MSR_GAP_WEIGHTING_FILTER_STATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1369
#define RSEMI_ATTR_MSR_GAP_WEIGHTING_FILTER_ROLL_OFF_FACTOR                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1370
#define RSEMI_ATTR_MSR_GAP_LIMIT_RELATIVE_STATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1371
#define RSEMI_ATTR_MSR_GAP_LIMIT_RELATIVE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1372
#define RSEMI_ATTR_MSR_GAP_LIMIT_ABSOLUTE_STATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1373
#define RSEMI_ATTR_MSR_GAP_LIMIT_ABSOLUTE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1374
#define RSEMI_ATTR_MSR_SUBBLOCK_CENTER_FREQUENCY                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1376
#define RSEMI_ATTR_MSR_SUBBLOCK_RF_BANDWIDTH                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1377
#define RSEMI_ATTR_MSR_SUBBLOCK_TX_CHANNEL_COUNT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1378
#define RSEMI_ATTR_MSR_TX_CENTER_FREQUENCY                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1379
#define RSEMI_ATTR_MSR_TX_TECHNOLOGY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1380
#define RSEMI_ATTR_MSR_TX_BANDWIDTH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1381
#define RSEMI_ATTR_MSR_TX_WEIGHTING_FILTER_STATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1382
#define RSEMI_ATTR_MSR_TX_WEIGHTING_FILTER_ROLL_OFF_FACTOR                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1383
#define RSEMI_ATTR_MSR_TX_CHANNEL_NAME                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1384
#define RSEMI_ATTR_MEAS_POW_ALT_CHANNEL_SPACING                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 751
#define RSEMI_ATTR_MEAS_POW_ALT_CHANNEL_NAME                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 755
#define RSEMI_ATTR_MEAS_POW_ALT_CHANNEL_BANDWIDTH                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 757
#define RSEMI_ATTR_POWER_ALT_CHANNEL_WEIGHTING_FILTER_STATE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1150
#define RSEMI_ATTR_POWER_ALT_CHANNEL_WEIGHTING_FILTER_ALPHA_VALUE           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1151
#define RSEMI_ATTR_SEM_WEIGHT_FILTER_ALT_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 938
#define RSEMI_ATTR_SEM_WEIGHT_FILTER_ALT_ALPHA                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 939
#define RSEMI_ATTR_MEAS_POW_CHANNEL_NAME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 753
#define RSEMI_ATTR_MEAS_POW_CHAN_SPACING                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1152
#define RSEMI_ATTR_MEAS_POW_CHANNEL_SPACING                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 749
#define RSEMI_ATTR_POW_CHANNEL_BANDWIDTH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1153
#define RSEMI_ATTR_POWER_CHANNEL_WEIGHTING_FILTER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1154
#define RSEMI_ATTR_POWER_CHANNEL_WEIGHTING_FILTER_ALPHA                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1155
#define RSEMI_ATTR_SEM_WEIGHT_FILTER_TX_CHANNEL_STATE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 940
#define RSEMI_ATTR_SEM_WEIGHT_FILTER_TX_CHANNEL_ALPHA                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 941
#define RSEMI_ATTR_MEAS_ACP_ALT_LIMIT_REL_STATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 774
#define RSEMI_ATTR_MEAS_ACP_ALT_LIMIT_ABS_STATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 775
#define RSEMI_ATTR_MEAS_ACP_LIMIT_STATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 771
#define RSEMI_ATTR_MEAS_ACP_LIMIT_REL_STATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 772
#define RSEMI_ATTR_MEAS_ACP_LIMIT_ABS_STATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 773
#define RSEMI_ATTR_ACP_USER_STD_SET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 764
#define RSEMI_ATTR_ACP_USER_STD_SAVE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 765
#define RSEMI_ATTR_ACP_USER_STD_DELETE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 766
#define RSEMI_ATTR_MEAS_ACP_HSP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 767
#define RSEMI_ATTR_MEAS_ACP_PRESET_REF_LEVEL                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 768
#define RSEMI_ATTR_MEAS_STAT_APD_STATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 796
#define RSEMI_ATTR_MEAS_STAT_CCDF_STATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 797
#define RSEMI_ATTR_MEAS_STAT_SAMPLES                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 798
#define RSEMI_ATTR_MEAS_STAT_X_REF                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 799
#define RSEMI_ATTR_MEAS_STAT_X_RANGE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 800
#define RSEMI_ATTR_MEAS_STAT_Y_UNIT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 801
#define RSEMI_ATTR_MEAS_STAT_Y_MIN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 802
#define RSEMI_ATTR_MEAS_STAT_Y_MAX                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 803
#define RSEMI_ATTR_MEAS_STAT_ADJ                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 805
#define RSEMI_ATTR_MEAS_STAT_PRESET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 807
#define RSEMI_ATTR_STAT_RESULT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 808
#define RSEMI_ATTR_MEAS_MDEPTH_STATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 809
#define RSEMI_ATTR_MEAS_MDEPTH_RESULT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 810
#define RSEMI_ATTR_MEAS_MODDEPTH_SEARCH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1167
#define RSEMI_ATTR_MEAS_MDEPTH_SEARCH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 811
#define RSEMI_ATTR_MEAS_TOI_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 812
#define RSEMI_ATTR_MEAS_TOI_RESULT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 813
#define RSEMI_ATTR_MEAS_TOI_SEARCH                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 814
#define RSEMI_ATTR_MEAS_HDIST_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 816
#define RSEMI_ATTR_MEAS_HDIST_NOOFHARM                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 817
#define RSEMI_ATTR_MEAS_HDIST_RBWAUTO                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 818
#define RSEMI_ATTR_MEAS_HDIST_PRESET                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 819
#define RSEMI_ATTR_MPOW_MIN                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 820
#define RSEMI_ATTR_MPOW_FTYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 821
#define RSEMI_ATTR_SE_PEAK_SEARCH_MARGIN                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 822
#define RSEMI_ATTR_SE_PEAK_SEARCH_DETAILS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1719
#define RSEMI_ATTR_SE_PEAK_SEARCH_PEAKS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 823
#define RSEMI_ATTR_SE_MARK_ALL_PEAKS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1173
#define RSEMI_ATTR_SE_LIST_RANG_COUNT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 841
#define RSEMI_ATTR_SE_PEAK_SEARCH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 842
#define RSEMI_ATTR_SE_STORE_FILE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 843
#define RSEMI_ATTR_SE_LIST_EVAL_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 848
#define RSEMI_ATTR_SE_LIST_RANG_DEL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 840
#define RSEMI_ATTR_SE_LIST_RANG_START                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 824
#define RSEMI_ATTR_SE_LIST_RANG_STOP                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 825
#define RSEMI_ATTR_SE_LIST_RANG_FILT_TYPE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 826
#define RSEMI_ATTR_SE_LIST_RANG_BAND                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 827
#define RSEMI_ATTR_SE_LIST_RANG_BAND_VID                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 828
#define RSEMI_ATTR_SE_LIST_RANG_SWE_TIME_AUTO                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 829
#define RSEMI_ATTR_SE_LIST_RANG_SWE_TIME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 830
#define RSEMI_ATTR_SE_LIST_RANG_DET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 831
#define RSEMI_ATTR_SE_LIST_RANG_RLEV                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 832
#define RSEMI_ATTR_SE_LIST_RANG_INP_ATT_AUTO                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 833
#define RSEMI_ATTR_SE_LIST_RANG_INP_ATT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 834
#define RSEMI_ATTR_SE_LIST_RANG_POINTS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 835
#define RSEMI_ATTR_SE_LIST_RANG_BREAK                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 836
#define RSEMI_ATTR_SE_LIST_RANG_TRAN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 837
#define RSEMI_ATTR_SE_LIST_RANG_INP_GAIN_STAT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 838
#define RSEMI_ATTR_SE_LIST_RANG_INP_GAIN_LEVEL                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1385
#define RSEMI_ATTR_SE_LIST_RANGE_INP_GAIN_LNA_STAT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1689
#define RSEMI_ATTR_SE_LIST_RANG_LIMIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 844
#define RSEMI_ATTR_SE_LIST_RANG_LIMIT_STATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 847
#define RSEMI_ATTR_SE_LIST_RANG_LIMIT_START                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 845
#define RSEMI_ATTR_SE_LIST_RANG_LIMIT_STOP                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 846
#define RSEMI_ATTR_IQ_DATA_ANALYZER_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 852
#define RSEMI_ATTR_IQ_DATA_FORMAT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 853
#define RSEMI_ATTR_IQ_SAMPLE_RATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 854
#define RSEMI_ATTR_IQ_MAX_BANDWIDTH_EXTENSION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1387
#define RSEMI_ATTR_IQ_MAX_BANDWIDTH_VALUE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1388
#define RSEMI_ATTR_IQ_MAX_BANDWIDTH_MAX                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1389
#define RSEMI_ATTR_IQ_BANDWIDTH_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1390
#define RSEMI_ATTR_IQ_BANDWIDTH_RESOLUTION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1391
#define RSEMI_ATTR_IQ_RECORD_LENGTH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 856
#define RSEMI_ATTR_IQ_DATA_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 858
#define RSEMI_ATTR_IQ_DATA_AVER_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 861
#define RSEMI_ATTR_IQ_DATA_AVER_COUNT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 862
#define RSEMI_ATTR_IQ_DATA_GATE_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 863
#define RSEMI_ATTR_IQ_DATA_GATE_TYPE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 864
#define RSEMI_ATTR_IQ_DATA_GATE_LENGTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 865
#define RSEMI_ATTR_IQ_DATA_GATE_GAP                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 866
#define RSEMI_ATTR_IQ_DATA_GATE_NUMBER_OF_PERIODS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 867
#define RSEMI_ATTR_IQ_DATA_DISPLAY_TYPE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 868
#define RSEMI_ATTR_IQ_DATA_FILTER_BANDWIDTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 869
#define RSEMI_ATTR_IQ_SWAP_IQ                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1392
#define RSEMI_ATTR_LOAD_IQ_DATA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 870
#define RSEMI_ATTR_SAVE_IQ_DATA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 871
#define RSEMI_ATTR_IQ_FFT_ALGORITHM                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1393
#define RSEMI_ATTR_IQ_FFT_LENGTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1394
#define RSEMI_ATTR_IQ_FFT_WIN_LENGTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1395
#define RSEMI_ATTR_IQ_FFT_WIN_OVERLAP                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1396
#define RSEMI_ATTR_IQ_FFT_WINDOW_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1397
#define RSEMI_ATTR_IQ_APC_STATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1398
#define RSEMI_ATTR_IQ_APC_FACTOR_A                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1399
#define RSEMI_ATTR_IQ_APC_FACTOR_B                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1400
#define RSEMI_ATTR_IQ_APC_RESULT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1401
#define RSEMI_ATTR_IQ_DATA_EXPORT_FILE_DESCRIPTION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 872
#define RSEMI_ATTR_ESP_RESTORE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 874
#define RSEMI_ATTR_ESP_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 875
#define RSEMI_ATTR_SEM_PEAK_SEARCH                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1267
#define RSEMI_ATTR_ESP_MAN_VAL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 877
#define RSEMI_ATTR_SEM_PEAK_SEARCH_MARGIN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 883
#define RSEMI_ATTR_SEM_PEAK_SEARCH_PEAKS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 884
#define RSEMI_ATTR_SEM_LIST_EVAL_STATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 885
#define RSEMI_ATTR_SEM_MARK_ALL_PEAKS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 886
#define RSEMI_ATTR_SEM_POWER_REF_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 887
#define RSEMI_ATTR_SEM_BANDWIDTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 888
#define RSEMI_ATTR_SEM_RRC_FILTER_STATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 889
#define RSEMI_ATTR_SEM_RRC_FILTER_ALPHA_VALUE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 890
#define RSEMI_ATTR_SEM_REF_RANGE_POSITION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 891
#define RSEMI_ATTR_SEM_FAST_SEM                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 897
#define RSEMI_ATTR_SEM_LIST_FILE_EXPORT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 903
#define RSEMI_ATTR_SEM_RANGE_COUNT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 926
#define RSEMI_ATTR_SEM_POWER_CLASS_COUNT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 933
#define RSEMI_ATTR_ESP_PEAK_SEARCH                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 876
#define RSEMI_ATTR_SEM_INSERT_NEW_RANGE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 927
#define RSEMI_ATTR_SEM_DELETE_RANGE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 928
#define RSEMI_ATTR_SEM_RANGE_FREQ_START                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 906
#define RSEMI_ATTR_SEM_RANGE_FREQ_STOP                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 907
#define RSEMI_ATTR_SEM_RANGE_FILTER_TYPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 917
#define RSEMI_ATTR_SEM_RANGE_BANDWIDTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 904
#define RSEMI_ATTR_SEM_RANGE_VBW                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 905
#define RSEMI_ATTR_SEM_RANGE_SWEEP_TIME_AUTO                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 924
#define RSEMI_ATTR_SEM_RANGE_SWEEP_TIME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 923
#define RSEMI_ATTR_SEM_RANGE_REF_LEVEL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 922
#define RSEMI_ATTR_SEM_RANGE_INPUT_ATTENUATION_AUTO                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 919
#define RSEMI_ATTR_SEM_RANGE_INPUT_ATTENUATION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 918
#define RSEMI_ATTR_SEM_RANGE_PREAMPLIFIER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 920
#define RSEMI_ATTR_SEM_RANGE_LNA_PREAMPLIFIER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1690
#define RSEMI_ATTR_SEM_RANGE_TRANSDUCER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 925
#define RSEMI_ATTR_SEM_RANGE_LIMIT_CHECK_TYPE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 916
#define RSEMI_ATTR_SEM_RANGE_START_FREQ_ABS_LIMIT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 908
#define RSEMI_ATTR_SEM_RANGE_STOP_FREQ_ABS_LIMIT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 909
#define RSEMI_ATTR_SEM_RANGE_START_FREQ_REL_LIMIT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 910
#define RSEMI_ATTR_SEM_RANGE_STOP_FREQ_REL_LIMIT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 911
#define RSEMI_ATTR_SEM_POWER_CLASS_USED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 929
#define RSEMI_ATTR_SEM_POWER_CLASS_LIMIT_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 932
#define RSEMI_ATTR_SEM_POWER_CLASS_LOWER_LEVEL_LIMIT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 930
#define RSEMI_ATTR_SEM_POWER_CLASS_UPPER_LEVEL_LIMIT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 931
#define RSEMI_ATTR_SEM_PRESET_STANDARD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 898
#define RSEMI_ATTR_SEM_RESTORE_STANDARD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 901
#define RSEMI_ATTR_SEM_STORE_PRESET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 902
#define RSEMI_ATTR_SEM_SUBBLOCK_CENTER_FREQUENCY                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1402
#define RSEMI_ATTR_SEM_SUBBLOCK_COUNT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1403
#define RSEMI_ATTR_SEM_SUBBLOCK_POWER_REF_TYPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1404
#define RSEMI_ATTR_SEM_SUBBLOCK_BANDWIDTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1405
#define RSEMI_ATTR_SEM_SUBBLOCK_RRC_FILTER_STATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1406
#define RSEMI_ATTR_SEM_SUBBLOCK_RRC_FILTER_ALPHA_VALUE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1407
#define RSEMI_ATTR_SEM_SUBBLOCK_REF_RANGE_POSITION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1408
#define RSEMI_ATTR_SEM_SUBBLOCK_FAST_SEM                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1409
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_COUNT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1410
#define RSEMI_ATTR_SEM_SUBBLOCK_MSR_BAND_CATEGORY                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1411
#define RSEMI_ATTR_SEM_SUBBLOCK_MSR_RF_BANDWIDTH                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1412
#define RSEMI_ATTR_SEM_SUBBLOCK_MSR_GSM_PRESENT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1413
#define RSEMI_ATTR_SEM_SUBBLOCK_MSR_LTE_PRESENT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1414
#define RSEMI_ATTR_SEM_SUBBLOCK_MSR_APPLY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1415
#define RSEMI_ATTR_SEM_SUBBLOCK_INSERT_NEW_RANGE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1416
#define RSEMI_ATTR_SEM_SUBBLOCK_DELETE_RANGE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1417
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_FREQ_START                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1418
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_FREQ_STOP                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1419
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_FILTER_TYPE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1420
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_BANDWIDTH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1421
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_VBW                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1422
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_SWEEP_TIME_AUTO                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1423
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_SWEEP_TIME                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1424
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_REF_LEVEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1425
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_INPUT_ATTENUATION_AUTO                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1426
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_INPUT_ATTENUATION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1427
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_PREAMPLIFIER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1428
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_PREAMPLIFIER_LEVEL                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1429
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_TRANSDUCER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1430
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_MULTILIMT_CALC                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1431
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_MIN_SWEEP_POINTS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1432
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_LIMIT_CHECK_TYPE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1433
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_START_FREQ_ABS_LIMIT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1434
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_STOP_FREQ_ABS_LIMIT                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1435
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_START_FREQ_REL_LIMIT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1436
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_STOP_FREQ_REL_LIMIT                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1439
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_START_FREQ_REL_LIMIT_ABS_MAX          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1437
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_START_FREQ_REL_LIMIT_FUNC             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1438
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_STOP_FREQ_REL_LIMIT_ABS_MAX           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1440
#define RSEMI_ATTR_SEM_SUBBLOCK_RANGE_STOP_FREQ_REL_LIMIT_FUNC              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1441
#define RSEMI_ATTR_SEM_SUBBLOCK_PRESET_STANDARD                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1443
#define RSEMI_ATTR_SEM_SUBBLOCK_RESTORE_STANDARD                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1444
#define RSEMI_ATTR_SEM_SUBBLOCK_STORE_PRESET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1446
#define RSEMI_ATTR_ANALOG_DEMOD_TRIGGER_SOURCE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1447
#define RSEMI_ATTR_ANALOG_DEMOD_TRIGGER_AM_LEVEL_ABS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1448
#define RSEMI_ATTR_ANALOG_DEMOD_TRIGGER_AM_LEVEL_RELATIVE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1449
#define RSEMI_ATTR_ANALOG_DEMOD_TRIGGER_FM_LEVEL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1450
#define RSEMI_ATTR_ANALOG_DEMOD_TRIGGER_PM_LEVEL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1451
#define RSEMI_ATTR_ANALOG_DEMOD_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1452
#define RSEMI_ATTR_ANALOG_DEMOD_AF_COUPLING                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1453
#define RSEMI_ATTR_ANALOG_DEMOD_MEAS_TIME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1454
#define RSEMI_ATTR_ANALOG_DEMOD_BANDWIDTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1455
#define RSEMI_ATTR_ANALOG_DEMOD_ZOOM_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1456
#define RSEMI_ATTR_ANALOG_DEMOD_ZOOM_START                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1457
#define RSEMI_ATTR_ANALOG_DEMOD_ZOOM_LENGTH_MODE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1458
#define RSEMI_ATTR_ANALOG_DEMOD_ZOOM_LENGTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1459
#define RSEMI_ATTR_ANALOG_DEMOD_SQUELCH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1460
#define RSEMI_ATTR_ANALOG_DEMOD_SQUELCH_LEVEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1461
#define RSEMI_ATTR_ANALOG_DEMOD_PHASE_WRAP                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1463
#define RSEMI_ATTR_ANALOG_DEMOD_ZERO_PHASE_REF_POINT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1464
#define RSEMI_ATTR_ANALOG_DEMOD_PRESET_LOAD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1465
#define RSEMI_ATTR_ANALOG_DEMOD_PRESET_STORE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1466
#define RSEMI_ATTR_ANALOG_DEMOD_PRESET_RESTORE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1467
#define RSEMI_ATTR_ANALOG_DEMOD_AF_CENTER_FREQUENCY                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1468
#define RSEMI_ATTR_ANALOG_DEMOD_AF_SPAN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1469
#define RSEMI_ATTR_ANALOG_DEMOD_AF_START_FREQUENCY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1470
#define RSEMI_ATTR_ANALOG_DEMOD_AF_STOP_FREQUENCY                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1471
#define RSEMI_ATTR_ANALOG_DEMOD_AF_FULL_SPAN                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1472
#define RSEMI_ATTR_ANALOG_DEMOD_RF_SPECTRUM_RESOLUTION_BANDWIDTH            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1473
#define RSEMI_ATTR_ANALOG_DEMOD_RF_SPECTRUM_SPAN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1474
#define RSEMI_ATTR_ANALOG_DEMOD_RF_SPECTRUM_ZOOM                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1475
#define RSEMI_ATTR_ANALOG_DEMOD_HIGH_PASS_AF_FILTER_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1476
#define RSEMI_ATTR_ANALOG_DEMOD_HIGH_PASS_FILTER_FREQUENCY                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1477
#define RSEMI_ATTR_ANALOG_DEMOD_LOW_PASS_AF_FILTER_ENABLED                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1478
#define RSEMI_ATTR_ANALOG_DEMOD_LOW_PASS_AF_FILTER_FREQUENCY                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1479
#define RSEMI_ATTR_ANALOG_DEMOD_LOW_PASS_FILTER_FREQUENCY_RELATIVE          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1480
#define RSEMI_ATTR_ANALOG_DEMOD_FILTER_FREQUENCY_MANUAL_HIGHPASS            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1481
#define RSEMI_ATTR_ANALOG_DEMOD_FILTER_FREQUENCY_MANUAL_LOWPASS             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1482
#define RSEMI_ATTR_ANALOG_DEMOD_DEEMPHASIS_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1483
#define RSEMI_ATTR_ANALOG_DEMOD_DEEMPHASIS_TIME_CONSTANT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1484
#define RSEMI_ATTR_ANALOG_DEMOD_FILTER_CCITT_WEIGHTING                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1485
#define RSEMI_ATTR_ANALOG_DEMOD_FILTER_CCIR_WEIGHTING                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1486
#define RSEMI_ATTR_ANALOG_DEMOD_FILTER_A_WEIGHTED_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1487
#define RSEMI_ATTR_ANALOG_DEMOD_SELECT_TRACE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1488
#define RSEMI_ATTR_ANALOG_DEMOD_RESULT_UNIT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1489
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_VALUE_AM_PPEAK               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1490
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_VALUE_AM_MPEAK               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1491
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_VALUE_AM_MIDDLE              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1492
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_VALUE_AM_RMS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1493
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_VALUE_FM_PPEAK               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1494
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_VALUE_FM_MPEAK               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1495
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_VALUE_FM_MIDDLE              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1496
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_VALUE_FM_RMS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1497
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_VALUE_PM_PPEAK               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1498
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_VALUE_PM_MPEAK               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1499
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_VALUE_PM_MIDDLE              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1500
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_VALUE_PM_RMS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1501
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_REL_VALUE_AM_PPEAK           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1502
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_REL_VALUE_AM_MPEAK           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1503
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_REL_VALUE_AM_MIDDLE          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1504
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_REL_VALUE_AM_RMS             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1505
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_REL_VALUE_FM_PPEAK           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1506
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_REL_VALUE_FM_MPEAK           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1507
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_REL_VALUE_FM_MIDDLE          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1508
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_REL_VALUE_FM_RMS             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1509
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_REL_VALUE_PM_PPEAK           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1510
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_REL_VALUE_PM_MPEAK           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1511
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_REL_VALUE_PM_MIDDLE          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1512
#define RSEMI_ATTR_ANALOG_DEMOD_SUMMARY_RESULT_REL_VALUE_PM_RMS             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1513
#define RSEMI_ATTR_AM_DETECTOR_MEAS_TO_REF_VALUE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1514
#define RSEMI_ATTR_PM_DETECTOR_MEAS_TO_REF_VALUE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1515
#define RSEMI_ATTR_FM_DETECTOR_MEAS_TO_REF_VALUE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1516
#define RSEMI_ATTR_AM_DETECTOR_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1517
#define RSEMI_ATTR_AM_DETECTOR_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1518
#define RSEMI_ATTR_AM_DETECTOR_REF_VALUE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1519
#define RSEMI_ATTR_PM_DETECTOR_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1520
#define RSEMI_ATTR_PM_DETECTOR_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1521
#define RSEMI_ATTR_PM_DETECTOR_REF_VALUE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1522
#define RSEMI_ATTR_FM_DETECTOR_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1523
#define RSEMI_ATTR_FM_DETECTOR_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1524
#define RSEMI_ATTR_FM_DETECTOR_REF_VALUE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1525
#define RSEMI_ATTR_BB_INPUT_BALANCED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1538
#define RSEMI_ATTR_BB_INPUT_SIGNAL_PATH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1539
#define RSEMI_ATTR_BB_FULLSCALE_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1540
#define RSEMI_ATTR_BB_FULLSCALE_LEVEL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1541
#define RSEMI_ATTR_REALTIME_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1
#define RSEMI_ATTR_RECEIVER_IQ_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1741
#define RSEMI_ATTR_SPEM_CENTER_FREQUENCY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 207
#define RSEMI_ATTR_SPEM_SPAN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 208
#define RSEMI_ATTR_SPEM_SPAN_FULL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 209
#define RSEMI_ATTR_SPEM_FREQUENCY_OFFSET                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 210
#define RSEMI_ATTR_SPEM_FREQUENCY_CENTER_LINK                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 211
#define RSEMI_ATTR_SPEM_FREQUENCY_CENTER_LINK_FACTOR                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 212
#define RSEMI_ATTR_SPEM_SWEEP_TIME_AUTO                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 213
#define RSEMI_ATTR_SPEM_SWEEP_TIME                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 214
#define RSEMI_ATTR_SPEM_RESOLUTION_BANDWIDTH_AUTO                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 215
#define RSEMI_ATTR_SPEM_RESOLUTION_BANDWIDTH                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 216
#define RSEMI_ATTR_SPEM_RESOLUTION_BANDWIDTH_RATIO                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 217
#define RSEMI_ATTR_SPEM_RESOLUTION_BANDWIDTH_RATIO_MIN_MAX                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1610
#define RSEMI_ATTR_SPEM_RESOLUTION_BANDWIDTH_RATIO_GET_MIN                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1614
#define RSEMI_ATTR_SPEM_RESOLUTION_BANDWIDTH_RATIO_GET_MAX                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1615
#define RSEMI_ATTR_SPEM_COLOR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define RSEMI_ATTR_SPEM_SHAPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6
#define RSEMI_ATTR_SPEM_COLOR_STYLE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 7
#define RSEMI_ATTR_SPEM_COLOR_LOW                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 8
#define RSEMI_ATTR_SPEM_COLOR_UPPER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define RSEMI_ATTR_SPEM_COLOR_DEFAULT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 10
#define RSEMI_ATTR_SPEM_HDEP                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 11
#define RSEMI_ATTR_SPEM_TIME_STAMP_STATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 12
#define RSEMI_ATTR_SPEM_FRAME_COUNT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 13
#define RSEMI_ATTR_SPEM_FRAME_SELECT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 14
#define RSEMI_ATTR_SPEM_FRAME_SELECT_MIN_MAX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1611
#define RSEMI_ATTR_SPECTROGRAM_FRAME_SELECT_GET_MIN                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1616
#define RSEMI_ATTR_SPECTROGRAM_FRAME_SELECT_GET_MAX                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1617
#define RSEMI_ATTR_SPEM_CONTINUOUS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 15
#define RSEMI_ATTR_SPEM_CLEAR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 16
#define RSEMI_ATTR_SPEM_FFT_WINDOW                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 17
#define RSEMI_ATTR_SPEM_REFERENCE_LEVEL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 218
#define RSEMI_ATTR_SPEM_REFERENCE_LEVEL_OFFSET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 219
#define RSEMI_ATTR_FILE_ITEMS_SAVE_RECAL_SPEM                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 18
#define RSEMI_ATTR_SPEM_NOISE_CORRECTION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 220
#define RSEMI_ATTR_SPEM_DISPLAY_VERTICAL_GRID_MODE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 221
#define RSEMI_ATTR_SPEM_DISPLAY_LOG_RANGE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 222
#define RSEMI_ATTR_SPEM_DISPLAY_ZOOM_STATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 223
#define RSEMI_ATTR_SPEM_LAYOUT_WINDOW_REMOVE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1727
#define RSEMI_ATTR_SPEM_LAYOUT_WINDOW_LIST                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1729
#define RSEMI_ATTR_SPEM_LAYOUT_QUERY_WINDOW_NAME                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1732
#define RSEMI_ATTR_SPEM_TRACE_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 224
#define RSEMI_ATTR_SPEM_TRACE_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 225
#define RSEMI_ATTR_SPEM_TRACE_RESET_BEHAVIOR                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 226
#define RSEMI_ATTR_SPEM_FILE_DEC_SEPARATOR                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 227
#define RSEMI_ATTR_SPEM_MARKER_TO_REFERENCE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 228
#define RSEMI_ATTR_SPEM_MARKER_STEP_SIZE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 229
#define RSEMI_ATTR_SPEM_MARK_FRAME_NUMBER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 20
#define RSEMI_ATTR_SPEM_MARKER_LOCAL_OSCILLATOR_SUPPRESSION                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 233
#define RSEMI_ATTR_SPEM_MARKER_PEAK_EXCURSION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 234
#define RSEMI_ATTR_SPEM_MARKER_THRESHOLD_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 235
#define RSEMI_ATTR_SPEM_MARKER_THRESHOLD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 236
#define RSEMI_ATTR_SPEM_MARKER_TABLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 237
#define RSEMI_ATTR_SPEM_MARKER_SEARCH_XY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 22
#define RSEMI_ATTR_SPEM_MARKER_SEARCH_Y                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 23
#define RSEMI_ATTR_SPEM_MARKER_SEARCH_AREA                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 21
#define RSEMI_ATTR_SPEM_MARKER_SEARCH_XY_MINIMUM                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1183
#define RSEMI_ATTR_SPEM_MARKER_SEARCH_XY_MAXIMUM                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1184
#define RSEMI_ATTR_SPEM_MARKER_SEARCH_Y_MINIMUM                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1185
#define RSEMI_ATTR_SPEM_MARKER_SEARCH_Y_MINIMUM_NEXT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1186
#define RSEMI_ATTR_SPEM_MARKER_SEARCH_Y_MINIMUM_NEXT_BELOW                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1187
#define RSEMI_ATTR_SPEM_MARKER_SEARCH_Y_MINIMUM_NEXT_ABOVE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1188
#define RSEMI_ATTR_SPEM_MARKER_SEARCH_Y_MAXIMUM                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1189
#define RSEMI_ATTR_SPEM_MARKER_SEARCH_Y_MAXIMUM_NEXT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1190
#define RSEMI_ATTR_SPEM_MARKER_SEARCH_Y_MAXIMUM_NEXT_BELOW                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1191
#define RSEMI_ATTR_SPEM_MARKER_SEARCH_Y_MAXIMUM_NEXT_ABOVE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1192
#define RSEMI_ATTR_SPEM_MARKER_SEARCH_Y_TRIGGER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 28
#define RSEMI_ATTR_SPEM_MARKER_SEARCH_LIMITS_ZOOM                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 230
#define RSEMI_ATTR_SPEM_MARKER_SEARCH_PEAK_AUTO                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 231
#define RSEMI_ATTR_SPEM_MARKER_SEARCH_MIN_AUTO                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 232
#define RSEMI_ATTR_SPEM_DMARKER_FRAME_NUMBER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1299
#define RSEMI_ATTR_SPEM_DMARKER_REFERENCE_MARKER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1300
#define RSEMI_ATTR_SPEM_DELTA_MARKER_FRAME_NUMBER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 24
#define RSEMI_ATTR_SPEM_DELTA_MARKER_REFERENCE_MARKER                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 238
#define RSEMI_ATTR_SPEM_DELTA_MARKER_SEARCH_XY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 26
#define RSEMI_ATTR_SPEM_DELTA_MARKER_SEARCH_Y                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 27
#define RSEMI_ATTR_SPEM_DELTA_MARKER_SEARCH_AREA                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 25
#define RSEMI_ATTR_SPEM_DELTA_MARKER_SEARCH_XY_MINIMUM                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1193
#define RSEMI_ATTR_SPEM_DELTA_MARKER_SEARCH_XY_MAXIMUM                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1194
#define RSEMI_ATTR_SPEM_DELTA_MARKER_SEARCH_Y_MINIMUM                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1195
#define RSEMI_ATTR_SPEM_DELTA_MARKER_SEARCH_Y_MINIMUM_NEXT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1196
#define RSEMI_ATTR_SPEM_DELTA_MARKER_SEARCH_Y_MINIMUM_NEXT_BELOW            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1197
#define RSEMI_ATTR_SPEM_DELTA_MARKER_SEARCH_Y_MINIMUM_NEXT_ABOVE            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1198
#define RSEMI_ATTR_SPEM_DELTA_MARKER_SEARCH_Y_MAXIMUM                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1199
#define RSEMI_ATTR_SPEM_DELTA_MARKER_SEARCH_Y_MAXIMUM_NEXT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1200
#define RSEMI_ATTR_SPEM_DELTA_MARKER_SEARCH_Y_MAXIMUM_NEXT_BELOW            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1201
#define RSEMI_ATTR_SPEM_DELTA_MARKER_SEARCH_Y_MAXIMUM_NEXT_ABOVE            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1202
#define RSEMI_ATTR_SPEM_DELTA_MARKER_SEARCH_Y_TRIGGER                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 204
#define RSEMI_ATTR_SPEM_TRIGGER_SOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 239
#define RSEMI_ATTR_SPEM_TRIGGER_DELAY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 240
#define RSEMI_ATTR_SPEM_TRIGGER_SLOPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 241
#define RSEMI_ATTR_SPEM_POST_TRIGGER_TIME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 242
#define RSEMI_ATTR_SPEM_PRE_TRIGGER_TIME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 243
#define RSEMI_ATTR_SPEM_CONTINUOUS_TRIGGER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 19
#define RSEMI_ATTR_SPEM_TIME_DOMAIN_TRIGGER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 60
#define RSEMI_ATTR_SPEM_TIME_DOMAIN_TRIGGER_LEVEL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 61
#define RSEMI_ATTR_SPEM_MASK_TRIGGER_SOURCE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 47
#define RSEMI_ATTR_SPEM_MASK_TRIGGER_NAME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 48
#define RSEMI_ATTR_SPEM_MASK_TRIGGER_COMMENT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 49
#define RSEMI_ATTR_SPEM_MASK_TRIGGER_DIRECTORY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 50
#define RSEMI_ATTR_SPEM_MASK_TRIGGER_DELETE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 51
#define RSEMI_ATTR_SPEM_MASK_TRIGGER_DELETE_SELECTED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1612
#define RSEMI_ATTR_SPEM_MASK_TRIGGER_CONDITION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 52
#define RSEMI_ATTR_SPEM_MASK_TRIGGER_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 53
#define RSEMI_ATTR_SPEM_MASK_SHIFT_LOW_X                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 55
#define RSEMI_ATTR_SPEM_MASK_SHIFT_LOW_Y                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 56
#define RSEMI_ATTR_SPEM_MASK_UPP_AUTO                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 54
#define RSEMI_ATTR_SPEM_MASK_SHIFT_UPP_X                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 57
#define RSEMI_ATTR_SPEM_MASK_SHIFT_UPP_Y                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 58
#define RSEMI_ATTR_SPEM_MASK_LOWER_STATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 244
#define RSEMI_ATTR_SPEM_MASK_UPPER_STATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 245
#define RSEMI_ATTR_SPEM_MASK_SPAN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 246
#define RSEMI_ATTR_PSPEM_GRANULARITY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 31
#define RSEMI_ATTR_PSPEM_SHAPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 32
#define RSEMI_ATTR_PSPEM_TRUN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 33
#define RSEMI_ATTR_PSPEM_MAXH_TRACE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 39
#define RSEMI_ATTR_PSPEM_MAXH_RESET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 41
#define RSEMI_ATTR_PSPEM_COLOR_STYLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 34
#define RSEMI_ATTR_PSPEM_COLOR_DEFAULT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 35
#define RSEMI_ATTR_PSPEM_COLOR_LOWER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 36
#define RSEMI_ATTR_PSPEM_COLOR_UPPER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 37
#define RSEMI_ATTR_PSPEM_STATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 29
#define RSEMI_ATTR_PSPEM_DURATION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 30
#define RSEMI_ATTR_PSPEM_TRACE_STYLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 38
#define RSEMI_ATTR_PSPEM_MAXH_INTENS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 40
#define RSEMI_ATTR_PSPEM_MARKER_POSITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 42
#define RSEMI_ATTR_QUERY_PSPEM_MARKER_Z_AXIS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 43
#define RSEMI_ATTR_PSPEM_DELTA_MARKER_POSITION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 44
#define RSEMI_ATTR_QUERY_PSPEM_DELTA_Z_AXIS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 45
#define RSEMI_ATTR_RESULT_DISPLAY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 46
#define RSEMI_ATTR_SPEM_STORE_TO_FILE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 59
#define RSEMI_ATTR_SPEM_INIT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 247
#define RSEMI_ATTR_SPEM_CONTINUE_MEASUREMENT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 248
#define RSEMI_ATTR_RECEIVER_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 205
#define RSEMI_ATTR_RECEIVER_MEASUREMENT_SEQUENCES                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1550
#define RSEMI_ATTR_INPUT_IMPEDANCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 62
#define RSEMI_ATTR_SWEEP_MODE_CONTINUOUS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 64
#define RSEMI_ATTR_NUMBER_OF_SWEEPS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 65
#define RSEMI_ATTR_QUERY_STARTED_SWEEP_NUMBER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 66
#define RSEMI_ATTR_START_FREQUENCY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 67
#define RSEMI_ATTR_STOP_FREQUENCY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 68
#define RSEMI_ATTR_RECEIVER_FREQUENCY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 69
#define RSEMI_ATTR_FREQUENCY_CENTER_STEP                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 70
#define RSEMI_ATTR_FREQUENCY_CENTER_STEP_AUTO                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1551
#define RSEMI_ATTR_FREQUENCY_CENTER_STEPSIZE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1552
#define RSEMI_ATTR_FREQUENCY_CENTER_STEPSIZE_FACTOR                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1553
#define RSEMI_ATTR_FREQUENCY_CENTER_STEPSIZE_TYPE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1554
#define RSEMI_ATTR_FREQUENCY_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 71
#define RSEMI_ATTR_SCAN_TIME                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 964
#define RSEMI_ATTR_TIME_DOMAIN_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1769
#define RSEMI_ATTR_RECEIVER_SIGNAL_TRACK_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 974
#define RSEMI_ATTR_RECEIVER_SIGNAL_TRACK_BWID                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 975
#define RSEMI_ATTR_RECEIVER_SIGNAL_TRACK_BWID_MIN_MAX                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1625
#define RSEMI_ATTR_RECEIVER_SIGNAL_TRACK_BWID_GET_MIN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1626
#define RSEMI_ATTR_RECEIVER_SIGNAL_TRACK_BWID_GET_MAX                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1627
#define RSEMI_ATTR_RECEIVER_SIGNAL_TRACK_THRESHOLD                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 976
#define RSEMI_ATTR_RECEIVER_SIGNAL_TRACK_TRACE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 977
#define RSEMI_ATTR_POWER_UNIT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 72
#define RSEMI_ATTR_AMP_MINIMUM_LEVEL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1317
#define RSEMI_ATTR_AMP_SCALING_TYPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1318
#define RSEMI_ATTR_AMPLITUDE_MINIMUM_LEVEL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 73
#define RSEMI_ATTR_AMPLITUDE_SCALING_TYPE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 74
#define RSEMI_ATTR_RF_INPUT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 75
#define RSEMI_ATTR_RF_INPUT_COUPLING                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 76
#define RSEMI_ATTR_IF_ANALYSIS_SPAN_COUPLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1673
#define RSEMI_ATTR_IF_ANALYSIS_RESOLUTION_BANDWIDTH                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1621
#define RSEMI_ATTR_RESOLUTION_BANDWIDTH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 77
#define RSEMI_ATTR_RESOLUTION_BANDWIDTH_AUTO                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 78
#define RSEMI_ATTR_RESOLUTION_BANDWIDTH_FILTER_TYPE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 79
#define RSEMI_ATTR_FREQUENCY_SCAN_STEP_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 80
#define RSEMI_ATTR_FREQ_SCAN_AXIS_SCALE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1319
#define RSEMI_ATTR_FREQUENCY_SCAN_AXIS_SCALE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 85
#define RSEMI_ATTR_SCAN_POINTS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 963
#define RSEMI_ATTR_FREQUENCY_SCAN_RANGE_START                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 81
#define RSEMI_ATTR_FREQUENCY_SCAN_RANGE_STOP                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 82
#define RSEMI_ATTR_FREQUENCY_SCAN_STEP_SIZE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 83
#define RSEMI_ATTR_FREQUENCY_SCAN_RANGE_COUNT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 84
#define RSEMI_ATTR_FREQUENCY_SCAN_MEASUREMENT_TIME                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 86
#define RSEMI_ATTR_FREQUENCY_SCAN_MEASUREMENT_TIME_MIN_MAX                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1638
#define RSEMI_ATTR_FREQUENCY_SCAN_MEASUREMENT_TIME_GET_MIN                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1639
#define RSEMI_ATTR_FREQUENCY_SCAN_MEASUREMENT_TIME_GET_MAX                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1640
#define RSEMI_ATTR_FREQUENCY_SCAN_BANDWIDTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 87
#define RSEMI_ATTR_FREQUENCY_SCAN_RF_ATTENUATION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 88
#define RSEMI_ATTR_FREQUENCY_SCAN_AUTO_RANGING_STATE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 89
#define RSEMI_ATTR_FREQUENCY_SCAN_AUTO_PREAMPLIFIER_STATE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 90
#define RSEMI_ATTR_FREQUENCY_SCAN_IF_ATTENUATION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1680
#define RSEMI_ATTR_FREQUENCY_SCAN_IF_AUTO_RANGING_STATE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1681
#define RSEMI_ATTR_FREQUENCY_SCAN_RANGE_PREAMPLIFIER                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 97
#define RSEMI_ATTR_FREQUENCY_SCAN_RANGE_PREAMPLIFIER_GAIN                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1555
#define RSEMI_ATTR_FREQUENCY_SCAN_RANGE_LNA_PREAMPLIFIER                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1682
#define RSEMI_ATTR_FREQUENCY_SCAN_RANGE_LNA_PREAMPLIFIER_AUTO               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1683
#define RSEMI_ATTR_FREQUENCY_SCAN_RANGE_SIGNAL_SOURCE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 91
#define RSEMI_ATTR_SCAN_TRANSMISSION_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 962
#define RSEMI_ATTR_RF_ATTENUATION_LEVEL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 92
#define RSEMI_ATTR_RF_ATTENUATION_PROTECTION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 94
#define RSEMI_ATTR_AUTO_RANGE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 93
#define RSEMI_ATTR_AUTO_PREAMPLIFIER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 95
#define RSEMI_ATTR_PREAMPLIFIER_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 96
#define RSEMI_ATTR_PRESCANNING_LISN_V_NETWORK_HIGH_PASS_FILTER              RS_SPECIFIC_PUBLIC_ATTR_BASE + 98
#define RSEMI_ATTR_PRESCANNING_LISN_V_NETWORK_PHASE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 99
#define RSEMI_ATTR_PRESCANNING_LISN_V_NETWORK_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 100
#define RSEMI_ATTR_MARKER_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 101
#define RSEMI_ATTR_MARKER_TRACE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 102
#define RSEMI_ATTR_MARKER_FREQUENCY_COUPLING                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 103
#define RSEMI_ATTR_MARKER_TO_CENTER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 104
#define RSEMI_ATTR_MARKER_TO_STEP                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 105
#define RSEMI_ATTR_MARKER_ZOOM                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 106
#define RSEMI_ATTR_MARKER_INFO_FIELD_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 107
#define RSEMI_ATTR_MARKER_COUPLING_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 108
#define RSEMI_ATTR_MARKER_USE_LAST_SCAN_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1556
#define RSEMI_ATTR_MARKER_POSITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 120
#define RSEMI_ATTR_MARKER_AOFF                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 121
#define RSEMI_ATTR_MARKER_AMPLITUDE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 122
#define RSEMI_ATTR_MARKER_SEARCH_LIMITS_STATE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 109
#define RSEMI_ATTR_MARKER_SEARCH_LIMITS_LEFT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 110
#define RSEMI_ATTR_MARKER_SEARCH_LIMITS_RIGHT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 111
#define RSEMI_ATTR_MARKER_SEARCH_PEAK                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 112
#define RSEMI_ATTR_MARKER_SEARCH_PEAK_NEXT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 113
#define RSEMI_ATTR_MARKER_SEARCH_PEAK_RIGHT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 114
#define RSEMI_ATTR_MARKER_SEARCH_PEAK_LEFT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 115
#define RSEMI_ATTR_MARKER_SEARCH_MIN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 116
#define RSEMI_ATTR_MARKER_SEARCH_MIN_NEXT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 117
#define RSEMI_ATTR_MARKER_SEARCH_MIN_RIGHT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 118
#define RSEMI_ATTR_MARKER_SEARCH_MIN_LEFT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 119
#define RSEMI_ATTR_DMARKER_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1301
#define RSEMI_ATTR_DMARKER_TRACE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1302
#define RSEMI_ATTR_DMARKER_AOFF                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1303
#define RSEMI_ATTR_DMARKER_LINK                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1304
#define RSEMI_ATTR_DMARKER_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1305
#define RSEMI_ATTR_DMARKER_POSITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1306
#define RSEMI_ATTR_DMARKER_REL_POSITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1307
#define RSEMI_ATTR_DMARKER_AMPLITUDE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1308
#define RSEMI_ATTR_DELTA_MARKER_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 123
#define RSEMI_ATTR_DELTA_MARKER_TRACE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 124
#define RSEMI_ATTR_DELTA_MARKER_AOFF                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 125
#define RSEMI_ATTR_MARKER_LINK                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 126
#define RSEMI_ATTR_DELTA_MARKER_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 135
#define RSEMI_ATTR_DELTA_MARKER_POSITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 136
#define RSEMI_ATTR_DELTA_MARKER_REL_POSITION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 137
#define RSEMI_ATTR_DELTA_MARKER_AMPLITUDE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 138
#define RSEMI_ATTR_DMARKER_PEAK                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1309
#define RSEMI_ATTR_DMARKER_PEAK_NEXT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1310
#define RSEMI_ATTR_DMARKER_PEAK_NEXT_LEFT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1311
#define RSEMI_ATTR_DMARKER_PEAK_NEXT_RIGHT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1312
#define RSEMI_ATTR_DMARKER_MIN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1313
#define RSEMI_ATTR_DMARKER_MIN_NEXT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1314
#define RSEMI_ATTR_DMARKER_MIN_NEXT_RIGHT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1315
#define RSEMI_ATTR_DMARKER_MIN_NEXT_LEFT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1316
#define RSEMI_ATTR_DELTA_MARKER_PEAK                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 127
#define RSEMI_ATTR_DELTA_MARKER_PEAK_NEXT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 128
#define RSEMI_ATTR_DELTA_MARKER_PEAK_NEXT_LEFT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 129
#define RSEMI_ATTR_DELTA_MARKER_PEAK_NEXT_RIGHT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 130
#define RSEMI_ATTR_DELTA_MARKER_MIN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 131
#define RSEMI_ATTR_DELTA_MARKER_MIN_NEXT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 132
#define RSEMI_ATTR_DELTA_MARKER_MIN_NEXT_RIGHT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 133
#define RSEMI_ATTR_DELTA_MARKER_MIN_NEXT_LEFT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 134
#define RSEMI_ATTR_BARGRAPH_MAXHOLD_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 139
#define RSEMI_ATTR_BARGRAPH_MAXHOLD_RESET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 140
#define RSEMI_ATTR_BARGRAPH_LEVEL_MINIMUM                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1203
#define RSEMI_ATTR_BARGRAPH_LEVEL_MAXIMUM                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1204
#define RSEMI_ATTR_BARGRAPH_MEASUREMENT_TIME                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 142
#define RSEMI_ATTR_BARGRAPH_COUPLING                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 978
#define RSEMI_ATTR_BARGRAPH_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 141
#define RSEMI_ATTR_TIME_LINE_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 965
#define RSEMI_ATTR_TIME_LINE_POSITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 966
#define RSEMI_ATTR_DISPLAY_LINE_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 144
#define RSEMI_ATTR_DISPLAY_LINE_POSITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 145
#define RSEMI_ATTR_FREQUENCY_LINE_STATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 146
#define RSEMI_ATTR_FREQUENCY_LINE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 147
#define RSEMI_ATTR_LIMIT_NAME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 148
#define RSEMI_ATTR_LIMIT_CONTROL_DOMAIN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 149
#define RSEMI_ATTR_LIMIT_COMMENT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 150
#define RSEMI_ATTR_LIMIT_ASSIGN_TRACE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 151
#define RSEMI_ATTR_LIMIT_DELETE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 152
#define RSEMI_ATTR_LIMIT_COPY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 153
#define RSEMI_ATTR_LIMIT_UNIT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 154
#define RSEMI_ATTR_LIMIT_LINE_SCALING_X                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1205
#define RSEMI_ATTR_LIMIT_LINE_SCALING_LOWER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1206
#define RSEMI_ATTR_LIMIT_LINE_SCALING_UPPER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1207
#define RSEMI_ATTR_LIMIT_LINE_MARGIN_LOWER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1208
#define RSEMI_ATTR_LIMIT_LINE_MARGIN_UPPER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1209
#define RSEMI_ATTR_LIMIT_LINE_OFFSET_X                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1210
#define RSEMI_ATTR_LIMIT_LINE_OFFSET_LOWER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1211
#define RSEMI_ATTR_LIMIT_LINE_OFFSET_UPPER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1212
#define RSEMI_ATTR_LIMIT_LINE_SHIFT_X                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1213
#define RSEMI_ATTR_LIMIT_LINE_SHIFT_LOWER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1214
#define RSEMI_ATTR_LIMIT_LINE_SHIFT_UPPER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1215
#define RSEMI_ATTR_LIMIT_LINE_SPACING_X                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1216
#define RSEMI_ATTR_LIMIT_LINE_SPACING_LOWER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1217
#define RSEMI_ATTR_LIMIT_LINE_SPACING_UPPER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1218
#define RSEMI_ATTR_LIMIT_LINE_VISIBILITY_LOWER                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1219
#define RSEMI_ATTR_LIMIT_LINE_VISIBILITY_UPPER                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1220
#define RSEMI_ATTR_LIMIT_LINE_THRESHOLD_LOWER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1221
#define RSEMI_ATTR_LIMIT_LINE_THRESHOLD_UPPER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1222
#define RSEMI_ATTR_LIMIT_LINE_SCALING                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 155
#define RSEMI_ATTR_LIMIT_LINE_MARGIN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 156
#define RSEMI_ATTR_LIMIT_LINE_OFFSET                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 157
#define RSEMI_ATTR_LIMIT_LINE_SHIFT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 158
#define RSEMI_ATTR_LIMIT_LINE_SPACING                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 159
#define RSEMI_ATTR_LIMIT_LINE_VISIBILITY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 160
#define RSEMI_ATTR_LIMIT_LINE_THRESHOLD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 161
#define RSEMI_ATTR_LIMIT_LINE_CHECK_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 162
#define RSEMI_ATTR_CLEAR_LIMIT_LINE_CHECK_RESULT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 163
#define RSEMI_ATTR_QUERY_LIMIT_LINE_CHECK_RESULT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 164
#define RSEMI_ATTR_LIMIT_LINE_TRACE_CHECK_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1558
#define RSEMI_ATTR_BARGRAPH_TRACE_MODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 143
#define RSEMI_ATTR_RECEIVER_LAYOUT_WINDOW_REMOVE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1735
#define RSEMI_ATTR_RECEIVER_LAYOUT_WINDOW_LIST                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1737
#define RSEMI_ATTR_RECEIVER_LAYOUT_QUERY_WINDOW_NAME                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1740
#define RSEMI_ATTR_ANALOG_DEMODULATION_STATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 165
#define RSEMI_ATTR_ANALOG_DEMODULATION_SQUELCH_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 166
#define RSEMI_ATTR_ANALOG_DEMODULATION_SQUELCH_LEVEL                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 167
#define RSEMI_ATTR_SGRAM_STATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1559
#define RSEMI_ATTR_SGRAM_CLEAR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1268
#define RSEMI_ATTR_SGRAM_SELECT_FRAME                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1269
#define RSEMI_ATTR_SGRAM_FRAMES_IN_MEMORY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1270
#define RSEMI_ATTR_SGRAM_LAYOUT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1691
#define RSEMI_ATTR_SPECTROGRAM_TRACE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 982
#define RSEMI_ATTR_SGRAM_TIME_STAMP                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1271
#define RSEMI_ATTR_SPECTROGRAM_CLEAR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 979
#define RSEMI_ATTR_SPECTROGRAM_SELECT_FRAME                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 980
#define RSEMI_ATTR_SPECTROGRAM_FRAMES_IN_MEMORY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 981
#define RSEMI_ATTR_SPECTROGRAM_TIME_STAMP                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 983
#define RSEMI_ATTR_SPECTROGRAM_COLOR_DEFAULT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 985
#define RSEMI_ATTR_SGRAM_COLOR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1272
#define RSEMI_ATTR_SPECTROGRAM_COLOR_STYLE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 987
#define RSEMI_ATTR_SPECTROGRAM_COLOR_SHAPE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 988
#define RSEMI_ATTR_SPECTROGRAM_COLOR_LOWER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 989
#define RSEMI_ATTR_SPECTROGRAM_COLOR_UPPER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 990
#define RSEMI_ATTR_SPECTROGRAM_COLOR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 986
#define RSEMI_ATTR_SGRAM_MARKER_FRAME                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1273
#define RSEMI_ATTR_SGRAM_MARKER_FRAME_TIME                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1274
#define RSEMI_ATTR_SGRAM_MARKER_SEARCH_AREA                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1275
#define RSEMI_ATTR_SGRAM_MARKER_MAXIMUM_LEVEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1276
#define RSEMI_ATTR_SGRAM_MARKER_MINIMUM_LEVEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1277
#define RSEMI_ATTR_SGRAM_MARKER_Y_NEXT_PEAK_ABOVE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1278
#define RSEMI_ATTR_SGRAM_MARKER_Y_NEXT_PEAK_BELOW                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1279
#define RSEMI_ATTR_SGRAM_MARKER_Y_NEXT_PEAK                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1280
#define RSEMI_ATTR_SGRAM_MARKER_Y_PEAK                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1281
#define RSEMI_ATTR_SGRAM_MARKER_Y_NEXT_MINIMUM_ABOVE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1282
#define RSEMI_ATTR_SGRAM_MARKER_Y_NEXT_MINIMUM_BELOW                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1283
#define RSEMI_ATTR_SGRAM_MARKER_Y_NEXT_MINIMUM                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1284
#define RSEMI_ATTR_SGRAM_MARKER_Y_MINIMUM                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1285
#define RSEMI_ATTR_SPECTROGRAM_MARKER_FRAME                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 991
#define RSEMI_ATTR_SPECTROGRAM_MARKER_FRAME_TIME                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 992
#define RSEMI_ATTR_SPECTROGRAM_MARKER_SEARCH_AREA                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 993
#define RSEMI_ATTR_SPECTROGRAM_MARKER_MAXIMUM_LEVEL                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 994
#define RSEMI_ATTR_SPECTROGRAM_MARKER_MINIMUM_LEVEL                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 995
#define RSEMI_ATTR_SPECTROGRAM_MARKER_Y_NEXT_PEAK_ABOVE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 996
#define RSEMI_ATTR_SPECTROGRAM_MARKER_Y_NEXT_PEAK_BELOW                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 997
#define RSEMI_ATTR_SPECTROGRAM_MARKER_Y_NEXT_PEAK                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 998
#define RSEMI_ATTR_SPECTROGRAM_MARKER_Y_PEAK                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 999
#define RSEMI_ATTR_SPECTROGRAM_MARKER_Y_NEXT_MINIMUM_ABOVE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1000
#define RSEMI_ATTR_SPECTROGRAM_MARKER_Y_NEXT_MINIMUM_BELOW                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1001
#define RSEMI_ATTR_SPECTROGRAM_MARKER_Y_NEXT_MINIMUM                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1002
#define RSEMI_ATTR_SPECTROGRAM_MARKER_Y_MINIMUM                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1003
#define RSEMI_ATTR_SGRAM_DELTA_MARKER_FRAME                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1286
#define RSEMI_ATTR_SGRAM_DELTA_MARKER_FRAME_TIME                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1287
#define RSEMI_ATTR_SGRAM_DELTA_MARKER_SEARCH_AREA                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1288
#define RSEMI_ATTR_SGRAM_DELTA_MARKER_MAXIMUM_LEVEL                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1289
#define RSEMI_ATTR_SGRAM_DELTA_MARKER_MINIMUM_LEVEL                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1290
#define RSEMI_ATTR_SGRAM_DELTA_MARKER_Y_NEXT_PEAK_ABOVE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1291
#define RSEMI_ATTR_SGRAM_DELTA_MARKER_Y_NEXT_PEAK_BELOW                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1292
#define RSEMI_ATTR_SGRAM_DELTA_MARKER_Y_NEXT_PEAK                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1293
#define RSEMI_ATTR_SGRAM_DELTA_MARKER_Y_PEAK                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1294
#define RSEMI_ATTR_SGRAM_DELTA_MARKER_Y_NEXT_MINIMUM_ABOVE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1295
#define RSEMI_ATTR_SGRAM_DELTA_MARKER_Y_NEXT_MINIMUM_BELOW                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1296
#define RSEMI_ATTR_SGRAM_DELTA_MARKER_Y_NEXT_MINIMUM                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1297
#define RSEMI_ATTR_SGRAM_DELTA_MARKER_Y_MINIMUM                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1298
#define RSEMI_ATTR_SPECTROGRAM_DELTA_MARKER_FRAME                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1004
#define RSEMI_ATTR_SPECTROGRAM_DELTA_MARKER_FRAME_TIME                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1005
#define RSEMI_ATTR_SPECTROGRAM_DELTA_MARKER_SEARCH_AREA                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1006
#define RSEMI_ATTR_SPECTROGRAM_DELTA_MARKER_MAXIMUM_LEVEL                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1007
#define RSEMI_ATTR_SPECTROGRAM_DELTA_MARKER_MINIMUM_LEVEL                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1008
#define RSEMI_ATTR_SPECTROGRAM_DELTA_MARKER_Y_NEXT_PEAK_ABOVE               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1009
#define RSEMI_ATTR_SPECTROGRAM_DELTA_MARKER_Y_NEXT_PEAK_BELOW               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1010
#define RSEMI_ATTR_SPECTROGRAM_DELTA_MARKER_Y_NEXT_PEAK                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1011
#define RSEMI_ATTR_SPECTROGRAM_DELTA_MARKER_Y_PEAK                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1012
#define RSEMI_ATTR_SPECTROGRAM_DELTA_MARKER_Y_NEXT_MINIMUM_ABOVE            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1013
#define RSEMI_ATTR_SPECTROGRAM_DELTA_MARKER_Y_NEXT_MINIMUM_BELOW            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1014
#define RSEMI_ATTR_SPECTROGRAM_DELTA_MARKER_Y_NEXT_MINIMUM                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1015
#define RSEMI_ATTR_SPECTROGRAM_DELTA_MARKER_Y_MINIMUM                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1016
#define RSEMI_ATTR_TRACE_DETECTOR_SELECTION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 63
#define RSEMI_ATTR_RECEIVER_TRIGGER_OFFSET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1560
#define RSEMI_ATTR_RECEIVER_TRIGGER_RFP_LEVEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1561
#define RSEMI_ATTR_RECEIVER_TRIGGER_IFP_LEVEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1562
#define RSEMI_ATTR_RECEIVER_TRIGGER_IFP_HOLDOFF                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1563
#define RSEMI_ATTR_RECEIVER_TRIGGER_IFP_HYSTERESIS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1564
#define RSEMI_ATTR_RECEIVER_TRIGGER_TIME_INTERVAL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1565
#define RSEMI_ATTR_PEAK_SEARCH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 961
#define RSEMI_ATTR_PEAK_SEARCH_EXCURSION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 168
#define RSEMI_ATTR_PEAK_SEARCH_MARGIN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 169
#define RSEMI_ATTR_PEAK_SEARCH_FREQUENCY_ADD                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 170
#define RSEMI_ATTR_PEAK_SEARCH_LIST_METHOD                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 171
#define RSEMI_ATTR_PEAK_SEARCH_LIST_VALUE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 172
#define RSEMI_ATTR_PEAK_SEARCH_NUMBER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 173
#define RSEMI_ATTR_CLEAR_PEAK_SEARCH_LIST                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 174
#define RSEMI_ATTR_PEAK_LIST_FILE_NAME                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 176
#define RSEMI_ATTR_PEAK_LIST_NUMBER_OF_PEAKS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1759
#define RSEMI_ATTR_PEAK_LIST_PEAK_FREQUENCY                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1760
#define RSEMI_ATTR_PEAK_LIST_PEAK_LEVEL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1761
#define RSEMI_ATTR_PEAK_LIST_PEAK_DETECTOR                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1762
#define RSEMI_ATTR_PEAK_LIST_PEAK_DELTA                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1763
#define RSEMI_ATTR_PEAK_LIST_PEAK_TRACE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1764
#define RSEMI_ATTR_PEAK_LIST_PEAK_COMMENT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1765
#define RSEMI_ATTR_PEAK_LIST_PEAK_DELETE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1766
#define RSEMI_ATTR_PEAK_LIST_DISPLAY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 175
#define RSEMI_ATTR_FINAL_MEASUREMENT_AUTO                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 178
#define RSEMI_ATTR_FINAL_MEASUREMENT_AUTOMATIC                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1720
#define RSEMI_ATTR_FINAL_MEASUREMENT_TIME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 179
#define RSEMI_ATTR_FINAL_MEASUREMENT_FILE_NAME                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 180
#define RSEMI_ATTR_FINAL_MEASUREMENT_NUMBER_OF_PEAKS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1770
#define RSEMI_ATTR_FINAL_MEASUREMENT_PEAK_FREQUENCY                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1771
#define RSEMI_ATTR_FINAL_MEASUREMENT_PEAK_LEVEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1772
#define RSEMI_ATTR_FINAL_MEASUREMENT_PEAK_DETECTOR                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1773
#define RSEMI_ATTR_FINAL_MEASUREMENT_PEAK_DELTA                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1774
#define RSEMI_ATTR_FINAL_MEASUREMENT_PEAK_TRACE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1775
#define RSEMI_ATTR_FINAL_MEASUREMENT_PEAK_COMMENT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1776
#define RSEMI_ATTR_FINAL_MEASUREMENT_DETECTOR                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 177
#define RSEMI_ATTR_EMI_TEST_INITIATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 183
#define RSEMI_ATTR_EMI_FINAL_MEASUREMENT_INITIATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 184
#define RSEMI_ATTR_INITIATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 185
#define RSEMI_ATTR_INITIATE_WITHOUT_OPC                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 206
#define RSEMI_ATTR_HOLD                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 186
#define RSEMI_ATTR_CONTINUE_MEASUREMENT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 187
#define RSEMI_ATTR_ABORT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 188
#define RSEMI_ATTR_EXT_GEN_INTERFACE_TYPE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1567
#define RSEMI_ATTR_EXT_GEN_IEEE_ADDR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1568
#define RSEMI_ATTR_EXT_GEN_INTF_TYPE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1569
#define RSEMI_ATTR_EXT_GEN_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1570
#define RSEMI_ATTR_EXT_GEN_ROSC_SOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1571
#define RSEMI_ATTR_TRACKING_GENERATOR_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1641
#define RSEMI_ATTR_TRACKING_GENERATOR_MEASUREMENT_TYPE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1642
#define RSEMI_ATTR_TRACKING_GENERATOR_CALIBRATION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1643
#define RSEMI_ATTR_TRACKING_GENERATOR_RESTORE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1644
#define RSEMI_ATTR_TRACKING_GENERATOR_NORMALIZATION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1645
#define RSEMI_ATTR_TRACKING_GENERATOR_MODULATION_AM                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1646
#define RSEMI_ATTR_TRACKING_GENERATOR_MODULATION_IQ                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1647
#define RSEMI_ATTR_TRACKING_GENERATOR_MODULATION_FM                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1648
#define RSEMI_ATTR_TRACKING_GENERATOR_MODULATION_FM_DEVIATION               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1649
#define RSEMI_ATTR_TRACKING_GENERATOR_MODULATION_FREQUENCY_OFFSET           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1650
#define RSEMI_ATTR_TRACKING_GENERATOR_MODULATION_OUTPUT_LEVEL               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1651
#define RSEMI_ATTR_TRACKING_GENERATOR_MODULATION_LEVEL_OFFSET               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1652
#define RSEMI_ATTR_TRACKING_GENERATOR_POWER_MODE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1653
#define RSEMI_ATTR_TRACKING_GENERATOR_POWER_START                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1654
#define RSEMI_ATTR_TRACKING_GENERATOR_POWER_STOP                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1655
#define RSEMI_ATTR_TRAN_SEL_NAME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1240
#define RSEMI_ATTR_TRAN_UNIT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1241
#define RSEMI_ATTR_TRAN_SCALING                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1242
#define RSEMI_ATTR_TRAN_COMMENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1243
#define RSEMI_ATTR_TRAN_STATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1244
#define RSEMI_ATTR_TRAN_CATALOG                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1572
#define RSEMI_ATTR_TRAN_DELETE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1245
#define RSEMI_ATTR_TRAN_DISPLAY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1246
#define RSEMI_ATTR_TRAN_ADJ_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1247
#define RSEMI_ATTR_TRAN_ACT_NAME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1248
#define RSEMI_ATTR_TFAC_GEN_NAME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 319
#define RSEMI_ATTR_TFAC_SEL_NAME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 320
#define RSEMI_ATTR_TFAC_UNIT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 321
#define RSEMI_ATTR_TFAC_SCALING                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 322
#define RSEMI_ATTR_TFAC_COMMENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 323
#define RSEMI_ATTR_TFAC_STATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 324
#define RSEMI_ATTR_TFAC_DELETE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 325
#define RSEMI_ATTR_TFAC_DISPLAY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 326
#define RSEMI_ATTR_TFAC_ADJ_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 327
#define RSEMI_ATTR_TFAC_ACT_NAME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 329
#define RSEMI_ATTR_TSET_SELECT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 967
#define RSEMI_ATTR_TSET_STATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 968
#define RSEMI_ATTR_TSET_COMMENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 969
#define RSEMI_ATTR_TSET_UNIT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 970
#define RSEMI_ATTR_TSET_BREAK                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 971
#define RSEMI_ATTR_TSET_DELETE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 972
#define RSEMI_ATTR_TSET_CATALOG                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1224
#define RSEMI_ATTR_TSET_ACTIVE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 973
#define RSEMI_ATTR_RF_SWITCH_NETWORK_ADDRESS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1692
#define RSEMI_ATTR_RF_SWITCH_COMMENT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1693
#define RSEMI_ATTR_RF_SWITCH_COMMAND                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1695
#define RSEMI_ATTR_RF_SWITCH_COMMAND_EXECUTE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1696
#define RSEMI_ATTR_RF_SWITCH_NAME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1697
#define RSEMI_ATTR_RF_SWITCH_INPUT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1698
#define RSEMI_ATTR_RF_SWITCH_DELETE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1699
#define RSEMI_ATTR_RF_SWITCH_LOAD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1700
#define RSEMI_ATTR_RF_SWITCH_OPC                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1702
#define RSEMI_ATTR_RF_SWITCH_SCPI                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1703
#define RSEMI_ATTR_RF_SWITCH_SELECT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1704
#define RSEMI_ATTR_RF_SWITCH_STORE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1706
#define RSEMI_ATTR_RF_SWITCH_DELAY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1708
#define RSEMI_ATTR_RF_SWITCH_RANGE_COMMAND                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1722
#define RSEMI_ATTR_RF_SWITCH_RANGE_COMMAND_EXECUTE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1723
#define RSEMI_ATTR_TRAN_INPUT_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1709
#define RSEMI_ATTR_TRAN_INPUT_ACT_NAME                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1710
#define RSEMI_ATTR_TSET_INPUT_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1711
#define RSEMI_ATTR_TSET_INPUT_ACTIVE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1712
#define RSEMI_ATTR_FILE_RECALL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 650
#define RSEMI_ATTR_FILE_STARTUP_RECALL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 651
#define RSEMI_ATTR_FILE_SAVE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 652
#define RSEMI_ATTR_FILE_SAVE_NEXT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 653
#define RSEMI_ATTR_FILE_DATA_CLEAR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 654
#define RSEMI_ATTR_FILE_DATA_CLEAR_ALL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 655
#define RSEMI_ATTR_FILE_EDIT_COMM                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 656
#define RSEMI_ATTR_FILE_DEC_SEPARATOR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 657
#define RSEMI_ATTR_FILE_MANAGER_EDIT_PATH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 658
#define RSEMI_ATTR_FILE_MANAGER_DELETE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 659
#define RSEMI_ATTR_FILE_MANAGER_MAKE_DIR                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 661
#define RSEMI_ATTR_FILE_MANAGER_EDIT_PATH_DEVICE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 662
#define RSEMI_ATTR_FILE_MANAGER_DELETE_DIR                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 663
#define RSEMI_ATTR_FILE_MANAGER_DELETE_IMMEDIATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 664
#define RSEMI_ATTR_FILE_ITEMS_SAVE_RECAL_SEL_TRAN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 666
#define RSEMI_ATTR_FILE_ITEMS_SAVE_RECAL_SEL_HWSETTINGS                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 667
#define RSEMI_ATTR_FILE_ITEMS_SAVE_RECAL_SEL_TRAC                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 668
#define RSEMI_ATTR_FILE_ITEMS_SAVE_RECAL_SEL_LINE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 669
#define RSEMI_ATTR_FILE_ITEMS_SAVE_RECAL_ALL                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 670
#define RSEMI_ATTR_FILE_ITEMS_SAVE_RECAL_NONE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 671
#define RSEMI_ATTR_FILE_ITEMS_SAVE_RECAL_DEFAULT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 672
#define RSEMI_ATTR_DATA_SET_STORE_MODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1575
#define RSEMI_ATTR_NETWORK_DISCONNECT_DRIVE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 684
#define RSEMI_ATTR_UNUSED_NETWORK_DRIVES                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 685
#define RSEMI_ATTR_USED_NETWORK_DRIVES                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 686
#define RSEMI_ATTR_HCOPY_ABORT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 632
#define RSEMI_ATTR_HCOPY_DEVICE_LANG_OUT_FORM                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 639
#define RSEMI_ATTR_HCOPY_OUTPUT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1026
#define RSEMI_ATTR_HCOPY_PRINT_SCREEN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 640
#define RSEMI_ATTR_HCOPY_PRINT_TABLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1320
#define RSEMI_ATTR_HCOPY_PRINT_TAB                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 641
#define RSEMI_ATTR_HCOPY_COMM_SCREEN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1226
#define RSEMI_ATTR_HCOPY_COMM_SCR                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 642
#define RSEMI_ATTR_HCOPY_PRINT_TRACE_STATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1227
#define RSEMI_ATTR_HCOPY_PRINT_TRACE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 643
#define RSEMI_ATTR_HCOPY_FILE_NAME                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 645
#define RSEMI_ATTR_HCOPY_PRINTER_NEXT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 647
#define RSEMI_ATTR_HCOPY_PRINTER_FIRST                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 648
#define RSEMI_ATTR_HCOPY_PRINT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 635
#define RSEMI_ATTR_HCOPY_PRINT_NEXT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 636
#define RSEMI_ATTR_HCOPY_DEVICE_DESTINATION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 637
#define RSEMI_ATTR_HCOPY_DEVICE_ORIENTATION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 644
#define RSEMI_ATTR_HCOPY_PRINTER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 646
#define RSEMI_ATTR_HCOPY_TIME_DATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 649
#define RSEMI_ATTR_HCOPY_COLOR_DEF                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 633
#define RSEMI_ATTR_HCOPY_COLOR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 634
#define RSEMI_ATTR_HCOPY_COLOR_PREDEFINED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 638
#define RSEMI_ATTR_INPUT_UPORT_STATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1229
#define RSEMI_ATTR_INP_UPORT_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 369
#define RSEMI_ATTR_INPUT_UPORT_VALUE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1230
#define RSEMI_ATTR_INP_UPORT_VALUE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 370
#define RSEMI_ATTR_OUT_UPORT_VALUE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 371
#define RSEMI_ATTR_SERVICE_INP_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1231
#define RSEMI_ATTR_SERVICE_INPUT_SOURCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 688
#define RSEMI_ATTR_SERVICE_INPUT_PULSED_STATE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 690
#define RSEMI_ATTR_SERVICE_CAL_FREQ_RF_SPECTRUM                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1234
#define RSEMI_ATTR_SERVICE_CAL_FREQ_MW_DIST                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1235
#define RSEMI_ATTR_SERVICE_CAL_FREQ_MW                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1236
#define RSEMI_ATTR_SERVICE_CAL_AUTO_POWER_REDUCTION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1713
#define RSEMI_ATTR_SERVICE_CAL_KIT_ADDITIONAL_DIRECTORY                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1714
#define RSEMI_ATTR_SERVICE_INPUT_COMB_FREQUENCY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 694
#define RSEMI_ATTR_SERVICE_NOISE_SOURCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 696
#define RSEMI_ATTR_SERVICE_PULSE_CAL_FREQ                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 700
#define RSEMI_ATTR_SERVICE_CAL_FREQ_MICROWAVE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1715
#define RSEMI_ATTR_SERVICE_HW_INFO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 701
#define RSEMI_ATTR_SERVICE_VERSION_INFO                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1579
#define RSEMI_ATTR_TEST_REPORT_NEW                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1027
#define RSEMI_ATTR_TEST_REPORT_DATASET_ADD                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1028
#define RSEMI_ATTR_TEST_REPORT_DATASET_REMOVE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1029
#define RSEMI_ATTR_TEST_REPORT_DATASET_REMOVE_ALL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1030
#define RSEMI_ATTR_TEST_REPORT_DEFAULT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1035
#define RSEMI_ATTR_TEST_REPORT_TITLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1037
#define RSEMI_ATTR_TEST_REPORT_TITLE_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1754
#define RSEMI_ATTR_TEST_REPORT_DESCRIPTION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1038
#define RSEMI_ATTR_TEST_REPORT_PAGE_SIZE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1039
#define RSEMI_ATTR_TEST_REPORT_SHOW_PAGE_COUNT_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1755
#define RSEMI_ATTR_TEST_REPORT_PRINTER_FRIENDLY_COLOURS_ENABLED             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1756
#define RSEMI_ATTR_TEST_REPORT_TIME_STAMP_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1757
#define RSEMI_ATTR_TEST_REPORT_HEADER_STATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1758
#define RSEMI_ATTR_TEST_REPORT_HEADER_CONTROL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1040
#define RSEMI_ATTR_TEST_REPORT_HEADER_TEXT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1041
#define RSEMI_ATTR_TEST_REPORT_HEADER_TITLE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1042
#define RSEMI_ATTR_TEST_REPORT_LOGO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1043
#define RSEMI_ATTR_TEST_REPORT_LOGO_CONTROL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1044
#define RSEMI_ATTR_TEST_REPORT_TEMPLATE_LOAD                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1045
#define RSEMI_ATTR_TEST_REPORT_TEMPLATE_SAVE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1046
#define RSEMI_ATTR_TEST_REPORT_TEMPLATE_DELETE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1047
#define RSEMI_ATTR_TEST_REPORT_TEMPLATE_CATALOG                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1605
#define RSEMI_ATTR_ID_QUERY_RESPONSE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 195
#define RSEMI_ATTR_SYSTEM_VERSION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 189
#define RSEMI_ATTR_SERVICE_STEST                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 190
#define RSEMI_ATTR_SERVICE_STEST_RESULTS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 191
#define RSEMI_ATTR_SYSTEM_ERROR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 192
#define RSEMI_ATTR_SYST_ERR_LIST                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 958
#define RSEMI_ATTR_SYST_ERR_CLEAR                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 959
#define RSEMI_ATTR_SYST_ERR_CLEAR_REMOTE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1724
#define RSEMI_ATTR_SYST_DISPLAY_REMOTE_ERRORS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1716
#define RSEMI_ATTR_SYSTEM_PRESET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 194
#define RSEMI_ATTR_SYSTEM_PRESET_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1609
#define RSEMI_ATTR_PRESET_STATUS_REGISTERS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 249
#define RSEMI_ATTR_CALIBRATION_AUTO_AVERAGING                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1717
#define RSEMI_ATTR_QUESTIONABLE_REGISTER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 250
#define RSEMI_ATTR_OPERATION_REGISTER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 251
#define RSEMI_ATTR_QUERY_OPC                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1742
#define RSEMI_ATTR_PROCESS_ALL_PREVIOUS_COMMANDS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1744

// rsemi_rngInputImpedance
#define RSEMI_VAL_INPUT_IMPEDANCE_50                                        0
#define RSEMI_VAL_INPUT_IMPEDANCE_75                                        1

// rsemi_rngTraceDetectorSelection
#define RSEMI_VAL_DETECTOR_NEGATIVE                                         0
#define RSEMI_VAL_DETECTOR_POSITIVE                                         1
#define RSEMI_VAL_DETECTOR_RMS                                              2
#define RSEMI_VAL_DETECTOR_AVERAGE                                          3
#define RSEMI_VAL_DETECTOR_QPEAK                                            4
#define RSEMI_VAL_DETECTOR_CAVERAGE                                         5
#define RSEMI_VAL_DETECTOR_CRMS                                             6
#define RSEMI_VAL_DETECTOR_ACPULSE                                          7
#define RSEMI_VAL_DETECTOR_ACSINE                                           8
#define RSEMI_VAL_DETECTOR_NONE                                             9

// rsemi_rngFrequencyMode
#define RSEMI_VAL_FREQUENCY_MODE_SCAN                                       0
#define RSEMI_VAL_FREQUENCY_MODE_TDOM                                       1
#define RSEMI_VAL_FREQUENCY_MODE_FIX                                        2

// rsemi_rngPowerUnit
#define RSEMI_VAL_UNIT_DBM                                                  0
#define RSEMI_VAL_UNIT_VOLT                                                 1
#define RSEMI_VAL_UNIT_AMP                                                  2
#define RSEMI_VAL_UNIT_WATT                                                 3
#define RSEMI_VAL_UNIT_DBPW                                                 4
#define RSEMI_VAL_UNIT_DBUV                                                 5
#define RSEMI_VAL_UNIT_DBMV                                                 6
#define RSEMI_VAL_UNIT_DBUA                                                 7
#define RSEMI_VAL_UNIT_DBPT                                                 8
#define RSEMI_VAL_UNIT_DBUV_M                                               9
#define RSEMI_VAL_UNIT_DBUA_M                                               10

// rsemi_rngAmplitudeScalingType
#define RSEMI_VAL_VERTICAL_SCALING_LOGARITHMIC                              0
#define RSEMI_VAL_VERTICAL_SCALING_LINEAR                                   1
#define RSEMI_VAL_VERTICAL_SCALING_LDB                                      2

// rsemi_rngRFInput
#define RSEMI_VAL_SOURCE_RF_INPUT1                                          1
#define RSEMI_VAL_SOURCE_RF_INPUT2                                          2

// rsemi_rngRFInputCoupling
#define RSEMI_VAL_COUPLING_AC                                               0
#define RSEMI_VAL_COUPLING_DC                                               1

// rsemi_rngResolutionBandwidthFilterType
#define RSEMI_VAL_FILTER_TYPE_NORMAL                                        0
#define RSEMI_VAL_FILTER_TYPE_CFILTER                                       1
#define RSEMI_VAL_FILTER_TYPE_RRC                                           2
#define RSEMI_VAL_FILTER_TYPE_P5                                            3
#define RSEMI_VAL_FILTER_TYPE_CISPR                                         4
#define RSEMI_VAL_FILTER_TYPE_MIL                                           5
#define RSEMI_VAL_FILTER_TYPE_PULSE                                         6

// rsemi_rngFrequencyScanStepMode
#define RSEMI_VAL_SPACING_LINEAR                                            0
#define RSEMI_VAL_SPACING_LOGARITHMIC                                       1
#define RSEMI_VAL_SPACING_AUTO                                              2

// rsemi_rngFrequencyScanAxisScale
#define RSEMI_VAL_SCALE_LINEAR                                              0
#define RSEMI_VAL_SCALE_LOGARITHMIC                                         1

// rsemi_rngScanTableRangeSignalSource
#define RSEMI_VAL_SOURCE_INPUT1                                             1
#define RSEMI_VAL_SOURCE_INPUT2                                             2

// rsemi_rngPrescanningLISNVNetworkPhase
#define RSEMI_VAL_PRESCAN_LISN_PHASE_L1                                     1
#define RSEMI_VAL_PRESCAN_LISN_PHASE_L2                                     2
#define RSEMI_VAL_PRESCAN_LISN_PHASE_L3                                     3
#define RSEMI_VAL_PRESCAN_LISN_PHASE_N                                      4

// rsemi_rngPrescanningLISNVNetworkType
#define RSEMI_VAL_PRESCAN_NETWORK_TYPE_ENV216                               0
#define RSEMI_VAL_PRESCAN_NETWORK_TYPE_ENV4200                              1
#define RSEMI_VAL_PRESCAN_NETWORK_TYPE_ESH2Z5                               2
#define RSEMI_VAL_PRESCAN_NETWORK_TYPE_ESH3Z5                               3
#define RSEMI_VAL_PRESCAN_NETWORK_TYPE_FOUR                                 4
#define RSEMI_VAL_PRESCAN_NETWORK_TYPE_OFF                                  5
#define RSEMI_VAL_PRESCAN_NETWORK_TYPE_TWOP                                 6
#define RSEMI_VAL_PRESCAN_NETWORK_TYPE_ENV432                               7

// rsemi_rngReferenceDeltaMarkerMode
#define RSEMI_VAL_ABS                                                       0
#define RSEMI_VAL_REL                                                       1

// rsemi_rngBargraphTraceMode
#define RSEMI_VAL_TRACE_MODE_AVERAGE                                        0
#define RSEMI_VAL_TRACE_MODE_BLANK                                          1
#define RSEMI_VAL_TRACE_MODE_MAXHOLD                                        2
#define RSEMI_VAL_TRACE_MODE_MINHOLD                                        3
#define RSEMI_VAL_TRACE_MODE_VIEW                                           4
#define RSEMI_VAL_TRACE_MODE_WRITE                                          5

// rsemi_rngLimitLineDomain
#define RSEMI_VAL_FREQ                                                      0
#define RSEMI_VAL_TIME                                                      1

// rsemi_rngLimitUnit
#define RSEMI_VAL_UNIT_DB                                                   11
#define RSEMI_VAL_UNIT_DEG                                                  12
#define RSEMI_VAL_UNIT_RAD                                                  13
#define RSEMI_VAL_UNIT_S                                                    14
#define RSEMI_VAL_UNIT_HZ                                                   15
#define RSEMI_VAL_UNIT_PCT                                                  16
#define RSEMI_VAL_UNIT_UNITLESS                                             17

// rsemi_rngLimitLineSpacing
#define RSEMI_VAL_LIN                                                       0
#define RSEMI_VAL_LOG                                                       1

// rsemi_rngAnalogDemodulationState
#define RSEMI_VAL_ANALOG_DEMODULATION_OFF                                   0
#define RSEMI_VAL_ANALOG_DEMODULATION_AM                                    1
#define RSEMI_VAL_ANALOG_DEMODULATION_FM                                    2
#define RSEMI_VAL_ANALOG_DEMODULATION_IF                                    3
#define RSEMI_VAL_ANALOG_DEMODULATION_VIDEO                                 4

// rsemi_rngPeakSearchListMethod
#define RSEMI_VAL_METHOD_SUBRANGE                                           0
#define RSEMI_VAL_METHOD_PEAK                                               1

// rsemi_rngPeakListDisplay
#define RSEMI_VAL_PEAK_LABEL_CROS                                           0
#define RSEMI_VAL_PEAK_LABEL_OFF                                            1

// rsemi_rngPersisTraceSymb
#define RSEMI_VAL_TRA_DOTS                                                  0
#define RSEMI_VAL_TRA_VECT                                                  1

// rsemi_rngSpecColorStyle
#define RSEMI_VAL_SPEM_HOT                                                  0
#define RSEMI_VAL_SPEM_COLD                                                 1
#define RSEMI_VAL_SPEM_COL                                                  2
#define RSEMI_VAL_SPEM_RAD                                                  3
#define RSEMI_VAL_SPEM_GRAY                                                 4

// rsemi_rngPersisColorStyle
#define RSEMI_VAL_COL_HOT                                                   0
#define RSEMI_VAL_COL_COLD                                                  1
#define RSEMI_VAL_COL_RAD                                                   2
#define RSEMI_VAL_COL_GRAY                                                  3

// rsemi_rngDISPSizeWindow
#define RSEMI_VAL_DISP_SIZE_LARGE                                           0
#define RSEMI_VAL_DISP_SIZE_SMALL                                           1

// rsemi_rngSpemColor
#define RSEMI_VAL_SPEM_COL_COLOR                                            0
#define RSEMI_VAL_SPEM_COL_RADAR                                            1
#define RSEMI_VAL_SPEM_COL_GRAY                                             2

// rsemi_rngSpemSearchArea
#define RSEMI_VAL_SPEM_SAR_MEMORY                                           1
#define RSEMI_VAL_SPEM_SAR_VISIBLE                                          0

// rsemi_rngMarkerPosition
#define RSEMI_VAL_MARKER_POSITION_MAXHOLD                                   0
#define RSEMI_VAL_MARKER_POSITION_PERSISTENCE                               1

// rsemi_rngSpecMaskCondition
#define RSEMI_VAL_MASK_ENT                                                  0
#define RSEMI_VAL_MASK_LEAV                                                 1
#define RSEMI_VAL_MASK_INS                                                  2
#define RSEMI_VAL_MASK_OUTS                                                 3

// rsemi_rngMaskMode
#define RSEMI_VAL_MASK_ABS                                                  0
#define RSEMI_VAL_MASK_REL                                                  1

// rsemi_rngFFTWinType
#define RSEMI_VAL_SPEM_FFT_WINDOW_BLACKHARRIS                               0
#define RSEMI_VAL_SPEM_FFT_WINDOW_FLATTOP                                   1
#define RSEMI_VAL_SPEM_FFT_WINDOW_GAUSSIAN                                  2
#define RSEMI_VAL_SPEM_FFT_WINDOW_HANNING                                   3
#define RSEMI_VAL_SPEM_FFT_WINDOW_KAISERBESSER                              4
#define RSEMI_VAL_SPEM_FFT_WINDOW_RECTANGULAR                               5

// rsemi_rngContinuousTrigger
#define RSEMI_VAL_TRIGGER_CONTINUOUS                                        0
#define RSEMI_VAL_TRIGGER_STOP                                              1

// rsemi_rngSpectrogramFrequencyCenterLink
#define RSEMI_VAL_CENT_FREQ_LINK_OFF                                        0
#define RSEMI_VAL_CENT_FREQ_LINK_SPAN                                       1
#define RSEMI_VAL_CENT_FREQ_LINK_RBW                                        2

// rsemi_rngSpectrogramNoiseCorrection
#define RSEMI_VAL_NOISE_CORRECTION_OFF                                      0
#define RSEMI_VAL_NOISE_CORRECTION_ON                                       1
#define RSEMI_VAL_NOISE_CORRECTION_AUTO                                     2

// rsemi_rngSpectrogramFileDecimalSeparator
#define RSEMI_VAL_DEC_SEP_POIN                                              0
#define RSEMI_VAL_DEC_SEP_COMMA                                             1

// rsemi_rngSpectrogramMarkerStepSize
#define RSEMI_VAL_MARK_STEP_SIZE_STANDARD                                   0
#define RSEMI_VAL_MARK_STEP_SIZE_POINT                                      1

// rsemi_rngSpectrogramMarkerTable
#define RSEMI_VAL_STATE_OFF                                                 0
#define RSEMI_VAL_STATE_ON                                                  1
#define RSEMI_VAL_STATE_AUTO                                                2

// rsemi_rngSpectrogramTriggerSource
#define RSEMI_VAL_TRG_IMM                                                   0
#define RSEMI_VAL_TRG_EXT                                                   1

// rsemi_rngSpectrogramTriggerSlope
#define RSEMI_VAL_NEG                                                       0
#define RSEMI_VAL_POS                                                       1

// rsemi_rngTraceMode
#define RSEMI_TRAC_MOD_WRITE                                                0
#define RSEMI_TRAC_MOD_VIEW                                                 1
#define RSEMI_TRAC_MOD_AVER                                                 2
#define RSEMI_TRAC_MOD_MAXH                                                 3
#define RSEMI_TRAC_MOD_MINH                                                 4
#define RSEMI_TRAC_MOD_BLANK                                                5
#define RSEMI_TRAC_MOD_TRD                                                  6

// rsemi_rngAmplitudeUnitsRangeTable
#define RSEMI_VAL_AMPLITUDE_UNITS_DBM                                       0
#define RSEMI_VAL_AMPLITUDE_UNITS_DBMV                                      1
#define RSEMI_VAL_AMPLITUDE_UNITS_DBUV                                      2
#define RSEMI_VAL_AMPLITUDE_UNITS_VOLT                                      3
#define RSEMI_VAL_AMPLITUDE_UNITS_WATT                                      4
#define RSEMI_VAL_AMPLITUDE_UNITS_DBPW                                      5
#define RSEMI_VAL_AMPLITUDE_UNITS_DBUA                                      6
#define RSEMI_VAL_AMPLITUDE_UNITS_A                                         7

// rsemi_rngESPMode
#define RSEMI_VAL_ESP_MODE_AUTO                                             0
#define RSEMI_VAL_ESP_MODE_MAN                                              2

// rsemi_rngDetectorTypeRangeTable
#define RSEMI_VAL_DETECTOR_TYPE_AVERAGE                                     0
#define RSEMI_VAL_DETECTOR_TYPE_MAX_PEAK                                    1
#define RSEMI_VAL_DETECTOR_TYPE_MIN_PEAK                                    2
#define RSEMI_VAL_DETECTOR_TYPE_RMS                                         3
#define RSEMI_VAL_DETECTOR_TYPE_QPK                                         4
#define RSEMI_VAL_DETECTOR_TYPE_CRMS                                        5
#define RSEMI_VAL_DETECTOR_TYPE_CAV                                         6
#define RSEMI_VAL_DETECTOR_TYPE_AUTO_PEAK                                   7
#define RSEMI_VAL_DETECTOR_TYPE_SAMPLE                                      8

// rsemi_rngCoupling
#define RSEMI_VAL_DC                                                        0
#define RSEMI_VAL_AC                                                        1

// rsemi_rngListRangDet
#define RSEMI_VAL_LIST_RANG_DET_APE                                         0
#define RSEMI_VAL_LIST_RANG_DET_NEG                                         1
#define RSEMI_VAL_LIST_RANG_DET_POS                                         2
#define RSEMI_VAL_LIST_RANG_DET_SAMP                                        3
#define RSEMI_VAL_LIST_RANG_DET_RMS                                         4
#define RSEMI_VAL_LIST_RANG_DET_AVER                                        5
#define RSEMI_VAL_LIST_RANG_DET_ACPULSE                                     6
#define RSEMI_VAL_LIST_RANG_DET_ACSINE                                      7

// rsemi_rngDISPConfPreDefColour
#define RSEMI_VAL_DISP_COL_BLAC                                             0
#define RSEMI_VAL_DISP_COL_BLUE                                             1
#define RSEMI_VAL_DISP_COL_BROW                                             2
#define RSEMI_VAL_DISP_COL_GRE                                              3
#define RSEMI_VAL_DISP_COL_CYAN                                             4
#define RSEMI_VAL_DISP_COL_RED                                              5
#define RSEMI_VAL_DISP_COL_MAG                                              6
#define RSEMI_VAL_DISP_COL_YELL                                             7
#define RSEMI_VAL_DISP_COL_WHIT                                             8
#define RSEMI_VAL_DISP_COL_DGRA                                             9
#define RSEMI_VAL_DISP_COL_LGRA                                             10
#define RSEMI_VAL_DISP_COL_LBLU                                             11
#define RSEMI_VAL_DISP_COL_LGRE                                             12
#define RSEMI_VAL_DISP_COL_LCY                                              13
#define RSEMI_VAL_DISP_COL_LRED                                             14
#define RSEMI_VAL_DISP_COL_LMAG                                             15

// rsemi_rngHcopyDeviceLang
#define RSEMI_VAL_HCOPY_DEVICE_LANG_GDI                                     0
#define RSEMI_VAL_HCOPY_DEVICE_LANG_WMF                                     1
#define RSEMI_VAL_HCOPY_DEVICE_LANG_EWMF                                    2
#define RSEMI_VAL_HCOPY_DEVICE_LANG_BMP                                     3
#define RSEMI_VAL_HCOPY_DEVICE_LANG_JPG                                     4
#define RSEMI_VAL_HCOPY_DEVICE_LANG_PNG                                     5
#define RSEMI_VAL_HCOPY_DEVICE_LANG_PDF                                     6
#define RSEMI_VAL_HCOPY_DEVICE_LANG_RTF                                     7
#define RSEMI_VAL_HCOPY_DEVICE_LANG_DOC                                     8

// rsemi_rngHcopyDeviceOrient
#define RSEMI_VAL_HCOPY_DEVICE_ORIENT_LAND                                  0
#define RSEMI_VAL_HCOPY_DEVICE_ORIENT_PORT                                  1

// rsemi_rngDISPFormat
#define RSEMI_VAL_DISP_FORMAT_SINGLE                                        0
#define RSEMI_VAL_DISP_FORMAT_SPLIT                                         1

// rsemi_rngLinLog
#define RSEMI_VAL_MPOW                                                      2
#define RSEMI_VAL_AUTOGAIN                                                  3

// rsemi_rngServiceInput
#define RSEMI_VAL_INPUT_RF                                                  0
#define RSEMI_VAL_INPUT_CAL                                                 1
#define RSEMI_VAL_INPUT_MCAL                                                3

// rsemi_rngAvgType
#define RSEMI_VAL_AVG_LIN                                                   0
#define RSEMI_VAL_AVG_VID                                                   1
#define RSEMI_VAL_AVG_POW                                                   2

// rsemi_rngMarkerPeakListSort
#define RSEMI_VAL_MARKER_SORT_X                                             0
#define RSEMI_VAL_MARKER_SORT_Y                                             1

// rsemi_rngMarkerDemodType
#define RSEMI_VAL_MARKER_DEMOD_AM                                           0
#define RSEMI_VAL_MARKER_DEMOD_FM                                           1

// rsemi_rngMeasPowerSelect
#define RSEMI_VAL_MEAS_POW_ACP                                              0
#define RSEMI_VAL_MEAS_POW_CPOW                                             1
#define RSEMI_VAL_MEAS_POW_MCAC                                             2
#define RSEMI_VAL_MEAS_POW_OBAN                                             3
#define RSEMI_VAL_MEAS_POW_CN                                               4
#define RSEMI_VAL_MEAS_POW_CN0                                              5
#define RSEMI_VAL_MEAS_POW_AOBW                                             6
#define RSEMI_VAL_MEAS_POW_TPOW                                             7

// rsemi_rngMeasPowerStandard
#define RSEMI_VAL_MEAS_POW_STD_NONE                                         0
#define RSEMI_VAL_MEAS_POW_STD_TETRA                                        1
#define RSEMI_VAL_MEAS_POW_STD_PDC                                          2
#define RSEMI_VAL_MEAS_POW_STD_PHS                                          3
#define RSEMI_VAL_MEAS_POW_STD_CDPD                                         4
#define RSEMI_VAL_MEAS_POW_STD_FIS95A                                       5
#define RSEMI_VAL_MEAS_POW_STD_RIS95A                                       6
#define RSEMI_VAL_MEAS_POW_STD_FIS95C0                                      7
#define RSEMI_VAL_MEAS_POW_STD_RIS95C0                                      8
#define RSEMI_VAL_MEAS_POW_STD_FJ008                                        9
#define RSEMI_VAL_MEAS_POW_STD_RJ008                                        10
#define RSEMI_VAL_MEAS_POW_STD_FIS95C1                                      11
#define RSEMI_VAL_MEAS_POW_STD_RIS95C1                                      12
#define RSEMI_VAL_MEAS_POW_STD_FWCD                                         13
#define RSEMI_VAL_MEAS_POW_STD_RWCD                                         14
#define RSEMI_VAL_MEAS_POW_STD_FW3G                                         15
#define RSEMI_VAL_MEAS_POW_STD_RW3G                                         16
#define RSEMI_VAL_MEAS_POW_STD_D2CD                                         17
#define RSEMI_VAL_MEAS_POW_STD_S2CD                                         18
#define RSEMI_VAL_MEAS_POW_STD_M2CD                                         19
#define RSEMI_VAL_MEAS_POW_STD_TCDM                                         20
#define RSEMI_VAL_MEAS_POW_STD_AWL                                          21
#define RSEMI_VAL_MEAS_POW_STD_BWL                                          22
#define RSEMI_VAL_MEAS_POW_STD_WIM                                          23
#define RSEMI_VAL_MEAS_POW_STD_WIBRO                                        24
#define RSEMI_VAL_MEAS_POW_STD_RTCDMA                                       25
#define RSEMI_VAL_MEAS_POW_STD_RFID                                         26
#define RSEMI_VAL_MEAS_POW_STD_GSM                                          27
#define RSEMI_VAL_MEAS_POW_STD_EURT                                         28
#define RSEMI_VAL_MEAS_POW_STD_REUT                                         29
#define RSEMI_VAL_MEAS_POW_STD_PAPC                                         30
#define RSEMI_VAL_MEAS_POW_STD_MSR                                          31
#define RSEMI_VAL_MEAS_POW_STD_TRCD                                         32
#define RSEMI_VAL_MEAS_POW_STD_USER                                         33

// rsemi_rngMeasPowerMode
#define RSEMI_VAL_MEAS_POW_MODE_WRITE                                       0
#define RSEMI_VAL_MEAS_POW_MODE_MAXH                                        1

// rsemi_rngMeasStatUnit
#define RSEMI_VAL_PCT                                                       1

// rsemi_rngFFTFilterMode
#define RSEMI_VAL_FFT_MODE_AUTO                                             0
#define RSEMI_VAL_FFT_MODE_NARROW                                           1

// rsemi_rngBandFiltType
#define RSEMI_VAL_FILT_TYPE_NORM                                            0
#define RSEMI_VAL_FILT_TYPE_FFT                                             1
#define RSEMI_VAL_FILT_TYPE_CFIL                                            2
#define RSEMI_VAL_FILT_TYPE_RRC                                             3
#define RSEMI_VAL_FILT_TYPE_P5                                              4
#define RSEMI_VAL_FILT_TYPE_PULSE                                           5
#define RSEMI_VAL_FILT_TYPE_NOISE                                           6
#define RSEMI_VAL_FILT_TYPE_P5D                                             7
#define RSEMI_VAL_FILT_TYPE_CISP                                            8
#define RSEMI_VAL_FILT_TYPE_MIL                                             9

// rsemi_rngVbwFiltType
#define RSEMI_VAL_VBW_FILT_LIN                                              0
#define RSEMI_VAL_VBW_FILT_LOG                                              1

// rsemi_rngTFacUnit
#define RSEMI_VAL_TFAC_UNIT_DB                                              0
#define RSEMI_VAL_TFAC_UNIT_DBM                                             1
#define RSEMI_VAL_TFAC_UNIT_DBMV                                            2
#define RSEMI_VAL_TFAC_UNIT_DBUV                                            3
#define RSEMI_VAL_TFAC_UNIT_DBUVM                                           4
#define RSEMI_VAL_TFAC_UNIT_DBUA                                            5
#define RSEMI_VAL_TFAC_UNIT_DBUAM                                           6
#define RSEMI_VAL_TFAC_UNIT_DBPW                                            7
#define RSEMI_VAL_TFAC_UNIT_DBPT                                            8

// rsemi_rngCvlBand
#define RSEMI_VAL_CVL_BAND_A                                                0
#define RSEMI_VAL_CVL_BAND_Q                                                1
#define RSEMI_VAL_CVL_BAND_U                                                2
#define RSEMI_VAL_CVL_BAND_V                                                3
#define RSEMI_VAL_CVL_BAND_E                                                4
#define RSEMI_VAL_CVL_BAND_W                                                5
#define RSEMI_VAL_CVL_BAND_F                                                6
#define RSEMI_VAL_CVL_BAND_D                                                7
#define RSEMI_VAL_CVL_BAND_G                                                8
#define RSEMI_VAL_CVL_BAND_Y                                                9
#define RSEMI_VAL_CVL_BAND_J                                                10
#define RSEMI_VAL_CVL_BAND_USER                                             11
#define RSEMI_VAL_CVL_BAND_K                                                12
#define RSEMI_VAL_CVL_BAND_KA                                               13

// rsemi_rngFreqMode
#define RSEMI_VAL_FREQ_MODE_FIX                                             0
#define RSEMI_VAL_FREQ_MODE_SWE                                             1

// rsemi_rngListFiltType
#define RSEMI_VAL_LIST_FTYPE_NORM                                           0
#define RSEMI_VAL_LIST_FTYPE_CHAN                                           1
#define RSEMI_VAL_LIST_FTYPE_RRC                                            2
#define RSEMI_VAL_LIST_FTYPE_P5                                             3
#define RSEMI_VAL_LIST_FTYPE_PULS                                           4
#define RSEMI_VAL_LIST_FTYPE_MIL                                            5

// rsemi_rngOffOnAuto
#define RSEMI_VAL_STATE_ALL                                                 3

// rsemi_rngExtMixerHarmonicType
#define RSEMI_VAL_EXT_MIX_HARM_ODD                                          0
#define RSEMI_VAL_EXT_MIX_HARM_EVEN                                         1
#define RSEMI_VAL_EXT_MIX_HARM_EODD                                         2

// rsemi_rngExtMixerHarmBand
#define RSEMI_VAL_EXT_MIX_BAND_A                                            0
#define RSEMI_VAL_EXT_MIX_BAND_Q                                            1
#define RSEMI_VAL_EXT_MIX_BAND_U                                            2
#define RSEMI_VAL_EXT_MIX_BAND_V                                            3
#define RSEMI_VAL_EXT_MIX_BAND_E                                            4
#define RSEMI_VAL_EXT_MIX_BAND_W                                            5
#define RSEMI_VAL_EXT_MIX_BAND_F                                            6
#define RSEMI_VAL_EXT_MIX_BAND_D                                            7
#define RSEMI_VAL_EXT_MIX_BAND_G                                            8
#define RSEMI_VAL_EXT_MIX_BAND_Y                                            9
#define RSEMI_VAL_EXT_MIX_BAND_J                                            10
#define RSEMI_VAL_EXT_MIX_BAND_USER                                         11
#define RSEMI_VAL_EXT_MIX_BAND_K                                            12
#define RSEMI_VAL_EXT_MIX_BAND_KA                                           13

// rsemi_rngAdjChAutoSel
#define RSEMI_VAL_ADJ_RCHAN_AUTO_MIN                                        0
#define RSEMI_VAL_ADJ_RCHAN_AUTO_MAX                                        1
#define RSEMI_VAL_ADJ_RCHAN_AUTO_LHIG                                       2

// rsemi_rngAdjPreset
#define RSEMI_VAL_ADJ_PRE_ACP                                               0
#define RSEMI_VAL_ADJ_PRE_CPOW                                              1
#define RSEMI_VAL_ADJ_PRE_MCAC                                              2
#define RSEMI_VAL_ADJ_PRE_OBAN                                              3
#define RSEMI_VAL_ADJ_PRE_CN                                                4
#define RSEMI_VAL_ADJ_PRE_CN0                                               5

// rsemi_rngSourceIntExt
#define RSEMI_VAL_SOUR_INT                                                  0
#define RSEMI_VAL_SOUR_EXT                                                  1
#define RSEMI_VAL_SOUR_EAUT                                                 2
#define RSEMI_VAL_SOUR_SYNC                                                 3

// rsemi_rngExtGateTrigType
#define RSEMI_VAL_EGAT_TRIG_LEV                                             0
#define RSEMI_VAL_EGAT_TRIG_EDGE                                            1

// rsemi_rngHcopyDevice
#define RSEMI_VAL_HCOPY_DEVICE_MEM                                          0
#define RSEMI_VAL_HCOPY_DEVICE_PRN                                          1
#define RSEMI_VAL_HCOPY_DEVICE_CLP                                          2

// rsemi_rngExtGateSource
#define RSEMI_VAL_EGAT_SOUR_EXT                                             0
#define RSEMI_VAL_EGAT_SOUR_IFP                                             1
#define RSEMI_VAL_EGAT_SOUR_VID                                             2
#define RSEMI_VAL_EGAT_SOUR_RFP                                             3
#define RSEMI_VAL_EGAT_SOUR_PSE                                             4
#define RSEMI_VAL_EGAT_SOUR_EXT2                                            5
#define RSEMI_VAL_EGAT_SOUR_EXT3                                            6
#define RSEMI_VAL_EGAT_SOUR_IQP                                             7
#define RSEMI_VAL_EGAT_SOUR_EXT4                                            8

// rsemi_rngSweepContMode
#define RSEMI_VAL_SWE_MODE_AUTO                                             0
#define RSEMI_VAL_SWE_MODE_LIST                                             1
#define RSEMI_VAL_SWE_MODE_ESP                                              3

// rsemi_rngTraceFormat
#define RSEMI_VAL_TRACE_FORM_COMP                                           0
#define RSEMI_VAL_TRACE_FORM_IQBL                                           1
#define RSEMI_VAL_TRACE_FORM_IQP                                            2

// rsemi_rngTriggerSource
#define RSEMI_VAL_TRG_IFP                                                   2
#define RSEMI_VAL_TRG_VID                                                   3
#define RSEMI_VAL_TRG_TIME                                                  4
#define RSEMI_VAL_TRG_RFP                                                   5
#define RSEMI_VAL_TRG_PSEN                                                  6
#define RSEMI_VAL_TRG_TDTR                                                  7
#define RSEMI_VAL_TRG_BB_PWR                                                8
#define RSEMI_VAL_TRG_EXT2                                                  9
#define RSEMI_VAL_TRG_EXT3                                                  10
#define RSEMI_VAL_TRG_IQP                                                   11
#define RSEMI_VAL_TRG_GP0                                                   12
#define RSEMI_VAL_TRG_GP1                                                   13
#define RSEMI_VAL_TRG_GP2                                                   14
#define RSEMI_VAL_TRG_GP3                                                   15
#define RSEMI_VAL_TRG_GP4                                                   16
#define RSEMI_VAL_TRG_GP5                                                   17
#define RSEMI_VAL_TRG_TUN                                                   18
#define RSEMI_VAL_TRG_MASK                                                  19
#define RSEMI_VAL_TRG_EXT4                                                  20

// rsemi_rngVSAConfDisplayTraceSpacing
#define RSEMI_VAL_TRACE_SPACE_LIN                                           0
#define RSEMI_VAL_TRACE_SPACE_LOG                                           1
#define RSEMI_VAL_TRACE_SPACE_LDB                                           2

// rsemi_rngMarkerStepSize
#define RSEMI_VAL_MARK_STEP_SIZE_STAN                                       0
#define RSEMI_VAL_MARK_STEP_SIZE_POIN                                       1

// rsemi_rngMpowFiltType
#define RSEMI_VAL_MPOW_FTYPE_NORM                                           0
#define RSEMI_VAL_MPOW_FTYPE_CFIL                                           1
#define RSEMI_VAL_MPOW_FTYPE_RRC                                            2
#define RSEMI_VAL_MPOW_FTYPE_PULSE                                          3
#define RSEMI_VAL_MPOW_FTYPE_MIL                                            4

// rsemi_rngServiceCombFrequency
#define RSEMI_VAL_SERV_COMB_FREQ_COMB1                                      0
#define RSEMI_VAL_SERV_COMB_FREQ_COMB64                                     1
#define RSEMI_VAL_SERV_COMB_FREQ_COMB65                                     2

// rsemi_rngSEMFilterType
#define RSEMI_VAL_SEM_FILTER_TYPE_NORM                                      0
#define RSEMI_VAL_SEM_FILTER_TYPE_CFIL                                      1
#define RSEMI_VAL_SEM_FILTER_TYPE_RRC                                       2
#define RSEMI_VAL_SEM_FILTER_TYPE_PULS                                      3
#define RSEMI_VAL_SEM_FILTER_TYPE_P5                                        4
#define RSEMI_VAL_SEM_FILTER_TYPE_MIL                                       5

// rsemi_rngSEMInsertRange
#define RSEMI_VAL_SEM_INSERT_RANGE_AFTER                                    0
#define RSEMI_VAL_SEM_INSERT_RANGE_BEFORE                                   1

// rsemi_rngSEMRangeLimitCheckType
#define RSEMI_VAL_SEM_LIM_CHECK_TYPE_ABS                                    0
#define RSEMI_VAL_SEM_LIM_CHECK_TYPE_REL                                    1
#define RSEMI_VAL_SEM_LIM_CHECK_TYPE_AND                                    2
#define RSEMI_VAL_SEM_LIM_CHECK_TYPE_OR                                     3

// rsemi_rngSEMPowerRefType
#define RSEMI_VAL_SEM_REF_TYPE_PEAK                                         0
#define RSEMI_VAL_SEM_REF_TYPE_CPOW                                         1

// rsemi_rngIFOutputSource
#define RSEMI_VAL_IF_OUTPUT_SOURCE_IF                                       0
#define RSEMI_VAL_IF_OUTPUT_SOURCE_VID                                      1
#define RSEMI_VAL_IF_OUTPUT_SOURCE_HVID                                     2
#define RSEMI_VAL_IF_OUTPUT_SOURCE_AM                                       3
#define RSEMI_VAL_IF_OUTPUT_SOURCE_FM                                       4
#define RSEMI_VAL_IF_OUTPUT_SOURCE_FOCUS                                    5
#define RSEMI_VAL_IF_OUTPUT_SOURCE_IQ                                       6
#define RSEMI_VAL_IF_OUTPUT_SOURCE_PM                                       7
#define RSEMI_VAL_IF_OUTPUT_SOURCE_OFF                                      8

// rsemi_rngTouchscreenDisplay
#define RSEMI_VAL_TOUCH_OFF                                                 0
#define RSEMI_VAL_TOUCH_ON                                                  1
#define RSEMI_VAL_TOUCH_FRAM                                                2

// rsemi_rngAutoMan
#define RSEMI_VAL_AUTO                                                      0
#define RSEMI_VAL_MAN                                                       1

// rsemi_rngSweepType
#define RSEMI_VAL_SWEEP_TYPE_AUTO                                           0
#define RSEMI_VAL_SWEEP_TYPE_SWEEP                                          1
#define RSEMI_VAL_SWEEP_TYPE_FFT                                            2

// rsemi_rngAmplAttenMode
#define RSEMI_VAL_ATT_MODE_NORM                                             0
#define RSEMI_VAL_ATT_MODE_LDIS                                             1

// rsemi_rngIQDataGateType
#define RSEMI_VAL_GATE_TYPE_LEVEL                                           0
#define RSEMI_VAL_GATE_TYPE_EDGE                                            1

// rsemi_rngIQDataDisplayType
#define RSEMI_VAL_IQ_DATA_TYPE_RIMAG                                        0
#define RSEMI_VAL_IQ_DATA_TYPE_MAGN                                         1
#define RSEMI_VAL_IQ_DATA_TYPE_FREQ                                         2
#define RSEMI_VAL_IQ_DATA_TYPE_VECT                                         3

// rsemi_rngBandPowerMode
#define RSEMI_VAL_BPOWER_POWER                                              0
#define RSEMI_VAL_BPOWER_DENSITY                                            1
#define RSEMI_VAL_BPOWER_RPOW                                               2

// rsemi_rngresultdispay
#define RSEMI_VAL_PSPEM                                                     0
#define RSEMI_VAL_SPEM                                                      1
#define RSEMI_VAL_REAL_SPEM                                                 2
#define RSEMI_VAL_BARGRAPH                                                  3
#define RSEMI_VAL_IF_ANALYSIS                                               4
#define RSEMI_VAL_NONE                                                      5

// rsemi_rngPowerNoiseCorrection
#define RSEMI_VAL_MEAS_POW_NOISE_CORR_OFF                                   0
#define RSEMI_VAL_MEAS_POW_NOISE_CORR_ON                                    1
#define RSEMI_VAL_MEAS_POW_NOISE_CORR_AUTO                                  2

// rsemi_rngDataSetLoadMode
#define RSEMI_VAL_MEM_LOAD_MODE_NEW                                         0
#define RSEMI_VAL_MEM_LOAD_MODE_REPLACE                                     1

// rsemi_rngDataSetStoreMode
#define RSEMI_VAL_MEM_STORE_MODE_INSTRUMENT                                 0
#define RSEMI_VAL_MEM_STORE_MODE_CHANNEL                                    1

// rsemi_rngSequencerMode
#define RSEMI_VAL_SEQUENCER_MODE_SING                                       0
#define RSEMI_VAL_SEQUENCER_MODE_CONT                                       1
#define RSEMI_VAL_SEQUENCER_MODE_CDEF                                       2

// rsemi_rngAssignMarkertoTraceRaisingFalling
#define RSEMI_VAL_MARKER_TRACE_OFF1                                         0
#define RSEMI_VAL_MARKER_TRACE_OFF2                                         1
#define RSEMI_VAL_MARKER_TRACE_FALLING1                                     2
#define RSEMI_VAL_MARKER_TRACE_FALLING2                                     3
#define RSEMI_VAL_MARKER_TRACE_RAISING1                                     4
#define RSEMI_VAL_MARKER_TRACE_RAISING2                                     5

// rsemi_rngIFShift
#define RSEMI_VAL_IF_SHIFT_OFF                                              0
#define RSEMI_VAL_IF_SHIFT_A                                                1
#define RSEMI_VAL_IF_SHIFT_B                                                2
#define RSEMI_VAL_IF_SHIFT_AUTO                                             3

// rsemi_rngTVTriggerVerticalSignal
#define RSEMI_VAL_TRIG_TV_VFIEL_ALL                                         0
#define RSEMI_VAL_TRIG_TV_VFIEL_ODD                                         1
#define RSEMI_VAL_TRIG_TV_VFIEL_EVEN                                        2

// rsemi_rngMarkerLinkAllMarkers
#define RSEMI_VAL_LINK_MARKERS_NONE                                         0
#define RSEMI_VAL_LINK_MARKERS_SPECTRUM                                     1
#define RSEMI_VAL_LINK_MARKERS_TIME                                         2
#define RSEMI_VAL_LINK_MARKERS_BOTH                                         3

// rsemi_rngScanTransmissionMode
#define RSEMI_VAL_TRANS_NEVER                                               0
#define RSEMI_VAL_TRANS_ALWAYS                                              1
#define RSEMI_VAL_TRANS_CRA                                                 2

// rsemi_rngTransducerSetUnit
#define RSEMI_VAL_TSET_UNIT_DB                                              0
#define RSEMI_VAL_TSET_UNIT_DBM                                             1
#define RSEMI_VAL_TSET_UNIT_DBUV                                            2
#define RSEMI_VAL_TSET_UNIT_DBUVM                                           3
#define RSEMI_VAL_TSET_UNIT_DBUA                                            4
#define RSEMI_VAL_TSET_UNIT_DBUAM                                           5
#define RSEMI_VAL_TSET_UNIT_DBPW                                            6
#define RSEMI_VAL_TSET_UNIT_DBPT                                            7

// rsemi_rngSpectrogramColor
#define RSEMI_VAL_SGR_COLOR_COL                                             0
#define RSEMI_VAL_SGR_COLOR_RAD                                             1
#define RSEMI_VAL_SGR_COLOR_GRAY                                            2

// rsemi_rngColorStyle
#define RSEMI_VAL_COLOR_STYLE_HOT                                           0
#define RSEMI_VAL_COLOR_STYLE_COLD                                          1
#define RSEMI_VAL_COLOR_STYLE_RAD                                           2
#define RSEMI_VAL_COLOR_STYLE_GRAY                                          3

// rsemi_rngSearchArea
#define RSEMI_VAL_SEARCH_AREA_VIS                                           0
#define RSEMI_VAL_SEARCH_AREA_MEM                                           1

// rsemi_rngCouplingState
#define RSEMI_VAL_COUPLE_NONE                                               0
#define RSEMI_VAL_COUPLE_ALL                                                1

// rsemi_rngHCopyOutput
#define RSEMI_VAL_HCOPY_MODE_SCREEN                                         0
#define RSEMI_VAL_HCOPY_MODE_REPORT                                         1

// rsemi_rngTestReportItem
#define RSEMI_VAL_TEST_REPORT_DIAG                                          0
#define RSEMI_VAL_TEST_REPORT_FRES                                          1
#define RSEMI_VAL_TEST_REPORT_HEAD                                          2
#define RSEMI_VAL_TEST_REPORT_IF                                            3
#define RSEMI_VAL_TEST_REPORT_IFSP                                          4
#define RSEMI_VAL_TEST_REPORT_MARK                                          5
#define RSEMI_VAL_TEST_REPORT_PAG                                           6
#define RSEMI_VAL_TEST_REPORT_PRES                                          7
#define RSEMI_VAL_TEST_REPORT_SCAN                                          8
#define RSEMI_VAL_TEST_REPORT_SETT                                          9
#define RSEMI_VAL_TEST_REPORT_SPEC                                          10
#define RSEMI_VAL_TEST_REPORT_SRES                                          11
#define RSEMI_VAL_TEST_REPORT_TDST                                          12
#define RSEMI_VAL_TEST_REPORT_TRAN                                          13
#define RSEMI_VAL_TEST_REPORT_RES                                           14
#define RSEMI_VAL_TEST_REPORT_REAL                                          15

// rsemi_rngTestReportRepetition
#define RSEMI_VAL_TREP_NEVER                                                0
#define RSEMI_VAL_TREP_ONCE                                                 1
#define RSEMI_VAL_TREP_ALWAYS                                               2

// rsemi_rngTestReportPageSize
#define RSEMI_VAL_TEST_REPORT_A4                                            0
#define RSEMI_VAL_TEST_REPORT_US                                            1

// rsemi_rngStatusRegisterQuestionable
#define RSEMI_VAL_STAT_REG_MAIN                                             0
#define RSEMI_VAL_STAT_REG_FREQ                                             1
#define RSEMI_VAL_STAT_REG_POWER                                            2
#define RSEMI_VAL_STAT_REG_TIME                                             3
#define RSEMI_VAL_STAT_REG_TRAN                                             4
#define RSEMI_VAL_STAT_REG_LIM                                              5
#define RSEMI_VAL_STAT_REG_LMAR                                             6
#define RSEMI_VAL_STAT_REG_ACP                                              7
#define RSEMI_VAL_STAT_REG_DIQ                                              8
#define RSEMI_VAL_STAT_REG_EXTENDED                                         9
#define RSEMI_VAL_STAT_REG_EXTENDED_INFO                                    10
#define RSEMI_VAL_STAT_REG_SYNC                                             11
#define RSEMI_VAL_STAT_REG_TEMP                                             12

// rsemi_rngStatusRegister
#define RSEMI_VAL_STAT_REG_QUESTIONABLE                                     1
#define RSEMI_VAL_STAT_REG_OPERATION                                        2

// rsemi_rngStatusRegisterPart
#define RSEMI_VAL_STAT_REG_COND                                             0
#define RSEMI_VAL_STAT_REG_EVENT                                            1
#define RSEMI_VAL_STAT_REG_ENABLE                                           2
#define RSEMI_VAL_STAT_REG_PTR                                              3
#define RSEMI_VAL_STAT_REG_NTR                                              4

// rsemi_rngCMAPItem
#define RSEMI_VAL_CMAP1                                                     1
#define RSEMI_VAL_CMAP2                                                     2
#define RSEMI_VAL_CMAP3                                                     3
#define RSEMI_VAL_CMAP4                                                     4
#define RSEMI_VAL_CMAP5                                                     5
#define RSEMI_VAL_CMAP6                                                     6
#define RSEMI_VAL_CMAP7                                                     7
#define RSEMI_VAL_CMAP8                                                     8
#define RSEMI_VAL_CMAP9                                                     9
#define RSEMI_VAL_CMAP10                                                    10
#define RSEMI_VAL_CMAP11                                                    11
#define RSEMI_VAL_CMAP12                                                    12
#define RSEMI_VAL_CMAP13                                                    13
#define RSEMI_VAL_CMAP14                                                    14
#define RSEMI_VAL_CMAP15                                                    15
#define RSEMI_VAL_CMAP16                                                    16
#define RSEMI_VAL_CMAP17                                                    17
#define RSEMI_VAL_CMAP18                                                    18
#define RSEMI_VAL_CMAP19                                                    19
#define RSEMI_VAL_CMAP20                                                    20
#define RSEMI_VAL_CMAP21                                                    21
#define RSEMI_VAL_CMAP22                                                    22
#define RSEMI_VAL_CMAP23                                                    23
#define RSEMI_VAL_CMAP24                                                    24
#define RSEMI_VAL_CMAP25                                                    25
#define RSEMI_VAL_CMAP26                                                    26
#define RSEMI_VAL_CMAP27                                                    27
#define RSEMI_VAL_CMAP28                                                    28
#define RSEMI_VAL_CMAP29                                                    29
#define RSEMI_VAL_CMAP30                                                    30
#define RSEMI_VAL_CMAP31                                                    31
#define RSEMI_VAL_CMAP32                                                    32
#define RSEMI_VAL_CMAP33                                                    33
#define RSEMI_VAL_CMAP34                                                    34
#define RSEMI_VAL_CMAP35                                                    35
#define RSEMI_VAL_CMAP36                                                    36
#define RSEMI_VAL_CMAP37                                                    37
#define RSEMI_VAL_CMAP38                                                    38
#define RSEMI_VAL_CMAP39                                                    39
#define RSEMI_VAL_CMAP40                                                    40
#define RSEMI_VAL_CMAP41                                                    41
#define RSEMI_VAL_CMAP42                                                    42
#define RSEMI_VAL_CMAP43                                                    43
#define RSEMI_VAL_CMAP44                                                    44
#define RSEMI_VAL_CMAP45                                                    45
#define RSEMI_VAL_CMAP46                                                    46
#define RSEMI_VAL_CMAP47                                                    47
#define RSEMI_VAL_CMAP48                                                    48
#define RSEMI_VAL_CMAP49                                                    49

// rsemi_rngChannelType
#define RSEMI_VAL_CHANNEL_TYPE_RECEIVER                                     0
#define RSEMI_VAL_CHANNEL_TYPE_SPECTRUM                                     1
#define RSEMI_VAL_CHANNEL_TYPE_IQ                                           2
#define RSEMI_VAL_CHANNEL_TYPE_ADEM                                         3

// rsemi_rngIFOutputSideband
#define RSEMI_VAL_IFOUT_SBAND_NORMAL                                        0
#define RSEMI_VAL_IFOUT_SBAND_INVERTED                                      1

// rsemi_rngSweepOptimization
#define RSEMI_VAL_SWEEP_OPTIMIZATION_AUTO                                   0
#define RSEMI_VAL_SWEEP_OPTIMIZATION_DYNAMIC                                1
#define RSEMI_VAL_SWEEP_OPTIMIZATION_SPEED                                  2

// rsemi_rngTraceResultType
#define RSEMI_VAL_TRACE_RESULT_TRACE1                                       0
#define RSEMI_VAL_TRACE_RESULT_TRACE2                                       1
#define RSEMI_VAL_TRACE_RESULT_TRACE3                                       2
#define RSEMI_VAL_TRACE_RESULT_TRACE4                                       3
#define RSEMI_VAL_TRACE_RESULT_TRACE5                                       4
#define RSEMI_VAL_TRACE_RESULT_TRACE6                                       5
#define RSEMI_VAL_TRACE_RESULT_LIST                                         6
#define RSEMI_VAL_TRACE_RESULT_SPURIOUS                                     7
#define RSEMI_VAL_TRACE_RESULT_SPECTROGRAM                                  8

// rsemi_rngTraceExportAll
#define RSEMI_TRAC_EXPORT_MODE_SINGLE                                       0
#define RSEMI_TRAC_EXPORT_MODE_ALL                                          1

// rsemi_rngTriggerDirection
#define RSEMI_VAL_TRIG_DIRECTION_INP                                        0
#define RSEMI_VAL_TRIG_DIRECTION_OUTP                                       1

// rsemi_rngTriggerOType
#define RSEMI_VAL_TRIG_OTYPE_DEVICE                                         0
#define RSEMI_VAL_TRIG_OTYPE_TARMED                                         1
#define RSEMI_VAL_TRIG_OTYPE_UDEFINED                                       2

// rsemi_rngTriggerLevel
#define RSEMI_VAL_TRIG_LEVEL_HIGH                                           0
#define RSEMI_VAL_TRIG_LEVEL_LOW                                            1

// rsemi_rngPreampLevel
#define RSEMI_VAL_PREAMPLIFICATION_LEVEL_15DB                               0
#define RSEMI_VAL_PREAMPLIFICATION_LEVEL_30DB                               1

// rsemi_rngRFInputEnabled
#define RSEMI_VAL_RF_INPUT_RF                                               0
#define RSEMI_VAL_RF_INPUT_DIQ                                              1
#define RSEMI_VAL_RF_INPUT_AIQ                                              2
#define RSEMI_VAL_RF_INPUT_RFA                                              2

// rsemi_rngLayoutDirection
#define RSEMI_VAL_LAYOUT_DIRECTION_LEFT                                     0
#define RSEMI_VAL_LAYOUT_DIRECTION_RIGHT                                    1
#define RSEMI_VAL_LAYOUT_DIRECTION_ABOVE                                    2
#define RSEMI_VAL_LAYOUT_DIRECTION_BELOW                                    3

// rsemi_rngLayoutQueryWindowType
#define RSEMI_VAL_LAYOUT_TYPE_DIAGRAM                                       0
#define RSEMI_VAL_LAYOUT_TYPE_MTABLE                                        1
#define RSEMI_VAL_LAYOUT_TYPE_PEAKLIST                                      2
#define RSEMI_VAL_LAYOUT_TYPE_RSUMMARY                                      3
#define RSEMI_VAL_LAYOUT_TYPE_SGRAM                                         4

// rsemi_rngServiceCalibrationFrequencyRFSpectrum
#define RSEMI_VAL_CAL_FREQ_SPEC_NARR                                        0
#define RSEMI_VAL_CAL_FREQ_SPEC_BRO                                         1

// rsemi_rngServiceCalibrationFrequencyMW
#define RSEMI_VAL_CAL_FREQ_MW_SMAL                                          0
#define RSEMI_VAL_CAL_FREQ_MW_WIDE                                          1

// rsemi_rngLimitCheckState
#define RSEMI_VAL_LIMIT_CHECK_STATE_PASS                                    0
#define RSEMI_VAL_LIMIT_CHECK_STATE_FAIL                                    1

// rsemi_rngStatisticsResultType
#define RSEMI_VAL_STAT_RESULT_MEAN                                          0
#define RSEMI_VAL_STAT_RESULT_PEAK                                          1
#define RSEMI_VAL_STAT_RESULT_CFAC                                          2
#define RSEMI_VAL_STAT_RESULT_AVER                                          3

// rsemi_rngMeasStatProbability
#define RSEMI_VAL_SSTAT_PROB_0_01                                           3
#define RSEMI_VAL_SSTAT_PROB_0_1                                            0
#define RSEMI_VAL_SSTAT_PROB_1                                              1
#define RSEMI_VAL_SSTAT_PROB_10                                             2

// rsemi_rngDetector
#define RSEMI_VAL_BURS_DETECTOR_MEAN                                        0
#define RSEMI_VAL_BURS_DETECTOR_PEAK                                        1

// rsemi_rngMeasSEResultType
#define RSEMI_VAL_MEAS_SE_RESULT_FINAL1                                     0
#define RSEMI_VAL_MEAS_SE_RESULT_FINAL2                                     1
#define RSEMI_VAL_MEAS_SE_RESULT_FINAL3                                     2
#define RSEMI_VAL_MEAS_SE_RESULT_FINAL4                                     3
#define RSEMI_VAL_MEAS_SE_RESULT_FINAL5                                     4
#define RSEMI_VAL_MEAS_SE_RESULT_FINAL6                                     5

// rsemi_rngAcquisitionStatus
#define RSEMI_VAL_ACQUISITION_STATUS_INPROGRESS                             0
#define RSEMI_VAL_ACQUISITION_STATUS_COMPLETE                               1

// rsemi_rngReceiverMeasurementSequences
#define RSEMI_VAL_RECEIVER_MEAS_NONE                                        0
#define RSEMI_VAL_RECEIVER_MEAS_SCAN                                        1
#define RSEMI_VAL_RECEIVER_MEAS_BARG                                        2

// rsemi_rngStepsizeLinkType
#define RSEMI_VAL_FREQ_LINK_TYPE_OFF                                        0
#define RSEMI_VAL_FREQ_LINK_TYPE_COAR                                       1
#define RSEMI_VAL_FREQ_LINK_TYPE_FINE                                       2
#define RSEMI_VAL_FREQ_LINK_TYPE_MBW                                        3

// rsemi_rngServiceBBSignalType
#define RSEMI_VAL_BB_SIGNAL_TYPE_OFF                                        0
#define RSEMI_VAL_BB_SIGNAL_TYPE_AC                                         1
#define RSEMI_VAL_BB_SIGNAL_TYPE_DC                                         2

// rsemi_rngReferenceOscillatorTuningRange
#define RSEMI_VAL_ROSC_SMAL                                                 0
#define RSEMI_VAL_ROSC_WIDE                                                 1

// rsemi_rngSystemPreamplifierOption
#define RSEMI_VAL_PREAMP_B23                                                0
#define RSEMI_VAL_PREAMP_B24                                                1

// rsemi_rngADEMDetectorMode
#define RSEMI_VAL_ADEM_MODE_WRITE                                           0
#define RSEMI_VAL_ADEM_MODE_AVER                                            1
#define RSEMI_VAL_ADEM_MODE_MAXH                                            2

// rsemi_rngAnalogDemodulationResultUnit
#define RSEMI_VAL_ADEM_UNIT_PCT                                             0
#define RSEMI_VAL_ADEM_UNIT_DB                                              1

// rsemi_rngBBSignalPath
#define RSEMI_VAL_BB_SIG_PATH_I                                             0
#define RSEMI_VAL_BB_SIG_PATH_Q                                             1
#define RSEMI_VAL_BB_SIG_PATH_IQ                                            2

// rsemi_rngAmplitudePreselectorMode
#define RSEMI_VAL_PRESELECTOR_MODE_NARROW                                   0
#define RSEMI_VAL_PRESELECTOR_MODE_WIDE                                     1

// rsemi_rngAmplitudePreselectorFilterType
#define RSEMI_VAL_PRESELECTOR_FILTER_HIGHLOW                                0
#define RSEMI_VAL_PRESELECTOR_FILTER_BANDPASS                               1

// rsemi_rngFrame
#define RSEMI_VAL_FRAME_CURRENT                                             0
#define RSEMI_VAL_FRAME_ALL                                                 1

// rsemi_rngOutputTriggerDirection
#define RSEMI_VAL_DIRECTION_INPUT                                           0
#define RSEMI_VAL_DIRECTION_OUTPUT                                          1

// rsemi_rngOutputTriggerLevel
#define RSEMI_VAL_OUTPUT_LEVEL_LOW                                          0
#define RSEMI_VAL_OUTPUT_LEVEL_HIGH                                         1

// rsemi_rngOutputTriggerType
#define RSEMI_VAL_OUTPUT_TRIG_TYPE_DEVICE                                   0
#define RSEMI_VAL_OUTPUT_TRIG_TYPE_TARMED                                   1
#define RSEMI_VAL_OUTPUT_TRIG_TYPE_USER                                     2

// rsemi_rngSpectrumEmissionMaskMSRBandCategory
#define RSEMI_VAL_SEM_MSR_BAND_CATEGORY_1                                   1
#define RSEMI_VAL_SEM_MSR_BAND_CATEGORY_2                                   2
#define RSEMI_VAL_SEM_MSR_BAND_CATEGORY_3                                   3

// rsemi_rngSEMRangeLimitFunction
#define RSEMI_VAL_SEM_LIM_FUNC_OFF                                          0
#define RSEMI_VAL_SEM_LIM_FUNC_MAX                                          1

// rsemi_rngSEMRangeMultiLimitCalc
#define RSEMI_VAL_SEM_MULTLIM_CALC_NONE                                     0
#define RSEMI_VAL_SEM_MULTLIM_CALC_SUM                                      1
#define RSEMI_VAL_SEM_MULTLIM_CALC_MAX                                      2

// rsemi_rngIQBandwidthMode
#define RSEMI_VAL_IQ_BWID_MODE_MAN                                          0
#define RSEMI_VAL_IQ_BWID_MODE_AUTO                                         1
#define RSEMI_VAL_IQ_BWID_MODE_FFT                                          2

// rsemi_rngIQFFTAlgorithm
#define RSEMI_VAL_IQ_FFT_ALG_SING                                           0
#define RSEMI_VAL_IQ_FFT_ALG_AVER                                           1

// rsemi_rngIQFFTWindowType
#define RSEMI_VAL_IQ_WIN_TYPE_BLACK                                         0
#define RSEMI_VAL_IQ_WIN_TYPE_FLAT                                          1
#define RSEMI_VAL_IQ_WIN_TYPE_GAUS                                          2
#define RSEMI_VAL_IQ_WIN_TYPE_RECT                                          3
#define RSEMI_VAL_IQ_WIN_TYPE_P5                                            4

// rsemi_rngMSRTxTechnolgy
#define RSEMI_VAL_MSR_TX_TECHNOLOGY_GSM                                     0
#define RSEMI_VAL_MSR_TX_TECHNOLOGY_WCDMA                                   1
#define RSEMI_VAL_MSR_TX_TECHNOLOGY_LTE_1_40                                2
#define RSEMI_VAL_MSR_TX_TECHNOLOGY_LTE_3_00                                3
#define RSEMI_VAL_MSR_TX_TECHNOLOGY_LTE_5_00                                4
#define RSEMI_VAL_MSR_TX_TECHNOLOGY_LTE_10_00                               5
#define RSEMI_VAL_MSR_TX_TECHNOLOGY_LTE_15_00                               6
#define RSEMI_VAL_MSR_TX_TECHNOLOGY_LTE_20_00                               7
#define RSEMI_VAL_MSR_TX_TECHNOLOGY_USER                                    8

// rsemi_rngExternalGeneratorInterfaceType
#define RSEMI_VAL_INTERFACE_GPIB                                            0
#define RSEMI_VAL_INTERFACE_TCPIP                                           1

// rsemi_rngExtGenIntfType
#define RSEMI_VAL_EXT_GEN_INTF_GPIB                                         0
#define RSEMI_VAL_EXT_GEN_INTF_TTL                                          1

// rsemi_rngMinMax
#define RSEMI_VAL_MIN                                                       0
#define RSEMI_VAL_MAX                                                       1

// rsemi_rngFmTriggerSource
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_IMM                                   0
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_EXT                                   1
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_EXT2                                  2
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_EXT3                                  3
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_RFP                                   4
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_IFP                                   5
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_IQP                                   6
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_TIME                                  7
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_BBP                                   8
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_PSEN                                  9
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_AF                                    10
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_FM                                    11
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_AM                                    12
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_AMR                                   13
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_PM                                    14
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_GP0                                   15
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_GP1                                   16
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_GP2                                   17
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_GP3                                   18
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_GP4                                   19
#define RSEMI_VAL_ADEM_TRIGGER_SOURCE_GP5                                   20

// rsemi_rngFmeasDetectorType
#define RSEMI_VAL_FMEAS_DETECTOR_TYPE_OFF                                   0
#define RSEMI_VAL_FMEAS_DETECTOR_TYPE_AVER                                  1
#define RSEMI_VAL_FMEAS_DETECTOR_TYPE_CAV                                   2
#define RSEMI_VAL_FMEAS_DETECTOR_TYPE_CRMS                                  3
#define RSEMI_VAL_FMEAS_DETECTOR_TYPE_POS                                   4
#define RSEMI_VAL_FMEAS_DETECTOR_TYPE_QPE                                   5
#define RSEMI_VAL_FMEAS_DETECTOR_TYPE_ACPULSE                               6
#define RSEMI_VAL_FMEAS_DETECTOR_TYPE_ACSINE                                7

// rsemi_rngMSRADataEvaluation
#define RSEMI_VAL_MSRA_EVAL_TIME_DOM                                        0
#define RSEMI_VAL_MSRA_EVAL_FREQUENCY_DOM                                   1
#define RSEMI_VAL_MSRA_EVAL_IQ_DATA                                         2

// rsemi_rngAdemPhaseWrap
#define RSEMI_VAL_ADEM_UPHAS                                                0
#define RSEMI_VAL_ADEM_PHAS                                                 1

// rsemi_rngAdemOperatingMode
#define RSEMI_VAL_FM_FEED_AM_REL                                            0
#define RSEMI_VAL_FM_FEED_AM                                                1
#define RSEMI_VAL_FM_FEED_SPEC                                              2
#define RSEMI_VAL_FM_FEED_FM                                                3
#define RSEMI_VAL_FM_FEED_PM                                                4
#define RSEMI_VAL_FM_FEED_AMS_REL                                           5
#define RSEMI_VAL_FM_FEED_AMS                                               6
#define RSEMI_VAL_FM_FEED_FMS                                               7
#define RSEMI_VAL_FM_FEED_PMS                                               8
#define RSEMI_VAL_FM_FEED_FM_AFSP                                           9
#define RSEMI_VAL_FM_FEED_PM_AFSP                                           10
#define RSEMI_VAL_FM_FEED_AM_REL_AFSP                                       11
#define RSEMI_VAL_FM_FEED_RFP_AFSP                                          12
#define RSEMI_VAL_FSM_FEED_SUMM                                             13

// rsemi_rngTimeStampFrame
#define RSEMI_VAL_TSTAMP_FRAME_CURR                                         0
#define RSEMI_VAL_TSTAMP_FRAME_ALL                                          1

// rsemi_rngSystemPresetMode
#define RSEMI_VAL_PRESET_MODE_REC                                           0
#define RSEMI_VAL_PRESET_MODE_SAN                                           1

// rsemi_rngUpDown
#define RSEMI_VAL_UP                                                        1
#define RSEMI_VAL_DOWN                                                      0

// rsemi_rngTrackingGeneratorCalibration
#define RSEMI_VAL_TRACKING_GENERATOR_CAL_THROUGH                            0
#define RSEMI_VAL_TRACKING_GENERATOR_CAL_OPEN                               1

// rsemi_rngTrackingGeneratorMeasType
#define RSEMI_VAL_TRACKING_GENERATOR_MEAS_TYPE_REFLECTION                   0
#define RSEMI_VAL_TRACKING_GENERATOR_MEAS_TYPE_TRANSMISSION                 1

// rsemi_rngTrackingGeneratorPowerMode
#define RSEMI_VAL_TRACKING_GENERATOR_POWER_FIX                              0
#define RSEMI_VAL_TRACKING_GENERATOR_POWER_SWE                              1

// rsemi_rngSpectrogramLayout
#define RSEMI_VAL_SGR_LAYOUT_OFF                                            0
#define RSEMI_VAL_SGR_LAYOUT_FULL                                           1
#define RSEMI_VAL_SGR_LAYOUT_SPLIT                                          2

// rsemi_rngMeasPowerSet
#define RSEMI_VAL_MEAS_POW_SET_NORM                                         0
#define RSEMI_VAL_MEAS_POW_SET_COMB                                         1
#define RSEMI_VAL_MEAS_POW_SET_TPON                                         2

// rsemi_rngDirectPath
#define RSEMI_VAL_DIRECT_PATH_OFF                                           0
#define RSEMI_VAL_DIRECT_PATH_AUTO                                          1

// rsemi_rngTriggerIFPowerCoupling
#define RSEMI_VAL_TRIGGER_IFP_COUPLING_DC                                   0
#define RSEMI_VAL_TRIGGER_IFP_COUPLING_DCL                                  1
#define RSEMI_VAL_TRIGGER_IFP_COUPLING_AC                                   2

// rsemi_rngCalibrationAutoAveraging
#define RSEMI_VAL_AVERAGING_AUTO                                            0
#define RSEMI_VAL_AVERAGING_MAN                                             1

// rsemi_rngRFSwitchInput
#define RSEMI_VAL_RF_SWITCH_OFF                                             0
#define RSEMI_VAL_RF_SWITCH_INPUT1                                          1
#define RSEMI_VAL_RF_SWITCH_INPUT2                                          2

// rsemi_rngSpectrogramLayoutQueryWindowType
#define RSEMI_VAL_SPEM_LAYOUT_TYPE_SPEC                                     0
#define RSEMI_VAL_SPEM_LAYOUT_TYPE_SGRAM                                    1
#define RSEMI_VAL_SPEM_LAYOUT_TYPE_PSP                                      2
#define RSEMI_VAL_SPEM_LAYOUT_TYPE_MTABLE                                   3

// rsemi_rngReceiverLayoutQueryWindowType
#define RSEMI_VAL_RECEIVER_LAYOUT_TYPE_BGR                                  0
#define RSEMI_VAL_RECEIVER_LAYOUT_TYPE_DIAG                                 1
#define RSEMI_VAL_RECEIVER_LAYOUT_TYPE_FACC                                 2
#define RSEMI_VAL_RECEIVER_LAYOUT_TYPE_FME                                  3
#define RSEMI_VAL_RECEIVER_LAYOUT_TYPE_IFAN                                 4
#define RSEMI_VAL_RECEIVER_LAYOUT_TYPE_IFSG                                 5
#define RSEMI_VAL_RECEIVER_LAYOUT_TYPE_MTABLE                               6
#define RSEMI_VAL_RECEIVER_LAYOUT_TYPE_PEAKLIST                             7
#define RSEMI_VAL_RECEIVER_LAYOUT_TYPE_PRES                                 8
#define RSEMI_VAL_RECEIVER_LAYOUT_TYPE_SCAN                                 9
#define RSEMI_VAL_RECEIVER_LAYOUT_TYPE_SCSG                                 10

// rsemi_rngTestReportChannelType
#define RSEMI_VAL_TREP_CHANNEL_TYPE_CAPD                                    0
#define RSEMI_VAL_TREP_CHANNEL_TYPE_IQ                                      1
#define RSEMI_VAL_TREP_CHANNEL_TYPE_REC                                     2
#define RSEMI_VAL_TREP_CHANNEL_TYPE_RTIM                                    3
#define RSEMI_VAL_TREP_CHANNEL_TYPE_SAN                                     4

// rsemi_rngPeakListPeakTrace
#define RSEMI_VAL_PEAK_LIST_TRACE1                                          1
#define RSEMI_VAL_PEAK_LIST_TRACE2                                          2
#define RSEMI_VAL_PEAK_LIST_TRACE3                                          3
#define RSEMI_VAL_PEAK_LIST_TRACE4                                          4
#define RSEMI_VAL_PEAK_LIST_TRACE5                                          5
#define RSEMI_VAL_PEAK_LIST_TRACE6                                          6

// rsemi_rngTimeDomainMode
#define RSEMI_VAL_TDOPTIM_AUTO                                              0
#define RSEMI_VAL_TDOPTIM_DYNAMIC                                           1
/* END GENERATE */
	
/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSEMI_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSEMI_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSEMI_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSEMI_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *---------------- Constant definition  ------------------------------------*
 ****************************************************************************/	
/****************************************************************************
 *------------------------ Attribute Value Defines -------------------------*
 ****************************************************************************/
#define RSEMI_VAL_RECEIVER_FREQUENCY_CENTER 1
#define RSEMI_VAL_RECEIVER_FREQUENCY_STEP   2

#define	RSEMI_VAL_MARKER_SEARCH_HIGHEST             1
#define RSEMI_VAL_MARKER_SEARCH_MINIMUM             2
#define RSEMI_VAL_MARKER_SEARCH_NEXT_PEAK           3
#define RSEMI_VAL_MARKER_SEARCH_NEXT_PEAK_LEFT      4
#define RSEMI_VAL_MARKER_SEARCH_NEXT_PEAK_RIGHT     5
#define RSEMI_VAL_MARKER_SEARCH_NEXT_MINIMUM        6
#define RSEMI_VAL_MARKER_SEARCH_NEXT_MINIMUM_LEFT   7
#define RSEMI_VAL_MARKER_SEARCH_NEXT_MINIMUM_RIGHT  8

#define	RSEMI_VAL_DELTA_MARKER_SEARCH_HIGHEST             1
#define RSEMI_VAL_DELTA_MARKER_SEARCH_MINIMUM             2
#define RSEMI_VAL_DELTA_MARKER_SEARCH_NEXT_PEAK           3
#define RSEMI_VAL_DELTA_MARKER_SEARCH_NEXT_PEAK_LEFT      4
#define RSEMI_VAL_DELTA_MARKER_SEARCH_NEXT_PEAK_RIGHT     5
#define RSEMI_VAL_DELTA_MARKER_SEARCH_NEXT_MINIMUM        6
#define RSEMI_VAL_DELTA_MARKER_SEARCH_NEXT_MINIMUM_LEFT   7
#define RSEMI_VAL_DELTA_MARKER_SEARCH_NEXT_MINIMUM_RIGHT  8
	
#define RSEMI_VAL_LOW  0
#define RSEMI_VAL_UPP  1

#define RSEMI_VAL_HCOP_ALL   0
#define RSEMI_VAL_HCOP_TABLE 1
#define RSEMI_VAL_HCOP_TRACE 2

#define RSEMI_VAL_TRIG_TV_HORIZONTAL 3

#define RSEMI_VAL_LIMIT_LOWER 0
#define RSEMI_VAL_LIMIT_UPPER 1
#define RSEMI_VAL_LIMIT_CONTROL 2

#define RSEMI_VAL_LIMIT_MOVE_OFFSET 0
#define RSEMI_VAL_LIMIT_MOVE_SHIFT  1


#define RSEMI_VAL_LINE_THR     0
#define RSEMI_VAL_LINE_DISPLAY 1
#define RSEMI_VAL_LINE_FREQ    2
#define RSEMI_VAL_LINE_TIME    3

#define RSEMI_VAL_HCOPY_DEST_BMP 0
#define RSEMI_VAL_HCOPY_DEST_WMF 1
#define RSEMI_VAL_HCOPY_DEST_EMF 2
#define RSEMI_VAL_HCOPY_DEST_CLP 3
#define RSEMI_VAL_HCOPY_DEST_PRN 4
#define RSEMI_VAL_HCOPY_DEST_JPG 5
#define RSEMI_VAL_HCOPY_DEST_PNG 6
#define RSEMI_VAL_HCOPY_DEST_PDF 7 
#define RSEMI_VAL_HCOPY_DEST_RTF 8 
#define RSEMI_VAL_HCOPY_DEST_DOC 9 

#define RSEMI_VAL_AUTOSCALE_ALL 0
#define RSEMI_VAL_AUTOSCALE_A   1
#define RSEMI_VAL_AUTOSCALE_B   2
#define RSEMI_VAL_AUTOSCALE_C   3
#define RSEMI_VAL_AUTOSCALE_D   4

#define RSEMI_VAL_EATT_OFF  0
#define RSEMI_VAL_EATT_AUTO 1
#define RSEMI_VAL_EATT_MAN  2

#define RSEMI_VAL_ADJ_ALL  0
#define RSEMI_VAL_ADJ_FREQ 1
#define RSEMI_VAL_ADJ_LEV  2

#define RSEMI_VAL_FILE_ITEMS_NONE          0
#define RSEMI_VAL_FILE_ITEMS_DEFAULT       1
#define RSEMI_VAL_FILE_ITEMS_ALL           2
#define RSEMI_VAL_FILE_ITEMS_HWSETTINGS    3
#define RSEMI_VAL_FILE_ITEMS_ALLTRACES     4
#define RSEMI_VAL_FILE_ITEMS_ALLLINES      5
#define RSEMI_VAL_FILE_ITEMS_ALLTRAN       6

#define RSEMI_VAL_FORMAT_ASC  0
#define RSEMI_VAL_FORMAT_REAL 1

#define RSEMI_VAL_INSTRUMENT_SETTING_FREQUENCY_CENTER 1
#define RSEMI_VAL_INSTRUMENT_SETTING_FREQUENCY_STEP   2
#define RSEMI_VAL_INSTRUMENT_SETTING_REFERENCE_LEVEL  3

#define RSEMI_VAL_SSTAT_RESULT_MEAN  0
#define RSEMI_VAL_SSTAT_RESULT_PEAK  1
#define RSEMI_VAL_SSTAT_RESULT_CREST 2
#define RSEMI_VAL_SSTAT_RESULT_AVERAGE 3

#define RSEMI_VAL_BURS_MEAS_MEAN 0
#define RSEMI_VAL_BURS_MEAS_PEAK 1

/*- Instrument specific attribute value definitions --------------------*/

#define RSEMI_VAL_NAV           -1    
    
#define RSEMI_VAL_TRIGGER_TX 0
#define RSEMI_VAL_TRIGGER_RX 1
	
#define RSEMI_VAL_PAYLOAD_TYPE_DEFAULT  0
#define RSEMI_VAL_PAYLOAD_TYPE_ALL_ZERO 1

#define RSEMI_VAL_LIMIT_CONT   0
#define RSEMI_VAL_LIMIT_LOW    1    
#define RSEMI_VAL_LIMIT_UPP    2
	
#define RSEMI_VAL_TRACE1     1
#define RSEMI_VAL_TRACE2     2
#define RSEMI_VAL_TRACE3     3
#define RSEMI_VAL_TRACE4     4 
#define RSEMI_VAL_TRACE5     5
#define RSEMI_VAL_TRACE6     6

	
#define RSEMI_VAL_SPECM_MARK_MAX_PEAK      0
#define RSEMI_VAL_SPECM_MARK_MAX_NEXT      1
#define RSEMI_VAL_SPECM_MARK_MAX_LEFT      2
#define RSEMI_VAL_SPECM_MARK_MAX_RIGHT     3
#define RSEMI_VAL_SPECM_MARK_MIN_PEAK      4
#define RSEMI_VAL_SPECM_MARK_MIN_NEXT      5
#define RSEMI_VAL_SPECM_MARK_MIN_LEFT      6
#define RSEMI_VAL_SPECM_MARK_MIN_RIGHT     7
#define RSEMI_VAL_SPECM_MARK_Y_MAX_PEAK    8
#define RSEMI_VAL_SPECM_MARK_Y_MAX_NEXT    9
#define RSEMI_VAL_SPECM_MARK_Y_MAX_ABOVE  10
#define RSEMI_VAL_SPECM_MARK_Y_MAX_BELOW  11
#define RSEMI_VAL_SPECM_MARK_Y_MIN_PEAK   12
#define RSEMI_VAL_SPECM_MARK_Y_MIN_NEXT   13
#define RSEMI_VAL_SPECM_MARK_Y_MIN_ABOVE  14
#define RSEMI_VAL_SPECM_MARK_Y_MIN_BELOW  15
#define RSEMI_VAL_SPECM_MARK_XY_MAX       16
#define RSEMI_VAL_SPECM_MARK_XY_MIN       17
#define RSEMI_VAL_SPECM_MARK_Y_TRIGGER    18
	
#define	RSEMI_VAL_SPECM_FRAME_CURRENT      0
#define RSEMI_VAL_SPECM_FRAME_ALL     	   1

#define RSEMI_VAL_LOWER  0
#define RSEMI_VAL_UPPER  1
	
#define RSEMI_VAL_REG_COND   3
#define RSEMI_VAL_REG_EVENT  4
	
#define RSEMI_VAL_SPECM_TSTAMP_CURR 0
#define RSEMI_VAL_SPECM_TSTAMP_ALL  1

#define RSEMI_VAL_SAN_CREATE 0
#define RSEMI_VAL_SAN_SELECT 1
#define RSEMI_VAL_SAN_DELETE 2

#define RSEMI_VAL_COUPLING_RBW        0
#define RSEMI_VAL_COUPLING_VBW        1
#define RSEMI_VAL_COUPLING_SWEEP_TIME 2

#define RSEMI_VAL_COUPLING_RATIO_RBW 0
#define RSEMI_VAL_COUPLING_RATIO_VBW 1

#define RSEMI_VAL_TRG_BBP 3
#define RSEMI_VAL_TRG_PSE 4

#define RSEMI_VAL_TDOM_PEAK 0
#define RSEMI_VAL_TDOM_RMS  1
#define RSEMI_VAL_TDOM_MEAN 2
#define RSEMI_VAL_TDOM_SDEV 3

#define RSEMI_VAL_ACP_TX  0
#define RSEMI_VAL_ACP_ADJ 1
#define RSEMI_VAL_ACP_ALT 2

#define RSEMI_VAL_OPER_SELECT  0
#define RSEMI_VAL_OPER_SAVE    1
#define RSEMI_VAL_OPER_RECALL  2
#define RSEMI_VAL_OPER_DELETE  3

#define RSEMI_VAL_MEM_SAVE    0
#define RSEMI_VAL_MEM_RECALL  1
#define RSEMI_VAL_MEM_DELETE  2
#define RSEMI_VAL_MEM_STARTUP 3

#define RSEMI_VAL_TDOM_RESULT          0
#define RSEMI_VAL_TDOM_AVG_RESULT      1
#define RSEMI_VAL_TDOM_MAX_HOLD_RESULT 2

#define RSEMI_VAL_USTD_SET  0
#define RSEMI_VAL_USTD_SAVE 1
#define RSEMI_VAL_USTD_DEL  2

#define RSEMI_VAL_MIXER_LOSS_AVER 0
#define RSEMI_VAL_MIXER_LOSS_TABL 1

#define RSEMI_VAL_FILE_NEW        0
#define RSEMI_VAL_FILE_COPY       1
#define RSEMI_VAL_FILE_RENAME     2
#define RSEMI_VAL_FILE_DELETE     3
#define RSEMI_VAL_FILE_RDIR       4
#define RSEMI_VAL_FILE_FORMAT     5
#define RSEMI_VAL_FILE_CDIR       6
#define RSEMI_VAL_FILE_CDISC      7
#define RSEMI_VAL_FILE_DELETE_IMM 8

#define RSEMI_VAL_SSTAT_OFF  0
#define RSEMI_VAL_SSTAT_APD  1
#define RSEMI_VAL_SSTAT_CCDF 2

#define RSEMI_VAL_WFILTER_ALL 0
#define RSEMI_VAL_WFILTER_ADJ 1
#define RSEMI_VAL_WFILTER_ALT 2
#define RSEMI_VAL_WFILTER_TX  3

#define RSEMI_VAL_USER_PORT_INP 0
#define RSEMI_VAL_USER_PORT_OUT 1

#define RSEMI_VAL_OFF 0
#define RSEMI_VAL_ON  1
#define RSEMI_VAL_ALL 2

#define RSEMI_VAL_TIME_STAMP_CURR 0
#define RSEMI_VAL_TIME_STAMP_ALL  1

#define RSEMI_VAL_COUPLING_ATTENUATION  0
#define RSEMI_VAL_COUPLING_BANDWIDTH    1
#define RSEMI_VAL_COUPLING_CENTER       2
#define RSEMI_VAL_COUPLING_DEMODULATION 3
#define RSEMI_VAL_COUPLING_GAIN         4
#define RSEMI_VAL_COUPLING_LIMIT        5
#define RSEMI_VAL_COUPLING_MARKER       6
#define RSEMI_VAL_COUPLING_PRESELECTOR  7
#define RSEMI_VAL_COUPLING_SPAN         8

#define RSEMI_VAL_TEMPLATE_LOAD  	 0
#define RSEMI_VAL_TEMPLATE_SAVE  	 1
#define RSEMI_VAL_TEMPLATE_DELETE	 2

#define RSEMI_VAL_TREP_NEW             0
#define RSEMI_VAL_TREP_APPEND          1
#define RSEMI_VAL_TREP_REMOVE          2
#define RSEMI_VAL_TREP_REMOVE_ALL      3

#define RSEMI_VAL_TREP_DSET_NONE   0
#define RSEMI_VAL_TREP_DSET_INVERT 1
#define RSEMI_VAL_TREP_DSET_ALL	   2


#define RSEMI_VAL_PROBE_OFF 0
#define RSEMI_VAL_PROBE_1   1
#define RSEMI_VAL_PROBE_2   2

#define RSEMI_VAL_MANUAL	2

#define RSEMI_VAL_STAT_REG_PRESET 0

#define RSEMI_VAL_STAT_REG_QUERY_COND  0
#define RSEMI_VAL_STAT_REG_QUERY_EVENT 1

#define RSEMI_VAL_FAST_SWEEP_NORMAL 0
#define RSEMI_VAL_FAST_SWEEP_FAST 1
/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/
ViStatus _VI_FUNC rsemi_init (ViRsrc resourceName, ViBoolean IDQuery,
                              ViBoolean resetDevice, ViPSession instrumentHandle);
ViStatus _VI_FUNC rsemi_InitWithOptions (ViRsrc resourceName, ViBoolean IDQuery,
                                         ViBoolean resetDevice,
                                         ViString optionString,
                                         ViPSession instrumentHandle);
ViStatus _VI_FUNC rsemi_SetSANMode (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ConfigureSpectrumDisplay (ViSession instrumentHandle,
                                                  ViInt32 operation,
                                                  ViInt32 spectrumDisplay);
ViStatus _VI_FUNC rsemi_ConfigureSpectrumFrequencyStartStop
             (ViSession instrumentHandle, ViInt32 window, ViReal64 startFrequency,
              ViReal64 stopFrequency);
ViStatus _VI_FUNC rsemi_ConfigureSpectrumFrequencyStartMinMax
             (ViSession instrumentHandle, ViInt32 window, ViInt32 minMax);
ViStatus _VI_FUNC rsemi_QuerySpectrumFrequencyStartMinMax
             (ViSession instrumentHandle, ViInt32 window, ViPReal64 minimum,
              ViPReal64 maximum);
ViStatus _VI_FUNC rsemi_ConfigureSpectrumFrequencyStopMinMax
             (ViSession instrumentHandle, ViInt32 window, ViInt32 minMax);
ViStatus _VI_FUNC rsemi_QuerySpectrumFrequencyStopMinMax (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViPReal64 minimum,
                                                          ViPReal64 maximum);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyCenter (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViReal64 centerFrequency);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyCenterSpan (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViReal64 centerFrequency,
                                                      ViReal64 span);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyStepSize (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViReal64 stepSize);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyStepSizeAuto (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViBoolean stepSizeAuto);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyCouplingFactor (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViInt32 coupling,
                                                          ViInt32 couplingFactor);
ViStatus _VI_FUNC rsemi_ConfigureFrequencySpanFull (ViSession instrumentHandle,
                                                    ViInt32 window);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyZeroSpan (ViSession instrumentHandle,
                                                    ViInt32 window);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyOffset (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViReal64 frequencyOffset);
ViStatus _VI_FUNC rsemi_ConfigureSpectrumFrequencyMode (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViInt32 frequencyMode);
ViStatus _VI_FUNC rsemi_ConfigureSweepTime (ViSession instrumentHandle,
                                            ViInt32 window, ViBoolean sweepTimeAuto,
                                            ViReal64 sweepTime);
ViStatus _VI_FUNC rsemi_ConfigureSweepCouplingAuto (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViInt32 sweepCoupling);
ViStatus _VI_FUNC rsemi_ConfigureSweepCoupling (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViInt32 sweepCoupling,
                                                ViReal64 couplingValue);
ViStatus _VI_FUNC rsemi_ConfigureSweepCouplingAdvanced (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViInt32 ratioSelection,
                                                        ViReal64 couplingValue);
ViStatus _VI_FUNC rsemi_ConfigureBandwidthRatioMinMax (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViInt32 minMax);
ViStatus _VI_FUNC rsemi_QueryBandwidthRatioMinMax (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViPReal64 minimum,
                                                   ViPReal64 maximum);
ViStatus _VI_FUNC rsemi_ConfigureIFAnalysisResolutionBandwidth
             (ViSession instrumentHandle, ViReal64 bandwidth);
ViStatus _VI_FUNC rsemi_ConfigureFilterType (ViSession instrumentHandle,
                                             ViInt32 window, ViInt32 filterType);
ViStatus _VI_FUNC rsemi_ConfigureVBWMode (ViSession instrumentHandle,
                                          ViInt32 window, ViInt32 videoFilterType);
ViStatus _VI_FUNC rsemi_ConfigureFFTFilterMode (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViInt32 FFTFilterMode);
ViStatus _VI_FUNC rsemi_ConfigureAveraging (ViSession instrumentHandle,
                                            ViInt32 window, ViInt32 trace,
                                            ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureAveragingType (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViInt32 averagingType);
ViStatus _VI_FUNC rsemi_ConfigureAveragingCount (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32 count);
ViStatus _VI_FUNC rsemi_ConfigureSpectrumAcquisition (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViBoolean sweepModeContinuous,
                                                      ViInt32 numberOfSweeps);
ViStatus _VI_FUNC rsemi_ConfigureVerticalScale (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViInt32 verticalScale);
ViStatus _VI_FUNC rsemi_ConfigureHorizontalScale (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViInt32 horizontalScale);
ViStatus _VI_FUNC rsemi_ConfigureSweepPoints (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 sweepPoints);
ViStatus _VI_FUNC rsemi_QuerySweepPoints (ViSession instrumentHandle,
                                          ViInt32 window, ViPInt32 sweepPoints);
ViStatus _VI_FUNC rsemi_ConfigureSweepOptimization (ViSession instrumentHandle,
                                                    ViInt32 sweepOptimization);
ViStatus _VI_FUNC rsemi_ConfigureSweepType (ViSession instrumentHandle,
                                            ViInt32 sweepType);
ViStatus _VI_FUNC rsemi_ConfigureAttenuation (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViBoolean attenuationAuto,
                                              ViInt32 attenuation);
ViStatus _VI_FUNC rsemi_ConfigureIFAttenuation (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViBoolean attenuationAuto,
                                                ViInt32 attenuation);
ViStatus _VI_FUNC rsemi_ConfigureAttenuationLimiter (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViBoolean attenuationLimiter);
ViStatus _VI_FUNC rsemi_ConfigureAttenuationMinMax (ViSession instrumentHandle,
                                                    ViInt32 window, ViInt32 minMax);
ViStatus _VI_FUNC rsemi_ConfigureAttenuationUpDown (ViSession instrumentHandle,
                                                    ViInt32 window, ViInt32 upDown);
ViStatus _VI_FUNC rsemi_QueryAttenuationMinMax (ViSession instrumentHandle,
                                                ViInt32 window, ViPReal64 minimum,
                                                ViPReal64 maximum);
ViStatus _VI_FUNC rsemi_ConfigureReferenceLevel (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViReal64 referenceLevel);
ViStatus _VI_FUNC rsemi_ConfigureReferenceLevelOffset (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViReal64 referenceLevelOffset);
ViStatus _VI_FUNC rsemi_ConfigureLevel (ViSession instrumentHandle, ViInt32 window,
                                        ViInt32 amplitudeUnits,
                                        ViInt32 inputImpedance,
                                        ViReal64 referenceLevel,
                                        ViReal64 referenceLevelOffset,
                                        ViBoolean attenuationAuto,
                                        ViInt32 attenuation);
ViStatus _VI_FUNC rsemi_ConfigureAttenuationMode (ViSession instrumentHandle,
                                                  ViInt32 window, ViInt32 mode);
ViStatus _VI_FUNC rsemi_ConfigureReferenceLevelCoupling (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViBoolean coupledReferenceLevel);
ViStatus _VI_FUNC rsemi_ConfigureUnitPower (ViSession instrumentHandle,
                                            ViInt32 window, ViInt32 unitPower);
ViStatus _VI_FUNC rsemi_DuplicateMeasurementChannel (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ReplaceMeasurementChannel (ViSession instrumentHandle,
                                                   ViString oldChannelName,
                                                   ViInt32 channelType,
                                                   ViString newChannelName);
ViStatus _VI_FUNC rsemi_RenameMeasurementChannel (ViSession instrumentHandle,
                                                  ViString oldChannelName,
                                                  ViString newChannelName);
ViStatus _VI_FUNC rsemi_PresetMeasurementChannel (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_QueryAllMeasurementChannels (ViSession instrumentHandle,
                                                     ViInt32 bufferSize,
                                                     ViChar _VI_FAR channelList[]);
ViStatus _VI_FUNC rsemi_ConfigureNoiseSource (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViBoolean noiseSource);
ViStatus _VI_FUNC rsemi_ConfigureIFOutputSource (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViInt32 outputSource);
ViStatus _VI_FUNC rsemi_ConfigureOutputCoupling (ViSession instrumentHandle,
                                                 ViInt32 output,
                                                 ViBoolean coupling);
ViStatus _VI_FUNC rsemi_ConfigureOutputVoltage (ViSession instrumentHandle,
                                                ViInt32 output,
                                                ViReal64 lowerVoltage,
                                                ViReal64 upperVoltage);
ViStatus _VI_FUNC rsemi_ConfigureACCutoffFrequency (ViSession instrumentHandle,
                                                    ViInt32 output,
                                                    ViReal64 frequency);
ViStatus _VI_FUNC rsemi_ConfigureIFOutput (ViSession instrumentHandle,
                                           ViInt32 output, ViReal64 frequency,
                                           ViReal64 lowerVoltage,
                                           ViReal64 upperVoltage);
ViStatus _VI_FUNC rsemi_ConfigureVideoOutput (ViSession instrumentHandle,
                                              ViInt32 output, ViInt32 mode,
                                              ViInt32 coupling, ViInt32 gainMode,
                                              ViReal64 gainValue,
                                              ViReal64 ACCutoffFrequency,
                                              ViBoolean lowpassState,
                                              ViReal64 lowpassFrequency,
                                              ViReal64 lowerVoltage,
                                              ViReal64 upperVoltage,
                                              ViBoolean phones);
ViStatus _VI_FUNC rsemi_ConfigureAMOutput (ViSession instrumentHandle,
                                           ViInt32 output, ViReal64 scale,
                                           ViReal64 ACCutoffFrequency,
                                           ViBoolean lowpassState,
                                           ViReal64 lowpassFrequency,
                                           ViReal64 lowerVoltage,
                                           ViReal64 upperVoltage, ViBoolean phones);
ViStatus _VI_FUNC rsemi_ConfigureFMOutput (ViSession instrumentHandle,
                                           ViInt32 output, ViInt32 coupling,
                                           ViReal64 scale,
                                           ViReal64 ACCutoffFrequency,
                                           ViBoolean lowpassState,
                                           ViReal64 lowpassFrequency,
                                           ViReal64 lowerVoltage,
                                           ViReal64 upperVoltage, ViBoolean phones);
ViStatus _VI_FUNC rsemi_ConfigurePMOutput (ViSession instrumentHandle,
                                           ViInt32 output, ViInt32 coupling,
                                           ViReal64 scale,
                                           ViReal64 ACCutoffFrequency,
                                           ViBoolean lowpassState,
                                           ViReal64 lowpassFrequency,
                                           ViReal64 lowerVoltage,
                                           ViReal64 upperVoltage, ViBoolean phones);
ViStatus _VI_FUNC rsemi_ConfigureLowPassFilter (ViSession instrumentHandle,
                                                ViInt32 output, ViBoolean state,
                                                ViReal64 frequency);
ViStatus _VI_FUNC rsemi_QueryIFOutputSideband (ViSession instrumentHandle,
                                               ViPInt32 sideband);
ViStatus _VI_FUNC rsemi_ConfigureTriggerInput (ViSession instrumentHandle,
                                               ViInt32 port);
ViStatus _VI_FUNC rsemi_ConfigureTriggerOutput (ViSession instrumentHandle,
                                                ViInt32 port, ViInt32 outputType,
                                                ViInt32 level, ViReal64 length);
ViStatus _VI_FUNC rsemi_GenerateTriggerPulse (ViSession instrumentHandle,
                                              ViInt32 port);
ViStatus _VI_FUNC rsemi_ConfigureProbePowerSupply (ViSession instrumentHandle,
                                                   ViInt32 probePower);
ViStatus _VI_FUNC rsemi_ConfigureTrace (ViSession instrumentHandle, ViInt32 window,
                                        ViInt32 trace, ViInt32 traceType);
ViStatus _VI_FUNC rsemi_ConfigureTraceDetector (ViSession instrumentHandle,
                                                ViInt32 window, ViInt32 trace,
                                                ViBoolean detectorTypeAuto,
                                                ViInt32 detectorType);
ViStatus _VI_FUNC rsemi_ConfigureTraceResetBehavior (ViSession instrumentHandle,
                                                     ViInt32 window, ViInt32 trace,
                                                     ViBoolean resetAtChange);
ViStatus _VI_FUNC rsemi_ConfigureTraceExport (ViSession instrumentHandle,
                                              ViInt32 exportMode,
                                              ViBoolean exportHeader,
                                              ViInt32 decimalSeparator);
ViStatus _VI_FUNC rsemi_StoreSANTraceToFile (ViSession instrumentHandle,
                                             ViInt32 window, ViInt32 trace,
                                             ViString fileName);
ViStatus _VI_FUNC rsemi_TraceIQSet (ViSession instrumentHandle, ViInt32 window,
                                    ViReal64 samplingRate, ViInt32 triggerMode,
                                    ViInt32 triggerSlope, ViReal64 bandwidth,
                                    ViInt32 pretriggerSamples, ViInt32 noOfSamples);
ViStatus _VI_FUNC rsemi_TraceIQSamplingRate (ViSession instrumentHandle,
                                             ViInt32 window, ViReal64 samplingRate);
ViStatus _VI_FUNC rsemi_TraceIQRecordLength (ViSession instrumentHandle,
                                             ViInt32 recordLength);
ViStatus _VI_FUNC rsemi_TraceIQAveraging (ViSession instrumentHandle,
                                          ViInt32 window, ViBoolean averageState,
                                          ViInt32 averageCount);
ViStatus _VI_FUNC rsemi_ConfigureTraceIQDataAnalyzerEnabled
             (ViSession instrumentHandle, ViInt32 window,
              ViBoolean IQDataAnalyzerEnabled);
ViStatus _VI_FUNC rsemi_ConfigureTraceIQDataAcquisition (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViBoolean traceState);
ViStatus _VI_FUNC rsemi_ConfigureTraceIQGate (ViSession instrumentHandle,
                                              ViBoolean gate, ViInt32 type,
                                              ViInt32 gateLength, ViInt32 gateGap,
                                              ViInt32 numberOfGatePeriods);
ViStatus _VI_FUNC rsemi_ConfigureTraceIQDataDisplayType (ViSession instrumentHandle,
                                                         ViInt32 displayType);
ViStatus _VI_FUNC rsemi_ConfigureIQBandwidth (ViSession instrumentHandle,
                                              ViInt32 mode, ViReal64 resolution);
ViStatus _VI_FUNC rsemi_ConfigureIQMaximumBW (ViSession instrumentHandle,
                                              ViBoolean maximumBWExtension,
                                              ViInt32 mode, ViReal64 bandwidth);
ViStatus _VI_FUNC rsemi_ConfigureIQFFTMode (ViSession instrumentHandle,
                                            ViInt32 algorithm, ViInt32 length,
                                            ViInt32 windowType,
                                            ViReal64 windowOverlap,
                                            ViInt32 windowLength);
ViStatus _VI_FUNC rsemi_ConfigureIQAveragePowerConsumption
             (ViSession instrumentHandle, ViBoolean state, ViReal64 factorA,
              ViReal64 factorB);
ViStatus _VI_FUNC rsemi_QueryIQAveragePowerConsumptionResult
             (ViSession instrumentHandle, ViPReal64 result);
ViStatus _VI_FUNC rsemi_QueryTraceIQFilterBandwidth (ViSession instrumentHandle,
                                                     ViPReal64 filterBandwidth);
ViStatus _VI_FUNC rsemi_TraceIQSwapIQ (ViSession instrumentHandle,
                                       ViBoolean swapIQ);
ViStatus _VI_FUNC rsemi_LoadIQData (ViSession instrumentHandle, ViString fileName);
ViStatus _VI_FUNC rsemi_StoreIQData (ViSession instrumentHandle, ViString fileName);
ViStatus _VI_FUNC rsemi_ConfigureIQDataExportFileDescription
             (ViSession instrumentHandle, ViString description);
ViStatus _VI_FUNC rsemi_CopyTrace (ViSession instrumentHandle, ViInt32 window,
                                   ViInt32 destinationTrace, ViInt32 sourceTrace);
ViStatus _VI_FUNC rsemi_ConfigureSubtractTraces (ViSession instrumentHandle,
                                                 ViInt32 window, ViReal64 position,
                                                 ViInt32 mode,
                                                 ViBoolean traceMathState);
ViStatus _VI_FUNC rsemi_SubtractTraces (ViSession instrumentHandle, ViInt32 window,
                                        ViInt32 trace2);
ViStatus _VI_FUNC rsemi_ConfigureSpectrumMarker (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32 marker,
                                                 ViBoolean markerEnabled,
                                                 ViInt32 trace);
ViStatus _VI_FUNC rsemi_ConfigureReferenceMarker (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViInt32 deltaMarker,
                                                  ViInt32 referenceMarker);
ViStatus _VI_FUNC rsemi_ConfigureSignalTrack (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViBoolean signalTrackEnabled,
                                              ViReal64 signalTrackBandwidth,
                                              ViReal64 signalTrackThreshold,
                                              ViInt32 trace);
ViStatus _VI_FUNC rsemi_ConfigureSignalTrackBandwidthMinMax
             (ViSession instrumentHandle, ViInt32 window, ViInt32 minMax);
ViStatus _VI_FUNC rsemi_QuerySignalTrackBandwidthMinMax (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViPReal64 minimum,
                                                         ViPReal64 maximum);
ViStatus _VI_FUNC rsemi_DisableAllSpectrumMarkers (ViSession instrumentHandle,
                                                   ViInt32 window);
ViStatus _VI_FUNC rsemi_MarkerSearch (ViSession instrumentHandle, ViInt32 window,
                                      ViInt32 marker, ViInt32 markerSearch);
ViStatus _VI_FUNC rsemi_MarkerPeakAuto (ViSession instrumentHandle, ViInt32 window,
                                        ViInt32 markerSearch, ViBoolean autoPeak);
ViStatus _VI_FUNC rsemi_MoveSpectrumMarker (ViSession instrumentHandle,
                                            ViInt32 window, ViInt32 marker,
                                            ViReal64 markerPosition);
ViStatus _VI_FUNC rsemi_SetInstrumentFromMarker (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32 marker,
                                                 ViInt32 instrumentSetting);
ViStatus _VI_FUNC rsemi_LinkMarkerToAnotherMarker (ViSession instrumentHandle,
                                                   ViInt32 firstMarker,
                                                   ViInt32 secondMarker,
                                                   ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureSpectrumMarkerZoom (ViSession instrumentHandle,
                                                     ViInt32 window, ViInt32 marker,
                                                     ViReal64 markerZoom,
                                                     ViUInt32 timeout);
ViStatus _VI_FUNC rsemi_LinkSpectrumMarkerAndDeltamarker (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViInt32 marker,
                                                          ViBoolean state);
ViStatus _VI_FUNC rsemi_LinkAllMarkers (ViSession instrumentHandle,
                                        ViInt32 linkMarkers);
ViStatus _VI_FUNC rsemi_QuerySpectrumMarker (ViSession instrumentHandle,
                                             ViInt32 window, ViInt32 marker,
                                             ViPReal64 markerPosition,
                                             ViPReal64 markerAmplitude);
ViStatus _VI_FUNC rsemi_ConfigureMarkerStepSize (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32 stepSize);
ViStatus _VI_FUNC rsemi_ProbabilityMarkerPosition (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 marker,
                                                   ViReal64 probability);
ViStatus _VI_FUNC rsemi_ConfigureMarkerBandPower (ViSession instrumentHandle,
                                                  ViBoolean bandPowerEnabled,
                                                  ViInt32 displayMode,
                                                  ViReal64 span);
ViStatus _VI_FUNC rsemi_QueryMarkerBandPower (ViSession instrumentHandle,
                                              ViPReal64 result);
ViStatus _VI_FUNC rsemi_ConfigureMarkerSearchThreshold (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViBoolean thresholdState,
                                                        ViReal64 markerThreshold);
ViStatus _VI_FUNC rsemi_ConfigureMarkerSearchPeakExcursion
             (ViSession instrumentHandle, ViInt32 window, ViReal64 peakExcursion);
ViStatus _VI_FUNC rsemi_ConfigureMarkerSearchLocalOscillator
             (ViSession instrumentHandle, ViInt32 window,
              ViBoolean localOscillatorSupression);
ViStatus _VI_FUNC rsemi_ConfigureSpectrumMarkerSearchLimits
             (ViSession instrumentHandle, ViInt32 window, ViBoolean searchLimits,
              ViReal64 searchLimitLeft, ViReal64 searchLimitRight);
ViStatus _VI_FUNC rsemi_ConfigureMarkerSearchLimitsZoom (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViBoolean searchLimitsZoom);
ViStatus _VI_FUNC rsemi_ConfigureMarkerDemodulation (ViSession instrumentHandle,
                                                     ViInt32 window, ViInt32 marker,
                                                     ViBoolean state,
                                                     ViInt32 demodulationType,
                                                     ViReal64 markerStopTime,
                                                     ViBoolean continuousDemodulation);
ViStatus _VI_FUNC rsemi_ConfigureMarkerPeakListAnnotation
             (ViSession instrumentHandle, ViInt32 window, ViBoolean label);
ViStatus _VI_FUNC rsemi_ConfigureMarkerPeakListState (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureMarkerPeakList (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32 marker,
                                                 ViInt32 peakListCount,
                                                 ViInt32 peakListSort,
                                                 ViInt32 peakListSize,
                                                 ViBoolean automaticPeaksSearch);
ViStatus _VI_FUNC rsemi_ActivateMarkerPeakSearch (ViSession instrumentHandle,
                                                  ViInt32 window, ViInt32 marker,
                                                  ViBoolean peakSearch);
ViStatus _VI_FUNC rsemi_ConfigureMarkerPeakListSettings (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViInt32 marker,
                                                         ViBoolean peakLabels,
                                                         ViInt32 maximumPeaks);
ViStatus _VI_FUNC rsemi_StoreMarkerPeakList (ViSession instrumentHandle,
                                             ViString path);
ViStatus _VI_FUNC rsemi_QueryMarkerPeakListFound (ViSession instrumentHandle,
                                                  ViInt32 window, ViInt32 marker,
                                                  ViPInt32 peakListFound);
ViStatus _VI_FUNC rsemi_QueryMarkerPeakList (ViSession instrumentHandle,
                                             ViInt32 window, ViInt32 marker,
                                             ViInt32 arraySize,
                                             ViInt32 peakListSelection,
                                             ViReal64 _VI_FAR peakList[]);
ViStatus _VI_FUNC rsemi_ConfigureSpectrumDeltaMarker (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViInt32 deltaMarker,
                                                      ViBoolean state,
                                                      ViInt32 trace);
ViStatus _VI_FUNC rsemi_ConfigureSpectrumDeltaMarkerPosition
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker,
              ViInt32 mode, ViReal64 position);
ViStatus _VI_FUNC rsemi_DisableAllDeltaMarkers (ViSession instrumentHandle,
                                                ViInt32 window);
ViStatus _VI_FUNC rsemi_LinkingDeltaMarkerToMarker (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViInt32 deltaMarker,
                                                    ViInt32 secondMarker,
                                                    ViBoolean state);
ViStatus _VI_FUNC rsemi_SpectrumDeltaMarkerSearch (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViInt32 deltaMarker,
                                                   ViInt32 markerSearch);
ViStatus _VI_FUNC rsemi_QuerySpectrumDeltaMarker (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViInt32 deltaMarker, ViInt32 mode,
                                                  ViPReal64 position,
                                                  ViPReal64 amplitude);
ViStatus _VI_FUNC rsemi_ConfigureDeltaMarkerBandPower (ViSession instrumentHandle,
                                                       ViBoolean bandPowerEnabled,
                                                       ViInt32 displayMode,
                                                       ViReal64 span);
ViStatus _VI_FUNC rsemi_QueryDeltaMarkerBandPower (ViSession instrumentHandle,
                                                   ViPReal64 result);
ViStatus _VI_FUNC rsemi_ConfigureReferenceFixed (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViBoolean fixedReference);
ViStatus _VI_FUNC rsemi_ConfigureReferenceFixedPoint (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViReal64 refPointLevel,
                                                      ViReal64 refPointLevelOffset,
                                                      ViReal64 refPointFrequencyTime);
ViStatus _VI_FUNC rsemi_ReferenceFixedPeakSearch (ViSession instrumentHandle,
                                                  ViInt32 window);
ViStatus _VI_FUNC rsemi_ConfigureReferenceOscillator (ViSession instrumentHandle,
                                                      ViInt32 source,
                                                      ViReal64 externalFrequency);
ViStatus _VI_FUNC rsemi_QuerySelectedReferenceOscillatorSource
             (ViSession instrumentHandle, ViPInt32 source);
ViStatus _VI_FUNC rsemi_ConfigureReferenceFrequencyInput (ViSession instrumentHandle,
                                                          ViInt32 tuningRange,
                                                          ViReal64 loopBandwidth);
ViStatus _VI_FUNC rsemi_ConfigureReferenceFrequencyOutput
             (ViSession instrumentHandle, ViBoolean output100MHz,
              ViBoolean output640MHz, ViBoolean outputSyncTrigger);
ViStatus _VI_FUNC rsemi_AudioOutputMaximumVolume (ViSession instrumentHandle,
                                                  ViReal64 maximumVolume);
ViStatus _VI_FUNC rsemi_AudioOutputMute (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_SpeakerVolume (ViSession instrumentHandle,
                                       ViReal64 speakerVolume);
ViStatus _VI_FUNC rsemi_ApplicationSetupRecovery (ViSession instrumentHandle,
                                                  ViBoolean applicationSetupRecovery);
ViStatus _VI_FUNC rsemi_ConfigureRemoteLoggingState (ViSession instrumentHandle,
                                                     ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureInstrumentCoupling (ViSession instrumentHandle,
                                                     ViInt32 coupling,
                                                     ViInt32 state);
ViStatus _VI_FUNC rsemi_SystemShutdown (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_QueryFrontendTemperature (ViSession instrumentHandle,
                                                  ViPReal64 frontendTemperature);
ViStatus _VI_FUNC rsemi_SystemPreamplifierOption (ViSession instrumentHandle,
                                                  ViInt32 option);
ViStatus _VI_FUNC rsemi_ConfigureSecureUserMode (ViSession instrumentHandle,
                                                 ViBoolean secureUserModeEnabled);
ViStatus _VI_FUNC rsemi_ConfigureTriggerSource (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViInt32 triggerSource);
ViStatus _VI_FUNC rsemi_ConfigureTrigger (ViSession instrumentHandle,
                                          ViInt32 window, ViReal64 triggerDelay,
                                          ViInt32 triggerPolarity);
ViStatus _VI_FUNC rsemi_ConfigureTriggerDropoutTime (ViSession instrumentHandle,
                                                     ViReal64 dropoutTime);
ViStatus _VI_FUNC rsemi_ConfigureExternalTrigger (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViReal64 externalTriggerLevel);
ViStatus _VI_FUNC rsemi_ConfigureVideoTrigger (ViSession instrumentHandle,
                                               ViInt32 window,
                                               ViReal64 videoTriggerLevel);
ViStatus _VI_FUNC rsemi_ConfigureIFPowerTrigger (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViReal64 triggerLevel);
ViStatus _VI_FUNC rsemi_ConfigureIFPowerTriggerParameters
             (ViSession instrumentHandle, ViInt32 window, ViReal64 triggerLevel,
              ViReal64 holdoff, ViReal64 hysteresis);
ViStatus _VI_FUNC rsemi_ConfigureIFPowerTriggerCoupling (ViSession instrumentHandle,
                                                         ViInt32 coupling);
ViStatus _VI_FUNC rsemi_ConfigureRFPowerTrigger (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViReal64 triggerLevel);
ViStatus _VI_FUNC rsemi_ConfigureRFPowerTriggerHoldoff (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViReal64 holdoff);
ViStatus _VI_FUNC rsemi_ConfigureIQPowerTrigger (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViReal64 triggerLevel);
ViStatus _VI_FUNC rsemi_ConfigureTimeTrigger (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViReal64 timeInterval);
ViStatus _VI_FUNC rsemi_QueryTriggerPositionInSample (ViSession instrumentHandle,
                                                      ViPInt32 triggerPositionInSample);
ViStatus _VI_FUNC rsemi_ConfigureExternalGate (ViSession instrumentHandle,
                                               ViInt32 window, ViBoolean gating,
                                               ViInt32 gateSource, ViInt32 mode,
                                               ViInt32 polarity, ViReal64 delay,
                                               ViReal64 length);
ViStatus _VI_FUNC rsemi_ConfigureExternalGateTrace (ViSession instrumentHandle,
                                                    ViInt32 trace, ViInt32 range,
                                                    ViBoolean traceState,
                                                    ViString comment,
                                                    ViReal64 traceStart,
                                                    ViReal64 traceStop,
                                                    ViReal64 periodLength);
ViStatus _VI_FUNC rsemi_ConfigureExternalMixerEnabled (ViSession instrumentHandle,
                                                       ViBoolean externalMixingEnabled);
ViStatus _VI_FUNC rsemi_ConfigureExternalMixerNumberOfPorts
             (ViSession instrumentHandle, ViInt32 numberOfPorts);
ViStatus _VI_FUNC rsemi_ConfigureExternalMixer (ViSession instrumentHandle,
                                                ViInt32 band, ViInt32 harmonic,
                                                ViInt32 harmonicType);
ViStatus _VI_FUNC rsemi_QueryExternalMixerRFStartStop (ViSession instrumentHandle,
                                                       ViPReal64 RFStart,
                                                       ViPReal64 RFStop);
ViStatus _VI_FUNC rsemi_ConfigureExternalMixerHandoverFrequency
             (ViSession instrumentHandle, ViReal64 handoverFrequency);
ViStatus _VI_FUNC rsemi_ConfigureExternalMixerRFOverrange
             (ViSession instrumentHandle, ViBoolean RFOverrange);
ViStatus _VI_FUNC rsemi_ConfigureExternalMixerPresetBand
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ConfigureExternalMixerHighHarmonic
             (ViSession instrumentHandle, ViBoolean highHarmonic,
              ViInt32 harmonicOrder);
ViStatus _VI_FUNC rsemi_ConfigureExternalMixerSignalIDMode
             (ViSession instrumentHandle, ViInt32 mode, ViReal64 autoIDThreshold);
ViStatus _VI_FUNC rsemi_ConfigureExternalMixerBias (ViSession instrumentHandle,
                                                    ViInt32 range, ViReal64 bias);
ViStatus _VI_FUNC rsemi_ConfigureExternalMixerConversionLoss
             (ViSession instrumentHandle, ViInt32 range, ViInt32 conversionLossMode,
              ViReal64 conversionLossAverage, ViString conversionLossTable);
ViStatus _VI_FUNC rsemi_ConfigureExternalMixerLowPower (ViSession instrumentHandle,
                                                        ViReal64 lowPower);
ViStatus _VI_FUNC rsemi_CreateExternalMixerConversionLossTable
             (ViSession instrumentHandle, ViString tableName, ViString mixerType,
              ViInt32 band, ViString serialNumber, ViInt32 harmonic, ViInt32 ports,
              ViReal64 bias, ViString comment, ViInt32 numberOfValues,
              ViReal64 _VI_FAR frequencyValues[],
              ViReal64 _VI_FAR conversionLossValues[]);
ViStatus _VI_FUNC rsemi_ExternalMixerConversionLossTableSelect
             (ViSession instrumentHandle, ViInt32 window, ViString tableName);
ViStatus _VI_FUNC rsemi_ExternalMixerConversionLossTableDelete
             (ViSession instrumentHandle, ViInt32 window, ViString tableName);
ViStatus _VI_FUNC rsemi_ExternalMixerConversionLossTableCatalog
             (ViSession instrumentHandle, ViPInt32 numberOfCVL, ViInt32 bufferSize,
              ViChar _VI_FAR CVLNamesList[]);
ViStatus _VI_FUNC rsemi_ConfigureRFInputState (ViSession instrumentHandle,
                                               ViInt32 source);
ViStatus _VI_FUNC rsemi_ConfigureAmplitudeRFInputCoupling
             (ViSession instrumentHandle, ViInt32 RFInputCoupling);
ViStatus _VI_FUNC rsemi_ConfigureAmplitudeRFInputImpedance
             (ViSession instrumentHandle, ViInt32 impedance);
ViStatus _VI_FUNC rsemi_ConfigureElectronicAttenuator (ViSession instrumentHandle,
                                                       ViInt32 input, ViInt32 mode,
                                                       ViInt32 manualValue);
ViStatus _VI_FUNC rsemi_ConfigurePreamplifierState (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigurePreamplifierValue (ViSession instrumentHandle,
                                                    ViInt32 preamplifierLevel);
ViStatus _VI_FUNC rsemi_ConfigureLNAPreamplifierState (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureLNAPreamplifier (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViBoolean autoMode);
ViStatus _VI_FUNC rsemi_InputProtectionReset (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ConfigureAttenuationProtection (ViSession instrumentHandle,
                                                        ViBoolean attenuationProtection);
ViStatus _VI_FUNC rsemi_ConfigureHighpassFilter (ViSession instrumentHandle,
                                                 ViBoolean highpassFilter);
ViStatus _VI_FUNC rsemi_ConfigureYIGFilter (ViSession instrumentHandle,
                                            ViInt32 window, ViBoolean YIGFilter);
ViStatus _VI_FUNC rsemi_ConfigureDirectPath (ViSession instrumentHandle,
                                             ViInt32 directPath);
ViStatus _VI_FUNC rsemi_ConfigurePreselectorState (ViSession instrumentHandle,
                                                   ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigurePreselectorMode (ViSession instrumentHandle,
                                                  ViInt32 mode);
ViStatus _VI_FUNC rsemi_ConfigurePreselectorNotchFilterState
             (ViSession instrumentHandle, ViInt32 filter, ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigurePreselectorSplitState (ViSession instrumentHandle,
                                                        ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigurePreselectorHPLPFilterFrequency
             (ViSession instrumentHandle, ViReal64 lowpass, ViReal64 highpass);
ViStatus _VI_FUNC rsemi_ConfigurePreselectorBandpassFilterFrequency
             (ViSession instrumentHandle, ViReal64 lower, ViReal64 upper);
ViStatus _VI_FUNC rsemi_CreateSpectrumLimitLine (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32 limit,
                                                 ViString name, ViInt32 domain,
                                                 ViString comment,
                                                 ViInt32 assignToTrace,
                                                 ViBoolean deleteExistingLimitLine);
ViStatus _VI_FUNC rsemi_ConfigureLimitLine (ViSession instrumentHandle,
                                            ViInt32 limit, ViInt32 type,
                                            ViInt32 units,
                                            ViInt32 xAxisInterpolation,
                                            ViInt32 yAxisInterpolation,
                                            ViInt32 xAxisScaling, ViReal64 margin,
                                            ViReal64 threshold);
ViStatus _VI_FUNC rsemi_DefineSpectrumLimitLine (ViSession instrumentHandle,
                                                 ViInt32 limit, ViInt32 type,
                                                 ViInt32 count,
                                                 ViReal64 _VI_FAR xAxis[],
                                                 ViReal64 _VI_FAR amplitude[]);
ViStatus _VI_FUNC rsemi_SelectLimitLine (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32 limit, ViString name,
                                         ViBoolean limitEnabled);
ViStatus _VI_FUNC rsemi_EnableLimitCheck (ViSession instrumentHandle,
                                          ViInt32 window, ViInt32 limit,
                                          ViInt32 type, ViBoolean limitEnabled,
                                          ViBoolean checkEnabled);
ViStatus _VI_FUNC rsemi_MoveLimitLine (ViSession instrumentHandle, ViInt32 limit,
                                       ViInt32 type, ViInt32 method,
                                       ViReal64 moveValue);
ViStatus _VI_FUNC rsemi_CopySpectrumLimitLine (ViSession instrumentHandle,
                                               ViInt32 limit, ViInt32 copyTo);
ViStatus _VI_FUNC rsemi_DeleteLimitLine (ViSession instrumentHandle, ViInt32 limit);
ViStatus _VI_FUNC rsemi_ClearLimitLineResults (ViSession instrumentHandle,
                                               ViInt32 window, ViInt32 limit);
ViStatus _VI_FUNC rsemi_ConfigureDisplayLimitLineState (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViInt32 line, ViInt32 type,
                                                        ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureDisplayLimitLinePosition
             (ViSession instrumentHandle, ViInt32 window, ViInt32 line,
              ViInt32 type, ViReal64 position);
ViStatus _VI_FUNC rsemi_GetActiveLimitLines (ViSession instrumentHandle,
                                             ViInt32 stringSize,
                                             ViChar _VI_FAR activeLimitLines[],
                                             ViPInt32 returnedStringLength);
ViStatus _VI_FUNC rsemi_EnableTraceLimitCheck (ViSession instrumentHandle,
                                               ViInt32 window, ViInt32 limit,
                                               ViInt32 trace,
                                               ViBoolean checkEnabled);
ViStatus _VI_FUNC rsemi_DisplaySetActiveWindow (ViSession instrumentHandle,
                                                ViInt32 window);
ViStatus _VI_FUNC rsemi_GetSelectedSubwindow (ViSession instrumentHandle,
                                              ViPInt32 subwindow);
ViStatus _VI_FUNC rsemi_ConfigureDisplayFocusedArea (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViInt32 subwindow);
ViStatus _VI_FUNC rsemi_ConfigureDisplayControl (ViSession instrumentHandle,
                                                 ViBoolean frequency,
                                                 ViBoolean logo, ViBoolean time);
ViStatus _VI_FUNC rsemi_ConfigureDisplayComment (ViSession instrumentHandle,
                                                 ViInt32 window, ViBoolean state,
                                                 ViString comment);
ViStatus _VI_FUNC rsemi_ConfigureDisplayWindowSize (ViSession instrumentHandle,
                                                    ViInt32 windowSize);
ViStatus _VI_FUNC rsemi_ConfigureDisplaySubwindowSize (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViInt32 subwindow,
                                                       ViInt32 windowSize);
ViStatus _VI_FUNC rsemi_ConfigureDisplayLogRange (ViSession instrumentHandle,
                                                  ViInt32 window, ViReal64 range);
ViStatus _VI_FUNC rsemi_ConfigureDisplayAmplitudeGridMode
             (ViSession instrumentHandle, ViInt32 window, ViInt32 yAxisGridMode);
ViStatus _VI_FUNC rsemi_ConfigureDisplayReferenceValue (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViReal64 referenceValue);
ViStatus _VI_FUNC rsemi_ConfigureDisplayReferencePosition
             (ViSession instrumentHandle, ViInt32 window,
              ViReal64 referencePosition);
ViStatus _VI_FUNC rsemi_ConfigureDisplaySoftFrontpanel (ViSession instrumentHandle,
                                                        ViBoolean softFrontpanel);
ViStatus _VI_FUNC rsemi_ConfigureDisplayYAxisScaling (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViReal64 scaling);
ViStatus _VI_FUNC rsemi_ConfigureDisplaySettings (ViSession instrumentHandle,
                                                  ViBoolean statusBarState,
                                                  ViBoolean softkeyBarState,
                                                  ViBoolean toolBarState,
                                                  ViInt32 touchscreenState);
ViStatus _VI_FUNC rsemi_ConfigureDisplayShowInputState (ViSession instrumentHandle,
                                                        ViBoolean inputStateShow);
ViStatus _VI_FUNC rsemi_ConfigureDisplayChannelBarState (ViSession instrumentHandle,
                                                         ViBoolean channelBarState);
ViStatus _VI_FUNC rsemi_ConfigureDisplayMultiViewState (ViSession instrumentHandle,
                                                        ViBoolean multiViewState);
ViStatus _VI_FUNC rsemi_GetDisplayThemeCatalog (ViSession instrumentHandle,
                                                ViPInt32 numberOfThemes,
                                                ViInt32 bufferSize,
                                                ViChar _VI_FAR themeList[]);
ViStatus _VI_FUNC rsemi_ConfigureDisplayThemeSelect (ViSession instrumentHandle,
                                                     ViString theme);
ViStatus _VI_FUNC rsemi_ConfigureMarkerInfo (ViSession instrumentHandle,
                                             ViBoolean markerInfo);
ViStatus _VI_FUNC rsemi_ConfigureDisplayZoom (ViSession instrumentHandle,
                                              ViInt32 window, ViBoolean zoomState,
                                              ViReal64 x1, ViReal64 y1, ViReal64 x2,
                                              ViReal64 y2);
ViStatus _VI_FUNC rsemi_ConfigureDisplayConductances (ViSession instrumentHandle,
                                                      ViBoolean displayConductances);
ViStatus _VI_FUNC rsemi_QueryActiveMeasurementWindow (ViSession instrumentHandle,
                                                      ViPInt32 window);
ViStatus _VI_FUNC rsemi_AddWindow (ViSession instrumentHandle, ViInt32 stringSize,
                                   ViString windowName, ViInt32 direction,
                                   ViInt32 windowType,
                                   ViChar _VI_FAR returnedWindowName[]);
ViStatus _VI_FUNC rsemi_RemoveWindow (ViSession instrumentHandle,
                                      ViString windowName);
ViStatus _VI_FUNC rsemi_ReplaceWindow (ViSession instrumentHandle,
                                       ViString windowName, ViInt32 windowType);
ViStatus _VI_FUNC rsemi_QueryWindowsList (ViSession instrumentHandle,
                                          ViInt32 bufferSize,
                                          ViChar _VI_FAR results[]);
ViStatus _VI_FUNC rsemi_QueryWindowIndex (ViSession instrumentHandle,
                                          ViString windowName, ViPInt32 index);
ViStatus _VI_FUNC rsemi_QueryWindowName (ViSession instrumentHandle,
                                         ViInt32 stringSize, ViInt32 index,
                                         ViChar _VI_FAR windowName[]);
ViStatus _VI_FUNC rsemi_ConfigureSplitterPosition (ViSession instrumentHandle,
                                                   ViString firstWindowName,
                                                   ViString secondWindowName,
                                                   ViInt32 position);
ViStatus _VI_FUNC rsemi_DisplayColorDefault (ViSession instrumentHandle,
                                             ViInt32 defaultSetting);
ViStatus _VI_FUNC rsemi_ConfigureDisplayColor (ViSession instrumentHandle,
                                               ViInt32 colorMap, ViReal64 TINT,
                                               ViReal64 SATURATION,
                                               ViReal64 BRIGHTNESS);
ViStatus _VI_FUNC rsemi_ConfigureDisplayColorByPredefined
             (ViSession instrumentHandle, ViInt32 colorMap,
              ViInt32 predefinedColors);
ViStatus _VI_FUNC rsemi_Calibration (ViSession instrumentHandle, ViBoolean sync,
                                     ViUInt32 timeoutms, ViPInt32 result);
ViStatus _VI_FUNC rsemi_CalibrationAbort (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_CalibrationResult (ViSession instrumentHandle,
                                           ViInt32 arraySize,
                                           ViChar _VI_FAR result[]);
ViStatus _VI_FUNC rsemi_CalibrationState (ViSession instrumentHandle,
                                          ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureAutoAdjust (ViSession instrumentHandle,
                                             ViInt32 adjustSettings,
                                             ViInt32 measurementTimeMode,
                                             ViReal64 measurementTime);
ViStatus _VI_FUNC rsemi_ConfigureAutoAdjustHystersis (ViSession instrumentHandle,
                                                      ViReal64 lowerHystersis,
                                                      ViReal64 upperHystersis);
ViStatus _VI_FUNC rsemi_ConfigureAutoAdjustTriggerState (ViSession instrumentHandle,
                                                         ViBoolean state);
ViStatus _VI_FUNC rsemi_ReadYTrace (ViSession instrumentHandle, ViInt32 window,
                                    ViInt32 trace, ViUInt32 maximumTime,
                                    ViInt32 arrayLength, ViPInt32 actualPoints,
                                    ViReal64 _VI_FAR amplitude[]);
ViStatus _VI_FUNC rsemi_FetchYTrace (ViSession instrumentHandle, ViInt32 window,
                                     ViInt32 trace, ViInt32 arrayLength,
                                     ViPInt32 actualPoints,
                                     ViReal64 _VI_FAR amplitude[]);
ViStatus _VI_FUNC rsemi_ReadYTracePrevious (ViSession instrumentHandle,
                                            ViInt32 window, ViInt32 trace,
                                            ViInt32 offsetSweepPoint,
                                            ViInt32 numberOfSweeps,
                                            ViInt32 arrayLength,
                                            ViPInt32 actualPoints,
                                            ViReal64 _VI_FAR amplitude[]);
ViStatus _VI_FUNC rsemi_FetchXTrace (ViSession instrumentHandle, ViInt32 trace,
                                     ViInt32 arrayLength, ViPInt32 actualPoints,
                                     ViReal64 _VI_FAR x[]);
ViStatus _VI_FUNC rsemi_ReadTraceIQData (ViSession instrumentHandle, ViInt32 window,
                                         ViUInt32 timeout, ViInt32 bufferSize,
                                         ViPInt32 noOfPoints,
                                         ViReal64 _VI_FAR realParts_I[],
                                         ViReal64 _VI_FAR imaginaryParts_Q[]);
ViStatus _VI_FUNC rsemi_FetchTraceIQData (ViSession instrumentHandle,
                                          ViInt32 offsetSamples,
                                          ViInt32 noOfSamples, ViInt32 bufferSize,
                                          ViPInt32 noOfPoints,
                                          ViReal64 _VI_FAR realParts_I[],
                                          ViReal64 _VI_FAR imaginaryParts_Q[]);
ViStatus _VI_FUNC rsemi_ReadMemoryIQLargeData (ViSession instrumentHandle,
                                               ViInt32 window, ViUInt32 timeout,
                                               ViInt32 format, ViInt32 dataOrder,
                                               ViPInt32 noOfPoints);
ViStatus _VI_FUNC rsemi_ReadMemoryIQLargeDataBlock (ViSession instrumentHandle,
                                                    ViInt32 bufferSize,
                                                    ViChar _VI_FAR returnedData[],
                                                    ViPInt32 returnedCounts);
ViStatus _VI_FUNC rsemi_GetLimitCheckResult (ViSession instrumentHandle,
                                             ViInt32 window, ViInt32 limit,
                                             ViPInt32 state);
ViStatus _VI_FUNC rsemi_MeasurementInitiate (ViSession instrumentHandle,
                                             ViInt32 window, ViUInt32 timeout);
ViStatus _VI_FUNC rsemi_InitiateSpurious (ViSession instrumentHandle,
                                          ViInt32 window, ViUInt32 timeout);
ViStatus _VI_FUNC rsemi_InitiateSEMMeasurement (ViSession instrumentHandle,
                                                ViInt32 window, ViUInt32 timeout);
ViStatus _VI_FUNC rsemi_Abort (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_MeasurementContinue (ViSession instrumentHandle,
                                             ViInt32 window, ViUInt32 timeout);
ViStatus _VI_FUNC rsemi_SendSoftwareTrigger (ViSession instrumentHandle,
                                             ViUInt32 timeout);
ViStatus _VI_FUNC rsemi_InitiateSequencer (ViSession instrumentHandle,
                                           ViUInt32 timeout);
ViStatus _VI_FUNC rsemi_AbortSequencer (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_RefreshSequencer (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ConfigureSequencerState (ViSession instrumentHandle,
                                                 ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureSequencerMode (ViSession instrumentHandle,
                                                ViInt32 sequencerMode);
ViStatus _VI_FUNC rsemi_GetSweepNumber (ViSession instrumentHandle, ViInt32 window,
                                        ViPInt32 numberOfSweeps);
ViStatus _VI_FUNC rsemi_ConfigureMarkerNoiseMeasurement (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViInt32 marker,
                                                         ViBoolean state);
ViStatus _VI_FUNC rsemi_QueryMarkerNoiseMeasurementResult
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker,
              ViPReal64 result);
ViStatus _VI_FUNC rsemi_ConfigureMarkerPhaseNoiseMeasurement
             (ViSession instrumentHandle, ViInt32 window, ViBoolean state);
ViStatus _VI_FUNC rsemi_PhaseNoisePeakSearch (ViSession instrumentHandle,
                                              ViInt32 window);
ViStatus _VI_FUNC rsemi_PhaseNoisePeakSearchAuto (ViSession instrumentHandle,
                                                  ViInt32 window, ViBoolean state);
ViStatus _VI_FUNC rsemi_QueryPhaseNoiseResult (ViSession instrumentHandle,
                                               ViInt32 window,
                                               ViPReal64 phaseNoiseResult);
ViStatus _VI_FUNC rsemi_ConfigureMarkerFrequencyCounter (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViInt32 marker,
                                                         ViBoolean markerFrequencyCounter,
                                                         ViReal64 frequencyCounterResolution);
ViStatus _VI_FUNC rsemi_QueryMarkerFrequencyCounterResult
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker,
              ViPReal64 counterFrequency);
ViStatus _VI_FUNC rsemi_ConfigureNdBPoints (ViSession instrumentHandle,
                                            ViInt32 window, ViBoolean nDBState,
                                            ViReal64 nDBLevel);
ViStatus _VI_FUNC rsemi_QueryNdBResult (ViSession instrumentHandle, ViInt32 window,
                                        ViPReal64 nDBResult);
ViStatus _VI_FUNC rsemi_QueryNdBFrequencies (ViSession instrumentHandle,
                                             ViInt32 window,
                                             ViPReal64 nDBFrequencyLower,
                                             ViPReal64 nDBFrequencyHigher);
ViStatus _VI_FUNC rsemi_QueryNdBTimes (ViSession instrumentHandle, ViInt32 window,
                                       ViPReal64 nDBTimeLower,
                                       ViPReal64 nDBTimeHigher);
ViStatus _VI_FUNC rsemi_QueryNdBQFactor (ViSession instrumentHandle, ViInt32 window,
                                         ViPReal64 nDBQFactor);
ViStatus _VI_FUNC rsemi_ConfigureListPowerSequence (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViInt32 noOfListItems,
                                                    ViReal64 _VI_FAR analyzerFrequency[],
                                                    ViReal64 _VI_FAR referenceLevel[],
                                                    ViReal64 _VI_FAR RFInputAttenuation[],
                                                    ViReal64 _VI_FAR RFInputElectronicAttn[],
                                                    ViInt32 _VI_FAR filterType[],
                                                    ViReal64 _VI_FAR resolutionBandwidth[],
                                                    ViReal64 _VI_FAR videoBandwidth[],
                                                    ViReal64 _VI_FAR measTime[],
                                                    ViReal64 _VI_FAR triggerLevel[]);
ViStatus _VI_FUNC rsemi_ConfigureListPowerSet (ViSession instrumentHandle,
                                               ViInt32 window, ViBoolean peakMeas,
                                               ViBoolean RMSMeas, ViBoolean AVGMeas,
                                               ViInt32 triggerMode,
                                               ViInt32 triggerSlope,
                                               ViReal64 triggerOffset,
                                               ViReal64 gateLength);
ViStatus _VI_FUNC rsemi_ListPowerMeasurementOff (ViSession instrumentHandle,
                                                 ViInt32 window);
ViStatus _VI_FUNC rsemi_QueryListPowerSequence (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViInt32 noOfListItems,
                                                ViReal64 _VI_FAR analyzerFrequency[],
                                                ViReal64 _VI_FAR referenceLevel[],
                                                ViReal64 _VI_FAR RFInputAttenuation[],
                                                ViReal64 _VI_FAR RFInputElectronicAttn[],
                                                ViInt32 _VI_FAR filterType[],
                                                ViReal64 _VI_FAR resolutionBandwidth[],
                                                ViReal64 _VI_FAR videoBandwidth[],
                                                ViReal64 _VI_FAR measTime[],
                                                ViReal64 _VI_FAR triggerLevel[],
                                                ViReal64 _VI_FAR listPowerResults[]);
ViStatus _VI_FUNC rsemi_QueryListPowerResult (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 noOfResults,
                                              ViReal64 _VI_FAR listPowerResults[],
                                              ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_ConfigureTimeDomainPowerMeasurementState
             (ViSession instrumentHandle, ViInt32 window, ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureTimeDomainPowerMeasurement
             (ViSession instrumentHandle, ViInt32 window, ViBoolean peak,
              ViBoolean RMS, ViBoolean mean, ViBoolean standardDeviation,
              ViBoolean average, ViBoolean maxHold, ViInt32 power);
ViStatus _VI_FUNC rsemi_TimeDomainPowerMeasurementAllOff (ViSession instrumentHandle,
                                                          ViInt32 window);
ViStatus _VI_FUNC rsemi_TimeDomainPowerMeasurementSetReference
             (ViSession instrumentHandle, ViInt32 window);
ViStatus _VI_FUNC rsemi_QueryTDomPowerResult (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 measurement,
                                              ViInt32 resultType, ViPReal64 result);
ViStatus _VI_FUNC rsemi_QueryTDomPowerPulseSequenceResult
             (ViSession instrumentHandle, ViInt32 window,
              ViReal64 timeOffsetOfFirstPulse, ViReal64 measurementTime,
              ViReal64 period, ViInt32 numberOfPulses, ViReal64 _VI_FAR result[]);
ViStatus _VI_FUNC rsemi_SelectPowerMeasurement (ViSession instrumentHandle,
                                                ViInt32 window, ViBoolean state,
                                                ViInt32 powerMeasurement);
ViStatus _VI_FUNC rsemi_ConfigurePowerSet (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 powerSet);
ViStatus _VI_FUNC rsemi_ConfigurePowerMeasurement (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViInt32 noOfAdjChannels,
                                                   ViInt32 channelMode,
                                                   ViInt32 powerMode,
                                                   ViBoolean resultMode);
ViStatus _VI_FUNC rsemi_ConfigurePowerChannelSpacing (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViInt32 channel,
                                                      ViInt32 channelNumber,
                                                      ViReal64 spacing);
ViStatus _VI_FUNC rsemi_ConfigurePowerChannelBandwidth (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViInt32 channel,
                                                        ViInt32 channelNumber,
                                                        ViReal64 bandwidth);
ViStatus _VI_FUNC rsemi_ConfigurePowerChannelName (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 channel,
                                                   ViInt32 channelNumber,
                                                   ViString name);
ViStatus _VI_FUNC rsemi_ConfigureChannelPowerNoiseCorrection
             (ViSession instrumentHandle, ViInt32 window,
              ViBoolean noiseCorrectionState);
ViStatus _VI_FUNC rsemi_ConfigureChannelPowerNoiseCorrectionAuto
             (ViSession instrumentHandle, ViInt32 window, ViInt32 mode);
ViStatus _VI_FUNC rsemi_ConfigureChannelPowerTrace (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViInt32 traceNumber);
ViStatus _VI_FUNC rsemi_ConfigureChannelPowerStandard (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViInt32 ACPStandard);
ViStatus _VI_FUNC rsemi_QueryChannelPowerStandardCatalog (ViSession instrumentHandle,
                                                          ViInt32 bufferSize,
                                                          ViChar _VI_FAR powerStandardCatalog[]);
ViStatus _VI_FUNC rsemi_ConfigureChannelPowerUserStandard
             (ViSession instrumentHandle, ViInt32 window, ViInt32 operation,
              ViString userStandardName);
ViStatus _VI_FUNC rsemi_PowerAdjustReferenceLevel (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViUInt32 timeout);
ViStatus _VI_FUNC rsemi_PowerPresetMeasurement (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViInt32 channelPowerType,
                                                ViUInt32 timeout);
ViStatus _VI_FUNC rsemi_QueryPowerResults (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 powerMeasurement,
                                           ViInt32 arraySize,
                                           ViReal64 _VI_FAR results[],
                                           ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_ConfPowerChannelWeightingFilters (ViSession instrumentHandle,
                                                          ViInt32 filterType,
                                                          ViInt32 channelNumber,
                                                          ViBoolean filterState,
                                                          ViReal64 filterValue);
ViStatus _VI_FUNC rsemi_ConfigureMSRPowerMeasurement (ViSession instrumentHandle,
                                                      ViInt32 ACLRMode,
                                                      ViInt32 powerMode,
                                                      ViBoolean powerUnit,
                                                      ViInt32 noiseCorrection,
                                                      ViInt32 traceNumber);
ViStatus _VI_FUNC rsemi_ConfigureMSRNumberOfSubblocks (ViSession instrumentHandle,
                                                       ViInt32 numberOfSubblocks);
ViStatus _VI_FUNC rsemi_ConfigureMSRSubblockDefinition (ViSession instrumentHandle,
                                                        ViInt32 subblock,
                                                        ViReal64 centerFrequency,
                                                        ViReal64 RFBandwidth,
                                                        ViInt32 txChannelCount);
ViStatus _VI_FUNC rsemi_ConfigureMSRTxChannelDefinition (ViSession instrumentHandle,
                                                         ViInt32 subblock,
                                                         ViInt32 txChannel,
                                                         ViReal64 txCenterFrequency,
                                                         ViInt32 technology,
                                                         ViReal64 txBandwidth,
                                                         ViBoolean weightingFilterState,
                                                         ViReal64 rollOffFactor);
ViStatus _VI_FUNC rsemi_QueryMSRTxName (ViSession instrumentHandle,
                                        ViInt32 subblock, ViInt32 txChannel,
                                        ViInt32 bufferSize, ViChar _VI_FAR name[]);
ViStatus _VI_FUNC rsemi_ConfigureMSRGapChannel (ViSession instrumentHandle,
                                                ViInt32 gap,
                                                ViReal64 channelSpacing,
                                                ViReal64 channelBandwidths,
                                                ViBoolean weightingFilterState,
                                                ViReal64 rollOffFactor);
ViStatus _VI_FUNC rsemi_ConfigureMSRGapLimitChecking (ViSession instrumentHandle,
                                                      ViInt32 gap,
                                                      ViBoolean relativeState,
                                                      ViReal64 relativeValue,
                                                      ViBoolean absoluteState,
                                                      ViReal64 absoluteValue);
ViStatus _VI_FUNC rsemi_QueryMSRGapLimitChecking (ViSession instrumentHandle,
                                                  ViInt32 arraySize,
                                                  ViInt32 _VI_FAR limitResults[],
                                                  ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_ConfigureACPFastACPState (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViBoolean fastACPState);
ViStatus _VI_FUNC rsemi_ACPChannelPowerAutoAdjust (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViUInt32 timeout);
ViStatus _VI_FUNC rsemi_ConfigureACPLimitState (ViSession instrumentHandle,
                                                ViInt32 window, ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureACPAdjacentChannelLimit (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViBoolean relativeState,
                                                          ViReal64 relativeValue,
                                                          ViBoolean absoluteState,
                                                          ViReal64 absoluteValue);
ViStatus _VI_FUNC rsemi_ConfigureACPAlternateChannelLimit
             (ViSession instrumentHandle, ViInt32 window,
              ViInt32 alternateChannelNumber, ViBoolean relativeState,
              ViReal64 relativeValue, ViBoolean absoluteState,
              ViReal64 absoluteValue);
ViStatus _VI_FUNC rsemi_QueryACPAdjacentChannelLimitCheckResults
             (ViSession instrumentHandle, ViInt32 window, ViPInt32 lowerResult,
              ViPInt32 upperResult);
ViStatus _VI_FUNC rsemi_QueryACPAlternateChannelLimitCheckResults
             (ViSession instrumentHandle, ViInt32 window,
              ViInt32 alternateChannelNumber, ViPInt32 lowerResult,
              ViPInt32 upperResult);
ViStatus _VI_FUNC rsemi_QueryACPGapChannelLimitCheckResults
             (ViSession instrumentHandle, ViInt32 window, ViInt32 gap,
              ViPInt32 lowerResult, ViPInt32 upperResult);
ViStatus _VI_FUNC rsemi_ConfigureMulticarrierACPPower (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViInt32 noOfAdjChannels,
                                                       ViInt32 noOfTXChannels,
                                                       ViInt32 channelMode,
                                                       ViInt32 powerMode,
                                                       ViBoolean resultMode);
ViStatus _VI_FUNC rsemi_ConfigureACPReferenceChannelAuto (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViInt32 reference);
ViStatus _VI_FUNC rsemi_ConfigureACPReferenceChannelMan (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViInt32 channel);
ViStatus _VI_FUNC rsemi_ConfigureOccupiedBandwidth (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViReal64 powerBandwidth,
                                                    ViReal64 channelBandwidth);
ViStatus _VI_FUNC rsemi_ConfigureSignalStatisticMeasurement
             (ViSession instrumentHandle, ViInt32 measurement,
              ViInt32 numberOfSamples, ViReal64 resolutionBandwidth);
ViStatus _VI_FUNC rsemi_ConfigureSignalStatisticMeasurementXAxis
             (ViSession instrumentHandle, ViReal64 xAxisRefLevel,
              ViReal64 xAxisRange);
ViStatus _VI_FUNC rsemi_ConfigureSignalStatisticMeasurementYAxis
             (ViSession instrumentHandle, ViInt32 yUnit, ViReal64 yAxisMaxValue,
              ViReal64 yAxisMinValue);
ViStatus _VI_FUNC rsemi_ConfigureSignalStatisticSweep (ViSession instrumentHandle,
                                                       ViBoolean sweepModeContinuous);
ViStatus _VI_FUNC rsemi_SignalStatisticMeasurementAdjustSettings
             (ViSession instrumentHandle, ViUInt32 timeout);
ViStatus _VI_FUNC rsemi_SignalStatisticMeasurementPresetScaling
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_QuerySignalStatisticCCDFLevel (ViSession instrumentHandle,
                                                       ViInt32 trace,
                                                       ViInt32 probability,
                                                       ViPReal64 result);
ViStatus _VI_FUNC rsemi_QuerySignalStatisticResult (ViSession instrumentHandle,
                                                    ViInt32 trace,
                                                    ViInt32 resultType,
                                                    ViPReal64 result);
ViStatus _VI_FUNC rsemi_ConfigureModDepthMeasurement (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViBoolean state);
ViStatus _VI_FUNC rsemi_QueryModulationDepth (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViPReal64 modulationDepth);
ViStatus _VI_FUNC rsemi_ModulationDepthSignalSearch (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViInt32 reserved);
ViStatus _VI_FUNC rsemi_ConfigureTOIMeasurement (ViSession instrumentHandle,
                                                 ViInt32 window, ViBoolean state);
ViStatus _VI_FUNC rsemi_QueryTOI (ViSession instrumentHandle, ViInt32 window,
                                  ViPReal64 TOIMeasurement);
ViStatus _VI_FUNC rsemi_TOISignalSearch (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32 marker);
ViStatus _VI_FUNC rsemi_ConfigureHDistMeasurement (ViSession instrumentHandle,
                                                   ViBoolean state,
                                                   ViInt32 noOfHarmonics,
                                                   ViBoolean harmonicRBWAuto);
ViStatus _VI_FUNC rsemi_AdjustHDistSettings (ViSession instrumentHandle,
                                             ViUInt32 timeout);
ViStatus _VI_FUNC rsemi_QueryHDist (ViSession instrumentHandle,
                                    ViPReal64 harmonicDistortionInPercent,
                                    ViPReal64 harmonicDistortionInDB);
ViStatus _VI_FUNC rsemi_QueryHDistHarmonicsList (ViSession instrumentHandle,
                                                 ViReal64 _VI_FAR harmonicsList[]);
ViStatus _VI_FUNC rsemi_BurstPowerSequence (ViSession instrumentHandle,
                                            ViInt32 window,
                                            ViReal64 analyzerFrequencyHz,
                                            ViReal64 resolutionBandwidthHz,
                                            ViReal64 measTimes,
                                            ViInt32 triggerSource,
                                            ViReal64 triggerLevel,
                                            ViReal64 triggerOffsets,
                                            ViInt32 typeOfMeas,
                                            ViInt32 noOfMeasurements);
ViStatus _VI_FUNC rsemi_BurstPowerFilterType (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 filterType);
ViStatus _VI_FUNC rsemi_GetBurstPowerSequence (ViSession instrumentHandle,
                                               ViInt32 window,
                                               ViReal64 analyzerFrequencyHz,
                                               ViReal64 resolutionBandwidthHz,
                                               ViReal64 measTimes,
                                               ViInt32 triggerSource,
                                               ViReal64 triggerLevel,
                                               ViReal64 triggerOffsets,
                                               ViInt32 typeOfMeas,
                                               ViInt32 noOfMeasurements,
                                               ViUInt32 timeout,
                                               ViReal64 _VI_FAR burstPowerResults[]);
ViStatus _VI_FUNC rsemi_GetBurstPowerResults (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 noOfResults,
                                              ViReal64 _VI_FAR burstPowerResults[]);
ViStatus _VI_FUNC rsemi_GetBurstPwrResultMin (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViPReal64 powerResultMin);
ViStatus _VI_FUNC rsemi_ConfigureSEState (ViSession instrumentHandle,
                                          ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureSEPeakSearchDetails (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViBoolean details);
ViStatus _VI_FUNC rsemi_ConfigureSEPeakSearch (ViSession instrumentHandle,
                                               ViInt32 window, ViReal64 margin,
                                               ViInt32 peaksPerRange);
ViStatus _VI_FUNC rsemi_ConfigureSESweepListStartStop (ViSession instrumentHandle,
                                                       ViInt32 range,
                                                       ViReal64 startFrequency,
                                                       ViReal64 stopFrequency);
ViStatus _VI_FUNC rsemi_ConfigureSESweepListFilterType (ViSession instrumentHandle,
                                                        ViInt32 range,
                                                        ViInt32 filter);
ViStatus _VI_FUNC rsemi_ConfigureSESweepListBandwidth (ViSession instrumentHandle,
                                                       ViInt32 range,
                                                       ViReal64 resolutionBandwidth,
                                                       ViReal64 videoBandwidth);
ViStatus _VI_FUNC rsemi_ConfigureSESweepSweepListTime (ViSession instrumentHandle,
                                                       ViInt32 range,
                                                       ViBoolean sweepTimeAuto,
                                                       ViReal64 sweepTime);
ViStatus _VI_FUNC rsemi_ConfigureSESweepListDetector (ViSession instrumentHandle,
                                                      ViInt32 range,
                                                      ViInt32 detector);
ViStatus _VI_FUNC rsemi_ConfigureSESweepListReferenceLevel
             (ViSession instrumentHandle, ViInt32 range, ViReal64 refLevelValue);
ViStatus _VI_FUNC rsemi_ConfigureSESweepListRFAttenuation
             (ViSession instrumentHandle, ViInt32 range, ViBoolean attenuatorAuto,
              ViReal64 manualAttenuatorValuedB);
ViStatus _VI_FUNC rsemi_ConfigureSESweepListPreamplifier (ViSession instrumentHandle,
                                                          ViInt32 range,
                                                          ViBoolean preamplifier);
ViStatus _VI_FUNC rsemi_ConfigureSESweepListPreamplifierLevel
             (ViSession instrumentHandle, ViInt32 range, ViInt32 preamplifierLevel);
ViStatus _VI_FUNC rsemi_ConfigureSESweepListLNAPreamplifier
             (ViSession instrumentHandle, ViInt32 range, ViBoolean preamplifier);
ViStatus _VI_FUNC rsemi_ConfigureSESweepListSweep (ViSession instrumentHandle,
                                                   ViInt32 range,
                                                   ViInt32 sweepPoints,
                                                   ViBoolean stopAfterSweep);
ViStatus _VI_FUNC rsemi_ConfigureSESweepListTransducerFactor
             (ViSession instrumentHandle, ViInt32 range, ViString transducerFactor);
ViStatus _VI_FUNC rsemi_ConfigureSESweepListLimits (ViSession instrumentHandle,
                                                    ViInt32 range,
                                                    ViBoolean limitChecking,
                                                    ViReal64 limit,
                                                    ViReal64 absoluteLimitStart,
                                                    ViReal64 absoluteLimitStop);
ViStatus _VI_FUNC rsemi_SEDeleteRange (ViSession instrumentHandle, ViInt32 range);
ViStatus _VI_FUNC rsemi_GetSENumberOfListRanges (ViSession instrumentHandle,
                                                 ViPInt32 numberOfRanges);
ViStatus _VI_FUNC rsemi_SESearchPeak (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_StoreSEToFile (ViSession instrumentHandle,
                                       ViString fileName);
ViStatus _VI_FUNC rsemi_ReadSEPeakList (ViSession instrumentHandle,
                                        ViInt32 noOfValues,
                                        ViReal64 _VI_FAR frequency[],
                                        ViReal64 _VI_FAR level[],
                                        ViReal64 _VI_FAR deltaLimit[],
                                        ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_SEListEvaluation (ViSession instrumentHandle,
                                          ViBoolean state);
ViStatus _VI_FUNC rsemi_ReadSEListEvaluation (ViSession instrumentHandle,
                                              ViInt32 noOfValues,
                                              ViReal64 _VI_FAR rangeNumber[],
                                              ViReal64 _VI_FAR startFrequency[],
                                              ViReal64 _VI_FAR stopFrequency[],
                                              ViReal64 _VI_FAR resolutionBandwidth[],
                                              ViReal64 _VI_FAR frequency[],
                                              ViReal64 _VI_FAR levelAbs[],
                                              ViReal64 _VI_FAR levelRel[],
                                              ViReal64 _VI_FAR delta[],
                                              ViReal64 _VI_FAR limitCheck[],
                                              ViReal64 _VI_FAR reserved1[],
                                              ViReal64 _VI_FAR reserved2[],
                                              ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_ConfigureSEMState (ViSession instrumentHandle,
                                           ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureSEM (ViSession instrumentHandle,
                                      ViInt32 limitLineType,
                                      ViReal64 limitLineValue);
ViStatus _VI_FUNC rsemi_ConfigureSEMPeakSearch (ViSession instrumentHandle,
                                                ViReal64 margin,
                                                ViInt32 peaksPerRange);
ViStatus _VI_FUNC rsemi_RestoreSEMStandardLines (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_SEMSearchPeak (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_SEMListEvaluation (ViSession instrumentHandle,
                                           ViBoolean state);
ViStatus _VI_FUNC rsemi_ReadSEMListEvaluationResults (ViSession instrumentHandle,
                                                      ViInt32 noOfValues,
                                                      ViReal64 _VI_FAR rangeNumber[],
                                                      ViReal64 _VI_FAR startFrequency[],
                                                      ViReal64 _VI_FAR stopFrequency[],
                                                      ViReal64 _VI_FAR resolutionBandwidth[],
                                                      ViReal64 _VI_FAR frequency[],
                                                      ViReal64 _VI_FAR powerAbs[],
                                                      ViReal64 _VI_FAR powerRel[],
                                                      ViReal64 _VI_FAR delta[],
                                                      ViReal64 _VI_FAR limitCheck[],
                                                      ViReal64 _VI_FAR reserved1[],
                                                      ViReal64 _VI_FAR reserved2[],
                                                      ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_SEMMarkAllPeaks (ViSession instrumentHandle,
                                         ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureSEMReferenceRange (ViSession instrumentHandle,
                                                    ViInt32 powerReferenceType,
                                                    ViReal64 txBandwidth,
                                                    ViBoolean RRCFilterState,
                                                    ViReal64 RRCFilterAlpha);
ViStatus _VI_FUNC rsemi_QuerySEMReferenceRangePosition (ViSession instrumentHandle,
                                                        ViPInt32 referenceRangePosition);
ViStatus _VI_FUNC rsemi_ConfigureFastSEM (ViSession instrumentHandle,
                                          ViBoolean fastSEM);
ViStatus _VI_FUNC rsemi_ConfigureSEMPresetStandard (ViSession instrumentHandle,
                                                    ViString presetStandard);
ViStatus _VI_FUNC rsemi_RestoreSEMStandardFiles (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_StoreSEMPresetSettings (ViSession instrumentHandle,
                                                ViString settingsFileName);
ViStatus _VI_FUNC rsemi_SEMSaveListToFile (ViSession instrumentHandle,
                                           ViString fileName);
ViStatus _VI_FUNC rsemi_ConfigureSEMRangeStartStop (ViSession instrumentHandle,
                                                    ViInt32 range,
                                                    ViReal64 rangeStart,
                                                    ViReal64 rangeStop);
ViStatus _VI_FUNC rsemi_ConfigureSEMRangeFilterType (ViSession instrumentHandle,
                                                     ViInt32 range,
                                                     ViInt32 filterType);
ViStatus _VI_FUNC rsemi_ConfigureSEMRangeBandwidth (ViSession instrumentHandle,
                                                    ViInt32 range,
                                                    ViReal64 resolutionBandwidth,
                                                    ViReal64 videoBandwidth);
ViStatus _VI_FUNC rsemi_ConfigureSEMRangeSweepTime (ViSession instrumentHandle,
                                                    ViInt32 range,
                                                    ViBoolean sweepTimeMode,
                                                    ViReal64 sweepTime);
ViStatus _VI_FUNC rsemi_ConfigureSEMRangeReferenceLevel (ViSession instrumentHandle,
                                                         ViInt32 range,
                                                         ViReal64 referenceLevel);
ViStatus _VI_FUNC rsemi_ConfigureSEMRangeRFAttenuation (ViSession instrumentHandle,
                                                        ViInt32 range,
                                                        ViBoolean RFAttenuationMode,
                                                        ViReal64 RFAttenuator,
                                                        ViBoolean preamplifiier);
ViStatus _VI_FUNC rsemi_ConfigureSEMRangeLNAPreamplifier (ViSession instrumentHandle,
                                                          ViInt32 range,
                                                          ViBoolean preamplifier);
ViStatus _VI_FUNC rsemi_ConfigureSEMRangeTransducerFactor
             (ViSession instrumentHandle, ViInt32 range, ViString transducerFactor);
ViStatus _VI_FUNC rsemi_ConfigureSEMRangeLimits (ViSession instrumentHandle,
                                                 ViInt32 range, ViInt32 source,
                                                 ViInt32 limitCheckType,
                                                 ViReal64 absoluteLimitStart,
                                                 ViReal64 absoluteLimitStop,
                                                 ViReal64 relativeLimitStart,
                                                 ViReal64 relativeLimitStop);
ViStatus _VI_FUNC rsemi_GetSEMRangeCount (ViSession instrumentHandle,
                                          ViPInt32 rangeCount);
ViStatus _VI_FUNC rsemi_SEMInsertNewRange (ViSession instrumentHandle,
                                           ViInt32 range, ViInt32 insertRange);
ViStatus _VI_FUNC rsemi_SEMDeleteRange (ViSession instrumentHandle, ViInt32 range);
ViStatus _VI_FUNC rsemi_ConfigureSEMUsedPowerClasses (ViSession instrumentHandle,
                                                      ViInt32 powerClassNumber,
                                                      ViInt32 usedPowerClass);
ViStatus _VI_FUNC rsemi_ConfigureSEMPowerClassCount (ViSession instrumentHandle,
                                                     ViInt32 count);
ViStatus _VI_FUNC rsemi_ConfigureSEMPowerClassLimits (ViSession instrumentHandle,
                                                      ViInt32 powerClassNumber,
                                                      ViInt32 limitState,
                                                      ViReal64 lowerLevelLimit,
                                                      ViReal64 upperLevelLimit);
ViStatus _VI_FUNC rsemi_ConfigureSEMPowerClassAllLimits (ViSession instrumentHandle,
                                                         ViInt32 numberOfLimits,
                                                         ViReal64 _VI_FAR limits[]);
ViStatus _VI_FUNC rsemi_QuerySEMPowerClassAllLimits (ViSession instrumentHandle,
                                                     ViReal64 _VI_FAR limits[]);
ViStatus _VI_FUNC rsemi_ConfigureSEMSubblockCount (ViSession instrumentHandle,
                                                   ViInt32 count);
ViStatus _VI_FUNC rsemi_ConfigureSEMSubblockCenterFrequency
             (ViSession instrumentHandle, ViInt32 subBlock,
              ViReal64 centerFrequency);
ViStatus _VI_FUNC rsemi_ConfigureSEMSubblockReferenceRange
             (ViSession instrumentHandle, ViInt32 subBlock,
              ViInt32 powerReferenceType, ViReal64 txBandwidth,
              ViBoolean RRCFilterState, ViReal64 RRCFilterAlpha);
ViStatus _VI_FUNC rsemi_QuerySEMSubblockReferenceRangePosition
             (ViSession instrumentHandle, ViInt32 subBlock,
              ViPInt32 referenceRangePosition);
ViStatus _VI_FUNC rsemi_ConfigureFastSEMSubblock (ViSession instrumentHandle,
                                                  ViInt32 subBlock,
                                                  ViBoolean fastSEM);
ViStatus _VI_FUNC rsemi_ConfigureSEMSubblockPresetStandard
             (ViSession instrumentHandle, ViInt32 subBlock,
              ViString presetStandard);
ViStatus _VI_FUNC rsemi_RestoreSEMSubblockStandardFiles (ViSession instrumentHandle,
                                                         ViInt32 subBlock);
ViStatus _VI_FUNC rsemi_StoreSEMSubblockPresetSettings (ViSession instrumentHandle,
                                                        ViInt32 subBlock,
                                                        ViString settingsFileName);
ViStatus _VI_FUNC rsemi_ConfigureSEMSubblockRangeStartStop
             (ViSession instrumentHandle, ViInt32 subBlock, ViInt32 range,
              ViReal64 rangeStart, ViReal64 rangeStop);
ViStatus _VI_FUNC rsemi_ConfigureSEMSubblockRangeFilterType
             (ViSession instrumentHandle, ViInt32 subBlock, ViInt32 range,
              ViInt32 filterType);
ViStatus _VI_FUNC rsemi_ConfigureSEMSubblockRangeBandwidth
             (ViSession instrumentHandle, ViInt32 subBlock, ViInt32 range,
              ViReal64 resolutionBandwidth, ViReal64 videoBandwidth);
ViStatus _VI_FUNC rsemi_ConfigureSEMSubblockRangeSweepTime
             (ViSession instrumentHandle, ViInt32 subBlock, ViInt32 range,
              ViBoolean sweepTimeMode, ViReal64 sweepTime);
ViStatus _VI_FUNC rsemi_ConfigureSEMSubblockRangeReferenceLevel
             (ViSession instrumentHandle, ViInt32 subBlock, ViInt32 range,
              ViReal64 referenceLevel);
ViStatus _VI_FUNC rsemi_ConfigureSEMSubblockRangeRFAttenuation
             (ViSession instrumentHandle, ViInt32 subBlock, ViInt32 range,
              ViBoolean RFAttenuationMode, ViReal64 RFAttenuator,
              ViBoolean preamplifiier, ViInt32 preamplifiierLevel);
ViStatus _VI_FUNC rsemi_ConfigureSEMSubblockRangeTransducerFactor
             (ViSession instrumentHandle, ViInt32 subBlock, ViInt32 range,
              ViString transducerFactor);
ViStatus _VI_FUNC rsemi_ConfigureSEMSubblockRangeMultiLimitCalc
             (ViSession instrumentHandle, ViInt32 subBlock, ViInt32 range,
              ViInt32 multiLimitCalc);
ViStatus _VI_FUNC rsemi_ConfigureSEMSubblockRangeMinimumSweepPoints
             (ViSession instrumentHandle, ViInt32 subBlock, ViInt32 range,
              ViInt32 minimumSweepPoints);
ViStatus _VI_FUNC rsemi_ConfigureSEMSubblockRangeLimits (ViSession instrumentHandle,
                                                         ViInt32 subBlock,
                                                         ViInt32 range,
                                                         ViInt32 source,
                                                         ViInt32 limitCheckType,
                                                         ViReal64 absoluteLimitStart,
                                                         ViReal64 absoluteLimitStop,
                                                         ViReal64 relativeLimitStart,
                                                         ViReal64 relativeLimitStop);
ViStatus _VI_FUNC rsemi_ConfigureSEMSubblockRangeRelativeLimitStartFunction
             (ViSession instrumentHandle, ViInt32 subBlock, ViInt32 range,
              ViInt32 source, ViInt32 function, ViReal64 relativeLevel,
              ViReal64 absoluteLevel);
ViStatus _VI_FUNC rsemi_ConfigureSEMSubblockRangeRelativeLimitStopFunction
             (ViSession instrumentHandle, ViInt32 subBlock, ViInt32 range,
              ViInt32 source, ViInt32 function, ViReal64 relativeLevel,
              ViReal64 absoluteLevel);
ViStatus _VI_FUNC rsemi_GetSEMSubblockRangeCount (ViSession instrumentHandle,
                                                  ViInt32 subBlock,
                                                  ViPInt32 rangeCount);
ViStatus _VI_FUNC rsemi_SEMSubblockInsertNewRange (ViSession instrumentHandle,
                                                   ViInt32 subBlock, ViInt32 range,
                                                   ViInt32 insertRange);
ViStatus _VI_FUNC rsemi_SEMSubblockDeleteRange (ViSession instrumentHandle,
                                                ViInt32 subBlock, ViInt32 range);
ViStatus _VI_FUNC rsemi_ConfigureMSRSettings (ViSession instrumentHandle,
                                              ViInt32 subBlock,
                                              ViInt32 bandCategory,
                                              ViReal64 RFBandwidth,
                                              ViBoolean GSMEdgePresent,
                                              ViBoolean LTEPresent);
ViStatus _VI_FUNC rsemi_MSRApplyToSEM (ViSession instrumentHandle,
                                       ViInt32 subBlock);
ViStatus _VI_FUNC rsemi_ConfigureADEMResultUnit (ViSession instrumentHandle,
                                                 ViInt32 resultUnit);
ViStatus _VI_FUNC rsemi_ConfigureAnalogBasebandInputParameters
             (ViSession instrumentHandle, ViInt32 iQMode,
              ViBoolean inputConfiguration);
ViStatus _VI_FUNC rsemi_ConfigureAnalogBasebandFullscaleLevel
             (ViSession instrumentHandle, ViBoolean mode, ViReal64 level);
ViStatus _VI_FUNC rsemi_RealtimeSpectrumAnalysisMode (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_IQAnalyzerMode (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramFrequencyCenterSpan
             (ViSession instrumentHandle, ViReal64 centerFrequency, ViReal64 span);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramFrequencyFullSpan
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramFrequencyOffset
             (ViSession instrumentHandle, ViReal64 frequencyOffset);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramFrequencyCenterStepSize
             (ViSession instrumentHandle, ViReal64 stepSize);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramFrequencyCouplingFactor
             (ViSession instrumentHandle, ViInt32 coupling, ViInt32 couplingFactor);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramAcquisition (ViSession instrumentHandle,
                                                         ViBoolean sweepModeContinuous,
                                                         ViInt32 numberOfSweeps);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramSweepTime (ViSession instrumentHandle,
                                                       ViBoolean sweepTimeAuto,
                                                       ViReal64 sweepTime);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramBandwidth (ViSession instrumentHandle,
                                                       ViBoolean resolutionBandwidthAuto,
                                                       ViReal64 resolutionBandwidth,
                                                       ViReal64 reserved);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramBandwidthRatio
             (ViSession instrumentHandle, ViReal64 resolutionBandwidthRatio);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramBandwidthRatioMinMax
             (ViSession instrumentHandle, ViInt32 ratio);
ViStatus _VI_FUNC rsemi_QuerySpectrogramBandwidthRatioMinMax
             (ViSession instrumentHandle, ViPReal64 minimum, ViPReal64 maximum);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDisplayParameters
             (ViSession instrumentHandle, ViInt32 window, ViInt32 color,
              ViInt32 reserved);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramColors (ViSession instrumentHandle,
                                                    ViReal64 shape,
                                                    ViInt32 colorStyle,
                                                    ViReal64 colorLower,
                                                    ViReal64 colorUpper);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDefaultColors
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMeasurementParameters
             (ViSession instrumentHandle, ViInt32 window, ViInt32 historyDepth,
              ViBoolean timeStamp, ViInt32 frameCount, ViBoolean continueFrame);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramSelectedFrame
             (ViSession instrumentHandle, ViInt32 window, ViInt32 frameNumber);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramSelectedFrameMinMax
             (ViSession instrumentHandle, ViInt32 window, ViInt32 minMax);
ViStatus _VI_FUNC rsemi_QuerySpectrogramSelectedFrameMinMax
             (ViSession instrumentHandle, ViInt32 window, ViPInt32 minimum,
              ViPInt32 maximum);
ViStatus _VI_FUNC rsemi_SpectrogramClear (ViSession instrumentHandle,
                                          ViInt32 window);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramFFTWindow (ViSession instrumentHandle,
                                                       ViInt32 FFTWindowType);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramReferenceLevel
             (ViSession instrumentHandle, ViReal64 referenceLevel);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramReferenceLevelOffset
             (ViSession instrumentHandle, ViReal64 referenceLevelOffset);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramUnit (ViSession instrumentHandle,
                                                  ViInt32 powerUnit);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramInputImpedance
             (ViSession instrumentHandle, ViInt32 inputImpedance);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramInputCoupling
             (ViSession instrumentHandle, ViInt32 inputCoupling);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramRFAttenuation
             (ViSession instrumentHandle, ViBoolean autoAttenuation,
              ViReal64 attenuation);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramPreamplifier (ViSession instrumentHandle,
                                                          ViBoolean preamplifier);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramNoiseCorrection
             (ViSession instrumentHandle, ViInt32 noiseCorrection);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDisplayVerticalScaling
             (ViSession instrumentHandle, ViInt32 reserved, ViInt32 scalingType);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDisplayVerticalGridMode
             (ViSession instrumentHandle, ViInt32 window, ViInt32 yAxisGridMode);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDisplayLogRange
             (ViSession instrumentHandle, ViInt32 window, ViReal64 range);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDisplayZoom (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViBoolean zoomState,
                                                         ViReal64 startFrequency,
                                                         ViReal64 startTime,
                                                         ViReal64 stopFrequency,
                                                         ViReal64 stopTime);
ViStatus _VI_FUNC rsemi_AddSpectrogramWindow (ViSession instrumentHandle,
                                              ViInt32 stringSize,
                                              ViString windowName,
                                              ViInt32 direction, ViInt32 windowType,
                                              ViChar _VI_FAR returnedWindowName[]);
ViStatus _VI_FUNC rsemi_RemoveSpectrogramWindow (ViSession instrumentHandle,
                                                 ViString windowName);
ViStatus _VI_FUNC rsemi_ReplaceSpectrogramWindow (ViSession instrumentHandle,
                                                  ViString windowName,
                                                  ViInt32 windowType);
ViStatus _VI_FUNC rsemi_QuerySpectrogramWindowsList (ViSession instrumentHandle,
                                                     ViInt32 bufferSize,
                                                     ViChar _VI_FAR results[]);
ViStatus _VI_FUNC rsemi_QuerySpectrogramWindowIndex (ViSession instrumentHandle,
                                                     ViString windowName,
                                                     ViPInt32 index);
ViStatus _VI_FUNC rsemi_QuerySpectrogramWindowName (ViSession instrumentHandle,
                                                    ViInt32 stringSize,
                                                    ViInt32 index,
                                                    ViChar _VI_FAR windowName[]);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramSplitterPosition
             (ViSession instrumentHandle, ViString firstWindowName,
              ViString secondWindowName, ViInt32 position);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramTrace (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 trace,
                                                   ViInt32 mode);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramTraceDetector
             (ViSession instrumentHandle, ViInt32 trace, ViInt32 detector);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramResetBehavior
             (ViSession instrumentHandle, ViInt32 window, ViInt32 trace,
              ViBoolean resetAtChange);
ViStatus _VI_FUNC rsemi_CopySpectrogramTrace (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViInt32 destinationTrace,
                                              ViInt32 sourceTrace);
ViStatus _VI_FUNC rsemi_StoreTraceToFile (ViSession instrumentHandle,
                                          ViInt32 window, ViInt32 trace,
                                          ViInt32 decimalSeparator,
                                          ViString fileName);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarker (ViSession instrumentHandle,
                                                    ViInt32 window, ViInt32 marker,
                                                    ViBoolean state, ViInt32 trace);
ViStatus _VI_FUNC rsemi_SpectrogramMoveMarker (ViSession instrumentHandle,
                                               ViInt32 window, ViInt32 marker,
                                               ViReal64 position);
ViStatus _VI_FUNC rsemi_QuerySpectrogramMarker (ViSession instrumentHandle,
                                                ViInt32 window, ViInt32 marker,
                                                ViPReal64 markerAmplitude);
ViStatus _VI_FUNC rsemi_SpectrogramDisableAllMarkers (ViSession instrumentHandle,
                                                      ViInt32 window);
ViStatus _VI_FUNC rsemi_SpectrogramSetInstrumentFromMarker
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker,
              ViInt32 instrumentSetting);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerZoom (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViInt32 marker,
                                                        ViReal64 markerZoom,
                                                        ViInt32 timeout);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerStepSize
             (ViSession instrumentHandle, ViInt32 stepSize);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerFrameNumber
             (ViSession instrumentHandle, ViInt32 window, ViInt32 markerNumber,
              ViInt32 frameNumber);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerSearchArea
             (ViSession instrumentHandle, ViInt32 window, ViInt32 markerNumber,
              ViInt32 searchArea);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerSearchLimits
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker,
              ViBoolean searchLimits, ViReal64 searchLimitLeft,
              ViReal64 searchLimitRight);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerSearchLimitsZoom
             (ViSession instrumentHandle, ViBoolean searchLimitsZoom);
ViStatus _VI_FUNC rsemi_SpectrogramMarkerSearch (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViInt32 markerNumber,
                                                 ViInt32 searchMode);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerSearchPeakAuto
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker,
              ViInt32 markerSearch, ViBoolean autoPeak);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerSearchLocalOscillator
             (ViSession instrumentHandle, ViInt32 window,
              ViBoolean localOscillatorSuppression);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerSearchPeakExcursion
             (ViSession instrumentHandle, ViInt32 window, ViReal64 peakExcursion);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerSearchThreshold
             (ViSession instrumentHandle, ViBoolean thresholdState,
              ViReal64 markerThreshold);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerTable (ViSession instrumentHandle,
                                                         ViInt32 markerTable);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDeltaMarker (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViInt32 deltaMarker,
                                                         ViBoolean state,
                                                         ViInt32 trace);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDeltaMarkerPosition
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker,
              ViInt32 mode, ViReal64 position);
ViStatus _VI_FUNC rsemi_QuerySpectrogramDeltaMarker (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViInt32 deltaMarker,
                                                     ViInt32 mode,
                                                     ViPReal64 position,
                                                     ViPReal64 amplitude);
ViStatus _VI_FUNC rsemi_SpectrogramDisableAllDeltaMarkers
             (ViSession instrumentHandle, ViInt32 window);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDeltaMarkerFrameNumber
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarkerNumber,
              ViInt32 frameNumber);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDeltaMarkerSearchArea
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker,
              ViInt32 searchArea);
ViStatus _VI_FUNC rsemi_SpectrogramDeltaMarkerSearch (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViInt32 deltaMarker,
                                                      ViInt32 searchMode);
ViStatus _VI_FUNC rsemi_SpectrogramLinkMarkerAndDeltaMarker
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker,
              ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramReferenceMarker
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker,
              ViInt32 marker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramTriggerSource
             (ViSession instrumentHandle, ViInt32 triggerSource);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramTrigger (ViSession instrumentHandle,
                                                     ViReal64 triggerDelay,
                                                     ViInt32 triggerPolarity,
                                                     ViReal64 preTriggerTime,
                                                     ViReal64 postTriggerTime);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramContinuousTrigger
             (ViSession instrumentHandle, ViInt32 trigger);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramTimeDomainTrigger
             (ViSession instrumentHandle, ViReal64 timeDomainTriggerLevel);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyMaskTriggerSource
             (ViSession instrumentHandle, ViInt32 window);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyMask (ViSession instrumentHandle,
                                                ViInt32 window, ViString name,
                                                ViString comment);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyMaskDirectory (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViString directory);
ViStatus _VI_FUNC rsemi_DeleteFrequencyMask (ViSession instrumentHandle,
                                             ViInt32 window, ViString name);
ViStatus _VI_FUNC rsemi_DeleteSelectedFrequencyMask (ViSession instrumentHandle,
                                                     ViInt32 window);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyMaskCondition (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViInt32 condition);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyMaskShape (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViInt32 arraySize,
                                                     ViInt32 mode,
                                                     ViReal64 _VI_FAR lower[],
                                                     ViReal64 _VI_FAR upper[]);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyMaskShapeLowerOrUpper
             (ViSession instrumentHandle, ViInt32 window, ViInt32 arraySize,
              ViInt32 mode, ViInt32 shape, ViReal64 _VI_FAR data[]);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyMaskAuto (ViSession instrumentHandle,
                                                    ViInt32 window);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyMaskShift (ViSession instrumentHandle,
                                                     ViInt32 window, ViInt32 type,
                                                     ViReal64 frequency,
                                                     ViReal64 amplitude);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyMaskState (ViSession instrumentHandle,
                                                     ViInt32 window, ViInt32 type,
                                                     ViBoolean frequencyMask);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyMaskSpan (ViSession instrumentHandle,
                                                    ViInt32 window, ViReal64 span);
ViStatus _VI_FUNC rsemi_ConfigurePersistenceSpectrumParameters
             (ViSession instrumentHandle, ViInt32 window, ViInt32 trace,
              ViBoolean enablePersistence, ViReal64 duration, ViReal64 granularity);
ViStatus _VI_FUNC rsemi_ConfigurePersistenceSpectrumDisplayParameters
             (ViSession instrumentHandle, ViInt32 window, ViReal64 shape,
              ViInt32 style, ViReal64 colorLower, ViReal64 colorUpper);
ViStatus _VI_FUNC rsemi_ConfigurePersistenceSpectrumDefaultColors
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ConfigurePersistenceSpectrumTruncate
             (ViSession instrumentHandle, ViInt32 window, ViBoolean truncate);
ViStatus _VI_FUNC rsemi_ConfigurePersistenceSpectrumTraceStyle
             (ViSession instrumentHandle, ViInt32 window, ViInt32 trace,
              ViInt32 symbol);
ViStatus _VI_FUNC rsemi_ConfigurePersistenceSpectrumMaxholdIntensity
             (ViSession instrumentHandle, ViInt32 window, ViInt32 trace,
              ViBoolean enableMaxhold, ViInt32 intensity);
ViStatus _VI_FUNC rsemi_ConfigurePersistenceSpectrumMaxholdReset
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ConfigurePersistenceSpectrumMarkerPosition
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker,
              ViInt32 markerPosition);
ViStatus _VI_FUNC rsemi_QueryPersistenceMarkerZAxis (ViSession instrumentHandle,
                                                     ViInt32 window, ViInt32 marker,
                                                     ViPReal64 zAxis);
ViStatus _VI_FUNC rsemi_ConfigurePersistenceSpectrumDeltaMarkerPosition
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker,
              ViInt32 deltaMarkerPostion);
ViStatus _VI_FUNC rsemi_QueryPersistenceDeltaMarkerZAxis (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViInt32 deltaMarker,
                                                          ViPReal64 zAxis);
ViStatus _VI_FUNC rsemi_ConfigureResultDisplay (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViInt32 resultDisplay);
ViStatus _VI_FUNC rsemi_GetSpectrogramTimeStamp (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32 frame,
                                                 ViInt32 arraySize,
                                                 ViInt32 _VI_FAR part1[],
                                                 ViInt32 _VI_FAR part2[],
                                                 ViInt32 _VI_FAR part3[],
                                                 ViInt32 _VI_FAR part4[],
                                                 ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_ReadTraceData (ViSession instrumentHandle, ViInt32 window,
                                       ViInt32 timeout, ViInt32 resultsType,
                                       ViInt32 arraySize,
                                       ViReal64 _VI_FAR traceData[],
                                       ViPInt32 noOfValues);
ViStatus _VI_FUNC rsemi_ReadSpectrogramTraceData (ViSession instrumentHandle,
                                                  ViInt32 window, ViInt32 timeout,
                                                  ViInt32 arraySize,
                                                  ViReal64 _VI_FAR results[],
                                                  ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_ReadPersistenceSpectrumTraceData (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViInt32 timeout,
                                                          ViInt32 arraySize,
                                                          ViReal64 _VI_FAR results[],
                                                          ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_ReadMaxholdTraceData (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 timeout,
                                              ViInt32 arraySize,
                                              ViReal64 _VI_FAR results[],
                                              ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_FetchTraceData (ViSession instrumentHandle, ViInt32 window,
                                        ViInt32 resultsType, ViInt32 arraySize,
                                        ViReal64 _VI_FAR traceData[],
                                        ViPInt32 noOfValues);
ViStatus _VI_FUNC rsemi_FetchSpectrogramTraceData (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViInt32 arraySize,
                                                   ViReal64 _VI_FAR results[],
                                                   ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_FetchPersistenceSpectrumTraceData
             (ViSession instrumentHandle, ViInt32 window, ViInt32 arraySize,
              ViReal64 _VI_FAR results[], ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_FetchMaxholdTraceData (ViSession instrumentHandle,
                                               ViInt32 window, ViInt32 arraySize,
                                               ViReal64 _VI_FAR results[],
                                               ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_GetSpectrogramXAxisScaling (ViSession instrumentHandle,
                                                    ViInt32 window, ViInt32 frame,
                                                    ViInt32 arraySize,
                                                    ViReal64 _VI_FAR xAxis[],
                                                    ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_StoreSpectrogramToFile (ViSession instrumentHandle,
                                                ViString fileName);
ViStatus _VI_FUNC rsemi_Initiate (ViSession instrumentHandle, ViInt32 window,
                                  ViInt32 timeout);
ViStatus _VI_FUNC rsemi_Continue (ViSession instrumentHandle, ViInt32 window);
ViStatus _VI_FUNC rsemi_ReceiverMode (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ReceiverMeasurementSequences (ViSession instrumentHandle,
                                                      ViInt32 measurement);
ViStatus _VI_FUNC rsemi_ConfigureInputImpedance (ViSession instrumentHandle,
                                                 ViInt32 inputImpedance);
ViStatus _VI_FUNC rsemi_ConfigureTraceDetectorSelection (ViSession instrumentHandle,
                                                         ViInt32 trace,
                                                         ViInt32 detector);
ViStatus _VI_FUNC rsemi_ConfigureAcquisition (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViBoolean sweepModeContinuous,
                                              ViInt32 numberOfSweeps);
ViStatus _VI_FUNC rsemi_QueryStartedSweepNumber (ViSession instrumentHandle,
                                                 ViPInt32 sweepCount);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyStartStop (ViSession instrumentHandle,
                                                     ViReal64 startFrequency,
                                                     ViReal64 stopFrequency);
ViStatus _VI_FUNC rsemi_ConfigureReceiverFrequency (ViSession instrumentHandle,
                                                    ViReal64 receiverFrequency);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyCenterStepSize (ViSession instrumentHandle,
                                                          ViReal64 stepSize);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyCenterStepSizeAuto
             (ViSession instrumentHandle, ViBoolean stepSizeAuto);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyCenterCouplingFactor
             (ViSession instrumentHandle, ViInt32 coupling, ViInt32 couplingFactor);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyCenterStepSizeType
             (ViSession instrumentHandle, ViInt32 type);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyMode (ViSession instrumentHandle,
                                                ViInt32 mode);
ViStatus _VI_FUNC rsemi_ConfigureScanTime (ViSession instrumentHandle,
                                           ViReal64 scanTime);
ViStatus _VI_FUNC rsemi_ConfigureTimeDomainMode (ViSession instrumentHandle,
                                                 ViInt32 mode);
ViStatus _VI_FUNC rsemi_ConfigureFrequencySignalTrack (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViBoolean signalTrackEnabled,
                                                       ViReal64 signalTrackBandwidth,
                                                       ViReal64 signalTrackThreshold,
                                                       ViInt32 trace);
ViStatus _VI_FUNC rsemi_ConfigureFrequencySignalTrackBandwidthMinMax
             (ViSession instrumentHandle, ViInt32 window, ViInt32 minMax);
ViStatus _VI_FUNC rsemi_QueryFrequencySignalTrackBandwidthMinMax
             (ViSession instrumentHandle, ViInt32 window, ViPReal64 minimum,
              ViPReal64 maximum);
ViStatus _VI_FUNC rsemi_ConfigureAmplitudeLevelUnit (ViSession instrumentHandle,
                                                     ViInt32 powerUnit);
ViStatus _VI_FUNC rsemi_ConfigureAmplitudeMinimumLevel (ViSession instrumentHandle,
                                                        ViInt32 reserved,
                                                        ViInt32 reserved2,
                                                        ViReal64 level);
ViStatus _VI_FUNC rsemi_ConfigureAmplitudeScalingType (ViSession instrumentHandle,
                                                       ViInt32 reserved,
                                                       ViInt32 reserved2,
                                                       ViInt32 scalingType);
ViStatus _VI_FUNC rsemi_ConfigureRFInput (ViSession instrumentHandle,
                                          ViInt32 source);
ViStatus _VI_FUNC rsemi_ConfigureRFInputCoupling (ViSession instrumentHandle,
                                                  ViInt32 RFInputCoupling);
ViStatus _VI_FUNC rsemi_ConfigureIFSpanCoupled (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViBoolean spanCoupled);
ViStatus _VI_FUNC rsemi_ConfigureResolutionBandwidth (ViSession instrumentHandle,
                                                      ViBoolean resolutionBandwidthAuto,
                                                      ViReal64 resolutionBandwidth);
ViStatus _VI_FUNC rsemi_ConfigureResolutionBandwidthFilterType
             (ViSession instrumentHandle, ViInt32 filterType);
ViStatus _VI_FUNC rsemi_ConfigureRFAttenuationLevel (ViSession instrumentHandle,
                                                     ViReal64 attenuation);
ViStatus _VI_FUNC rsemi_ConfigureRFAttenuationProtection (ViSession instrumentHandle,
                                                          ViBoolean attenuationProtection);
ViStatus _VI_FUNC rsemi_ConfigurePreamplifier (ViSession instrumentHandle,
                                               ViBoolean preamplifierAuto,
                                               ViBoolean preamplifier,
                                               ViBoolean autoRange);
ViStatus _VI_FUNC rsemi_ConfigureMarker (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32 marker, ViBoolean markerEnabled,
                                         ViInt32 trace);
ViStatus _VI_FUNC rsemi_ConfigureMarkerFrequencyCoupling (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViInt32 marker,
                                                          ViBoolean markerTracking);
ViStatus _VI_FUNC rsemi_ConfigureReceiverFromMarker (ViSession instrumentHandle,
                                                     ViInt32 window, ViInt32 marker,
                                                     ViInt32 instrumentSetting);
ViStatus _VI_FUNC rsemi_ConfigureMarkerZoom (ViSession instrumentHandle,
                                             ViInt32 window, ViInt32 marker,
                                             ViReal64 range, ViInt32 timeout);
ViStatus _VI_FUNC rsemi_ConfigureMarkerInfoFieldState (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViBoolean infoFieldEnabled);
ViStatus _VI_FUNC rsemi_ConfigureMarkerCoupling (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32 marker,
                                                 ViBoolean settingsCoupled);
ViStatus _VI_FUNC rsemi_ConfigureMarkerCouplingUseLastScan
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker,
              ViBoolean useLastScan);
ViStatus _VI_FUNC rsemi_ConfigureMarkerSearchLimits (ViSession instrumentHandle,
                                                     ViInt32 window, ViInt32 marker,
                                                     ViBoolean searchLimits,
                                                     ViReal64 searchLimitLeft,
                                                     ViReal64 searchLimitRight);
ViStatus _VI_FUNC rsemi_ConfigureMarkerSearch (ViSession instrumentHandle,
                                               ViInt32 window, ViInt32 marker,
                                               ViInt32 markerSearch);
ViStatus _VI_FUNC rsemi_MoveMarker (ViSession instrumentHandle, ViInt32 window,
                                    ViInt32 marker, ViReal64 position);
ViStatus _VI_FUNC rsemi_DisableAllMarkers (ViSession instrumentHandle,
                                           ViInt32 window);
ViStatus _VI_FUNC rsemi_QueryMarker (ViSession instrumentHandle, ViInt32 window,
                                     ViInt32 marker, ViPReal64 markerAmplitude);
ViStatus _VI_FUNC rsemi_ConfigureMarkerAmplitude (ViSession instrumentHandle,
                                                  ViInt32 window, ViInt32 marker,
                                                  ViReal64 markerAmplitude);
ViStatus _VI_FUNC rsemi_ConfigureDeltaMarker (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 deltaMarker,
                                              ViBoolean state, ViInt32 trace);
ViStatus _VI_FUNC rsemi_DisableAllDeltaMarker (ViSession instrumentHandle,
                                               ViInt32 window);
ViStatus _VI_FUNC rsemi_LinkMarkerAndDeltaMarker (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViInt32 deltaMarker,
                                                  ViBoolean state);
ViStatus _VI_FUNC rsemi_DeltaMarkerSearch (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 deltaMarker,
                                           ViInt32 deltaMarkerSearch);
ViStatus _VI_FUNC rsemi_ConfigureDeltaMarkerPosition (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViInt32 deltaMarker,
                                                      ViInt32 deltaMarkerMode,
                                                      ViReal64 position);
ViStatus _VI_FUNC rsemi_QueryDeltaMarker (ViSession instrumentHandle,
                                          ViInt32 window, ViInt32 deltaMarker,
                                          ViInt32 mode, ViPReal64 position,
                                          ViPReal64 amplitude);
ViStatus _VI_FUNC rsemi_ConfigureDisplayBargraphMaxhold (ViSession instrumentHandle,
                                                         ViBoolean bargraphMaxhold);
ViStatus _VI_FUNC rsemi_ResetDisplayBargraphMaxhold (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_QueryDisplayBargraphLevel (ViSession instrumentHandle,
                                                   ViInt32 levelType,
                                                   ViPReal64 bargraphLevel);
ViStatus _VI_FUNC rsemi_ConfigureDisplayBargraphDetectorSelection
             (ViSession instrumentHandle, ViInt32 arraySize,
              ViInt32 _VI_FAR detector[]);
ViStatus _VI_FUNC rsemi_ConfigureDisplayBargraphMeasurementTime
             (ViSession instrumentHandle, ViReal64 time);
ViStatus _VI_FUNC rsemi_ConfigureDisplayBargraphTraceMode
             (ViSession instrumentHandle, ViInt32 window, ViInt32 trace,
              ViInt32 mode);
ViStatus _VI_FUNC rsemi_ConfigureDisplayBargraphCoupling (ViSession instrumentHandle,
                                                          ViBoolean coupling);
ViStatus _VI_FUNC rsemi_ConfigureTimeLineState (ViSession instrumentHandle,
                                                ViInt32 window, ViInt32 line,
                                                ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureTimeLinePosition (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 line,
                                                   ViReal64 position);
ViStatus _VI_FUNC rsemi_ConfigureDisplayLineState (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 line,
                                                   ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureDisplayLinePosition (ViSession instrumentHandle,
                                                      ViInt32 window, ViInt32 line,
                                                      ViReal64 position);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyLineState (ViSession instrumentHandle,
                                                     ViInt32 window, ViInt32 line,
                                                     ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyLinePosition (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViInt32 line,
                                                        ViReal64 position);
ViStatus _VI_FUNC rsemi_CreateLimitLine (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32 limit, ViString name,
                                         ViInt32 domain, ViString comment,
                                         ViInt32 assignToTrace,
                                         ViBoolean deleteExistingLimitLine);
ViStatus _VI_FUNC rsemi_QueryActiveLimitLines (ViSession instrumentHandle,
                                               ViInt32 arraySize,
                                               ViChar _VI_FAR activeLimitLines[],
                                               ViPInt32 returnedStringLength);
ViStatus _VI_FUNC rsemi_CopyLimitLine (ViSession instrumentHandle, ViInt32 limit,
                                       ViInt32 copyTo);
ViStatus _VI_FUNC rsemi_ConfigureLimitLinesUnit (ViSession instrumentHandle,
                                                 ViInt32 limit, ViInt32 unit);
ViStatus _VI_FUNC rsemi_ConfigureLimitLineScaling (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 limit,
                                                   ViInt32 type,
                                                   ViInt32 limitLineScaling);
ViStatus _VI_FUNC rsemi_DefineLimitLine (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32 limit, ViInt32 type, ViInt32 count,
                                         ViReal64 _VI_FAR xAxis[],
                                         ViReal64 _VI_FAR amplitude[]);
ViStatus _VI_FUNC rsemi_ConfigureLimitLineMargin (ViSession instrumentHandle,
                                                  ViInt32 limit, ViInt32 type,
                                                  ViReal64 margin);
ViStatus _VI_FUNC rsemi_ConfigureLimitLineOffset (ViSession instrumentHandle,
                                                  ViInt32 limit, ViInt32 type,
                                                  ViReal64 offset);
ViStatus _VI_FUNC rsemi_ConfigureLimitLineShift (ViSession instrumentHandle,
                                                 ViInt32 limit, ViInt32 type,
                                                 ViReal64 distance);
ViStatus _VI_FUNC rsemi_ConfigureLimitLineInterpolation (ViSession instrumentHandle,
                                                         ViInt32 limit,
                                                         ViInt32 type,
                                                         ViInt32 interpolationMode);
ViStatus _VI_FUNC rsemi_ConfigureLimitLineVisibility (ViSession instrumentHandle,
                                                      ViInt32 limit, ViInt32 type,
                                                      ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureLimitLineThreshold (ViSession instrumentHandle,
                                                     ViInt32 limit, ViInt32 type,
                                                     ViReal64 threshold);
ViStatus _VI_FUNC rsemi_ConfigureLimitLineCheck (ViSession instrumentHandle,
                                                 ViInt32 limit, ViBoolean state);
ViStatus _VI_FUNC rsemi_ClearLimitLineCheckResult (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_QueryLimitLineCheckResult (ViSession instrumentHandle,
                                                   ViInt32 limit, ViPInt32 result);
ViStatus _VI_FUNC rsemi_AddReceiverWindow (ViSession instrumentHandle,
                                           ViInt32 stringSize, ViString windowName,
                                           ViInt32 direction, ViInt32 windowType,
                                           ViChar _VI_FAR returnedWindowName[]);
ViStatus _VI_FUNC rsemi_RemoveReceiverWindow (ViSession instrumentHandle,
                                              ViString windowName);
ViStatus _VI_FUNC rsemi_ReplaceReceiverWindow (ViSession instrumentHandle,
                                               ViString windowName,
                                               ViInt32 windowType);
ViStatus _VI_FUNC rsemi_QueryReceiverWindowsList (ViSession instrumentHandle,
                                                  ViInt32 bufferSize,
                                                  ViChar _VI_FAR results[]);
ViStatus _VI_FUNC rsemi_QueryReceiverWindowIndex (ViSession instrumentHandle,
                                                  ViString windowName,
                                                  ViPInt32 index);
ViStatus _VI_FUNC rsemi_QueryReceiverWindowName (ViSession instrumentHandle,
                                                 ViInt32 stringSize, ViInt32 index,
                                                 ViChar _VI_FAR windowName[]);
ViStatus _VI_FUNC rsemi_ConfigureReceiverSplitterPosition
             (ViSession instrumentHandle, ViString firstWindowName,
              ViString secondWindowName, ViInt32 position);
ViStatus _VI_FUNC rsemi_ConfigureAnalogDemodulationState (ViSession instrumentHandle,
                                                          ViInt32 demodulation);
ViStatus _VI_FUNC rsemi_ConfigureAnalogDemodulationSquelching
             (ViSession instrumentHandle, ViBoolean squelchState,
              ViReal64 threshold);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramState (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViBoolean spectrogramState);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramClear (ViSession instrumentHandle,
                                                   ViInt32 window);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramSelectFrame (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViReal64 frame);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramFramesInMemory
             (ViSession instrumentHandle, ViInt32 window, ViInt32 frames);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramLayout (ViSession instrumentHandle,
                                                    ViInt32 window, ViInt32 layout);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramTraceNew (ViSession instrumentHandle,
                                                      ViInt32 trace);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramTimeStamp (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViBoolean timeStamp);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramColorDefault
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramColor (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 color);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramColorStyle (ViSession instrumentHandle,
                                                        ViInt32 style);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramColorShape (ViSession instrumentHandle,
                                                        ViReal64 shape);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramColorLower (ViSession instrumentHandle,
                                                        ViInt32 lower);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramColorUpper (ViSession instrumentHandle,
                                                        ViInt32 upper);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerFrame (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViInt32 marker,
                                                         ViReal64 frame);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerFrameTime
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker,
              ViReal64 frameTime);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerSearchAreaSGR
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker,
              ViInt32 searchArea);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerMaximumLevel
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerMinimumLevel
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerYNextPeakAbove
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerYNextPeakBelow
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerYNextPeak
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerYPeak (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViInt32 marker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerYNextMinimumAbove
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerYNextMinimumBelow
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerYNextMinimum
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramMarkerYMinimum
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDeltaMarkerFrame
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker,
              ViReal64 frame);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDeltaMarkerFrameTime
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker,
              ViReal64 frameTime);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDeltaMarkerSearchAreaSGR
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker,
              ViInt32 searchArea);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDeltaMarkerMaximumLevel
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDeltaMarkerMinimumLevel
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDeltaMarkerYNextPeakAbove
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDeltaMarkerYNextPeakBelow
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDeltaMarkerYNextPeak
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDeltaMarkerYPeak
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDeltaMarkerYNextMinimumAbove
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDeltaMarkerYNextMinimumBelow
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDeltaMarkerYNextMinimum
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker);
ViStatus _VI_FUNC rsemi_ConfigureSpectrogramDeltaMarkerYMinimum
             (ViSession instrumentHandle, ViInt32 window, ViInt32 deltaMarker);
ViStatus _VI_FUNC rsemi_ConfigureReceiverTriggerOffset (ViSession instrumentHandle,
                                                        ViReal64 triggerOffset);
ViStatus _VI_FUNC rsemi_ConfigureReceiverIFPowerTrigger (ViSession instrumentHandle,
                                                         ViReal64 triggerLevel,
                                                         ViReal64 holdoff,
                                                         ViReal64 hysteresis);
ViStatus _VI_FUNC rsemi_ConfigureReceiverRFPowerTrigger (ViSession instrumentHandle,
                                                         ViReal64 triggerLevel);
ViStatus _VI_FUNC rsemi_ConfigureReceiverTimeTrigger (ViSession instrumentHandle,
                                                      ViReal64 timeInterval);
ViStatus _VI_FUNC rsemi_ReadReceiverTraceData (ViSession instrumentHandle,
                                               ViInt32 timeout, ViInt32 resultsType,
                                               ViInt32 arraySize,
                                               ViReal64 _VI_FAR traceData[],
                                               ViPInt32 noOfValues);
ViStatus _VI_FUNC rsemi_ReadReceiverFinalMeasurement (ViSession instrumentHandle,
                                                      ViInt32 timeout,
                                                      ViInt32 finalMeasurement,
                                                      ViInt32 noOfValues,
                                                      ViReal64 _VI_FAR frequency[],
                                                      ViReal64 _VI_FAR level[],
                                                      ViReal64 _VI_FAR deltaLevel[],
                                                      ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_ReadReceiverPeakList (ViSession instrumentHandle,
                                              ViInt32 timeout, ViInt32 peakList,
                                              ViInt32 noOfValues,
                                              ViReal64 _VI_FAR frequency[],
                                              ViReal64 _VI_FAR level[],
                                              ViReal64 _VI_FAR deltaLevel[],
                                              ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_ReadSpectrogramTimeStampData (ViSession instrumentHandle,
                                                      ViInt32 window, ViInt32 mode,
                                                      ViInt32 arraySize,
                                                      ViChar _VI_FAR timeStamp[]);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyScanStepMode (ViSession instrumentHandle,
                                                        ViInt32 spacing);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyScanRangeStartStop
             (ViSession instrumentHandle, ViInt32 range, ViReal64 startFrequency,
              ViReal64 stopFrequency);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyScanStepSize (ViSession instrumentHandle,
                                                        ViInt32 range,
                                                        ViReal64 frequency);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyScanBandwidth (ViSession instrumentHandle,
                                                         ViInt32 range,
                                                         ViReal64 bandwidth);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyScanMeasurementTime
             (ViSession instrumentHandle, ViInt32 range, ViReal64 time);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyScanMeasurementTimeMinMax
             (ViSession instrumentHandle, ViInt32 range, ViInt32 minMax);
ViStatus _VI_FUNC rsemi_QueryFrequencyScanMeasurementTimeMinMax
             (ViSession instrumentHandle, ViInt32 range, ViPReal64 minimum,
              ViPReal64 maximum);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyScanRFAttenuation
             (ViSession instrumentHandle, ViInt32 range, ViReal64 attenuation);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyScanAutoRangingState
             (ViSession instrumentHandle, ViInt32 range, ViBoolean autoRanging,
              ViBoolean autoPreamplifier, ViBoolean preamplifier);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyScanRangeSignalSource
             (ViSession instrumentHandle, ViInt32 range, ViInt32 source);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyScanRangeCount (ViSession instrumentHandle,
                                                          ViInt32 range,
                                                          ViInt32 rangesCount);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyScanRangePreamplifierGain
             (ViSession instrumentHandle, ViInt32 range, ViInt32 preamplifierGain);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyScanIFAttenuation
             (ViSession instrumentHandle, ViInt32 range, ViBoolean attenuationAuto,
              ViReal64 attenuation);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyScanLNAPreamplifierState
             (ViSession instrumentHandle, ViInt32 range, ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyScanLNAPreamplifier
             (ViSession instrumentHandle, ViInt32 range,
              ViBoolean LNAPreamplifierAuto);
ViStatus _VI_FUNC rsemi_ConfigureFrequencyScanAxisScale (ViSession instrumentHandle,
                                                         ViInt32 reserved,
                                                         ViInt32 reserved2,
                                                         ViInt32 scale);
ViStatus _VI_FUNC rsemi_ConfigureScanTransmissionMode (ViSession instrumentHandle,
                                                       ViInt32 control,
                                                       ViInt32 transmissionMode);
ViStatus _VI_FUNC rsemi_ConfigureScanPoints (ViSession instrumentHandle,
                                             ViInt32 numberOfPoints);
ViStatus _VI_FUNC rsemi_PeakSearch (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ConfigurePeakSearchExcursion (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViReal64 peakExcursion);
ViStatus _VI_FUNC rsemi_ConfigurePeakSearchMargin (ViSession instrumentHandle,
                                                   ViReal64 margin);
ViStatus _VI_FUNC rsemi_AddPeakSearchFrequency (ViSession instrumentHandle,
                                                ViReal64 frequency);
ViStatus _VI_FUNC rsemi_ConfigurePeakSearchListCreationMethod
             (ViSession instrumentHandle, ViInt32 method, ViInt32 methodValue);
ViStatus _VI_FUNC rsemi_ConfigurePeakSearchNumber (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViInt32 peakNumber);
ViStatus _VI_FUNC rsemi_ClearPeakSearchList (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ConfigurePeakListDisplay (ViSession instrumentHandle,
                                                  ViInt32 trace, ViInt32 symbol);
ViStatus _VI_FUNC rsemi_ConfigurePeakListMeasurementFile (ViSession instrumentHandle,
                                                          ViString fileName);
ViStatus _VI_FUNC rsemi_QueryPeakListSize (ViSession instrumentHandle, ViInt32 *size);
ViStatus _VI_FUNC rsemi_QueryPeakListData (ViSession instrumentHandle,
                                           ViInt32 arraySize,
                                           ViInt32 detectorBufferSize,
                                           ViInt32 commentBufferSize,
                                           ViInt32 _VI_FAR traceNumber[],
                                           ViChar _VI_FAR detector[],
                                           ViReal64 _VI_FAR frequency[],
                                           ViReal64 _VI_FAR level[],
                                           ViReal64 _VI_FAR deltaLimit[],
                                           ViChar _VI_FAR comment[]);
ViStatus _VI_FUNC rsemi_ConfigurePeakListPeakComment (ViSession instrumentHandle,
                                                      ViInt32 peak,
                                                      ViString comment);
ViStatus _VI_FUNC rsemi_QueryPeakListPeakFrequency (ViSession instrumentHandle,
                                                    ViInt32 peak,
                                                    ViPReal64 frequency);
ViStatus _VI_FUNC rsemi_QueryPeakListPeakLevel (ViSession instrumentHandle,
                                                ViInt32 peak, ViPReal64 level);
ViStatus _VI_FUNC rsemi_QueryPeakListPeakDetector (ViSession instrumentHandle,
                                                   ViInt32 peak,
                                                   ViInt32 detectorBufferSize,
                                                   ViChar _VI_FAR detector[]);
ViStatus _VI_FUNC rsemi_QueryPeakListPeakDeltaLimit (ViSession instrumentHandle,
                                                     ViInt32 peak,
                                                     ViPReal64 deltaLimit);
ViStatus _VI_FUNC rsemi_QueryPeakListPeakTrace (ViSession instrumentHandle,
                                                ViInt32 peak, ViPInt32 traceNumber);
ViStatus _VI_FUNC rsemi_QueryPeakListPeakData (ViSession instrumentHandle,
                                               ViInt32 peak,
                                               ViInt32 detectorBufferSize,
                                               ViInt32 commentBufferSize,
                                               ViPInt32 traceNumber,
                                               ViChar _VI_FAR detector[],
                                               ViPReal64 frequency, ViPReal64 level,
                                               ViPReal64 deltaLimit,
                                               ViChar _VI_FAR comment[]);
ViStatus _VI_FUNC rsemi_DeletePeakListPeak (ViSession instrumentHandle,
                                            ViInt32 peak);
ViStatus _VI_FUNC rsemi_ConfigureFinalMeasurementDetector
             (ViSession instrumentHandle, ViInt32 trace, ViInt32 detector);
ViStatus _VI_FUNC rsemi_ConfigureFinalMeasurementAutoState
             (ViSession instrumentHandle, ViBoolean automaticMeasurement);
ViStatus _VI_FUNC rsemi_ConfigureFinalMeasurementPeakFrequencyTime
             (ViSession instrumentHandle, ViReal64 time);
ViStatus _VI_FUNC rsemi_ConfigureFinalMeasurementPeakListFile
             (ViSession instrumentHandle, ViString fileName);
ViStatus _VI_FUNC rsemi_ConfigureFinalMeasurementVnetworkPhase
             (ViSession instrumentHandle, ViInt32 arraySize,
              ViInt32 _VI_FAR phases[]);
ViStatus _VI_FUNC rsemi_QueryFinalMeasurementPeakListSize
             (ViSession instrumentHandle, ViInt32 *size);
ViStatus _VI_FUNC rsemi_QueryFinalMeasurementPeakListData
             (ViSession instrumentHandle, ViInt32 arraySize,
              ViInt32 detectorBufferSize, ViInt32 commentBufferSize,
              ViInt32 _VI_FAR traceNumber[], ViChar _VI_FAR detector[],
              ViReal64 _VI_FAR frequency[], ViReal64 _VI_FAR level[],
              ViReal64 _VI_FAR deltaLimit[], ViChar _VI_FAR comment[]);
ViStatus _VI_FUNC rsemi_ConfigureFinalMeasurementPeakComment
             (ViSession instrumentHandle, ViInt32 peak, ViString comment);
ViStatus _VI_FUNC rsemi_QueryFinalMeasurementPeakFrequency
             (ViSession instrumentHandle, ViInt32 peak, ViPReal64 frequency);
ViStatus _VI_FUNC rsemi_QueryFinalMeasurementPeakLevel (ViSession instrumentHandle,
                                                        ViInt32 peak,
                                                        ViPReal64 level);
ViStatus _VI_FUNC rsemi_QueryFinalMeasurementPeakDetector
             (ViSession instrumentHandle, ViInt32 peak, ViInt32 detectorBufferSize,
              ViChar _VI_FAR detector[]);
ViStatus _VI_FUNC rsemi_QueryFinalMeasurementPeakDeltaLimit
             (ViSession instrumentHandle, ViInt32 peak, ViPReal64 deltaLimit);
ViStatus _VI_FUNC rsemi_QueryFinalMeasurementPeakTrace (ViSession instrumentHandle,
                                                        ViInt32 peak,
                                                        ViPInt32 traceNumber);
ViStatus _VI_FUNC rsemi_QueryFinalMeasurementPeakData (ViSession instrumentHandle,
                                                       ViInt32 peak,
                                                       ViInt32 detectorBufferSize,
                                                       ViInt32 commentBufferSize,
                                                       ViPInt32 traceNumber,
                                                       ViChar _VI_FAR detector[],
                                                       ViPReal64 frequency,
                                                       ViPReal64 level,
                                                       ViPReal64 deltaLimit,
                                                       ViChar _VI_FAR comment[]);
ViStatus _VI_FUNC rsemi_ConfigurePrescanningVnetworkHighpass
             (ViSession instrumentHandle, ViBoolean _150KHzHighPassFilter);
ViStatus _VI_FUNC rsemi_ConfigurePrescanningVnetworkPhase
             (ViSession instrumentHandle, ViInt32 phases);
ViStatus _VI_FUNC rsemi_ConfigurePrescanningVnetworkType (ViSession instrumentHandle,
                                                          ViInt32 networkType);
ViStatus _VI_FUNC rsemi_InitiateEMITest (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32 timeout);
ViStatus _VI_FUNC rsemi_InitiateFinalMeasurementTest (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViInt32 timeout);
ViStatus _VI_FUNC rsemi_FetchReceiverTraceData (ViSession instrumentHandle,
                                                ViInt32 resultsType,
                                                ViInt32 arraySize,
                                                ViReal64 _VI_FAR traceData[],
                                                ViPInt32 noOfValues);
ViStatus _VI_FUNC rsemi_FetchReceiverFinalMeasurement (ViSession instrumentHandle,
                                                       ViInt32 finalMeasurement,
                                                       ViInt32 noOfValues,
                                                       ViReal64 _VI_FAR frequency[],
                                                       ViReal64 _VI_FAR level[],
                                                       ViReal64 _VI_FAR deltaLevel[],
                                                       ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_FetchReceiverPeakList (ViSession instrumentHandle,
                                               ViInt32 peakList, ViInt32 noOfValues,
                                               ViReal64 _VI_FAR frequency[],
                                               ViReal64 _VI_FAR level[],
                                               ViReal64 _VI_FAR deltaLevel[],
                                               ViPInt32 returnedValues);
ViStatus _VI_FUNC rsemi_FetchReceiverPeakResults (ViSession instrumentHandle,
                                                  ViInt32 arraySize,
                                                  ViReal64 _VI_FAR peakLevel[],
                                                  ViReal64 _VI_FAR peakFrequency[],
                                                  ViPInt32 numberOfResults);
ViStatus _VI_FUNC rsemi_FetchReceiverScanMeasurement (ViSession instrumentHandle,
                                                      ViInt32 arraySize,
                                                      ViPInt32 traceStatus,
                                                      ViPInt32 numberOfResults,
                                                      ViChar _VI_FAR statusData[],
                                                      ViReal64 _VI_FAR resultsOfTrace1[],
                                                      ViReal64 _VI_FAR resultsOfTrace2[],
                                                      ViReal64 _VI_FAR resultsOfTrace3[]);
ViStatus _VI_FUNC rsemi_FetchReceiverScanMeasurementStatus
             (ViSession instrumentHandle, ViChar _VI_FAR statusData[]);
ViStatus _VI_FUNC rsemi_FetchReceiverDetector (ViSession instrumentHandle,
                                               ViInt32 arraySize,
                                               ViReal64 _VI_FAR detectors[],
                                               ViPInt32 noOfValues);
ViStatus _VI_FUNC rsemi_InitiateScan (ViSession instrumentHandle, ViInt32 window,
                                      ViInt32 timeout);
ViStatus _VI_FUNC rsemi_HoldScan (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ContinueScanAtHold (ViSession instrumentHandle,
                                            ViInt32 window);
ViStatus _VI_FUNC rsemi_ContinueScanAtReceiverFrequency (ViSession instrumentHandle,
                                                         ViInt32 window);
ViStatus _VI_FUNC rsemi_StopScan (ViSession instrumentHandle, ViInt32 timeout);
ViStatus _VI_FUNC rsemi_ConfigureExternalGeneratorGPIB (ViSession instrumentHandle,
                                                        ViInt32 generatorAddress,
                                                        ViInt32 TTLHandshake,
                                                        ViString generatorType,
                                                        ViInt32 reference);
ViStatus _VI_FUNC rsemi_TrackingGeneratorEnable (ViSession instrumentHandle,
                                                 ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureTrackingGenerator (ViSession instrumentHandle,
                                                    ViInt32 measurementType,
                                                    ViBoolean normalization);
ViStatus _VI_FUNC rsemi_ConfigureTrackingGeneratorCalibration
             (ViSession instrumentHandle, ViInt32 calibration);
ViStatus _VI_FUNC rsemi_TrackingGeneratorRestore (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ConfigureTrackingGeneratorModulationAM
             (ViSession instrumentHandle, ViInt32 window, ViBoolean AM);
ViStatus _VI_FUNC rsemi_ConfigureTrackingGeneratorModulationIQ
             (ViSession instrumentHandle, ViInt32 window, ViBoolean IQ);
ViStatus _VI_FUNC rsemi_ConfigureTrackingGeneratorModulationFM
             (ViSession instrumentHandle, ViInt32 window, ViBoolean FM,
              ViReal64 deviation);
ViStatus _VI_FUNC rsemi_ConfigureTrackingGeneratorModulationFrequencyOffset
             (ViSession instrumentHandle, ViInt32 window, ViReal64 offset);
ViStatus _VI_FUNC rsemi_ConfigureTrackingGeneratorModulationLevel
             (ViSession instrumentHandle, ViInt32 window, ViReal64 outputLevel,
              ViReal64 offset);
ViStatus _VI_FUNC rsemi_ConfigureTrackingGeneratorPower (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViReal64 start,
                                                         ViReal64 stop);
ViStatus _VI_FUNC rsemi_ConfigureTrackingGeneratorPowerMode
             (ViSession instrumentHandle, ViInt32 window, ViInt32 mode);
ViStatus _VI_FUNC rsemi_ConfigureDisplayUpdate (ViSession instrumentHandle,
                                                ViBoolean displayInRemote);
ViStatus _VI_FUNC rsemi_SelectTransducerFactor (ViSession instrumentHandle,
                                                ViInt32 reserved,
                                                ViBoolean transducerState,
                                                ViString transducerName);
ViStatus _VI_FUNC rsemi_ConfigureTransducerFactor (ViSession instrumentHandle,
                                                   ViInt32 reserved, ViString name,
                                                   ViInt32 unit,
                                                   ViInt32 interpolation,
                                                   ViString comment,
                                                   ViInt32 noOfTestPoints,
                                                   ViReal64 _VI_FAR frequencyData[],
                                                   ViReal64 _VI_FAR levelData[]);
ViStatus _VI_FUNC rsemi_ConfigureTransducerFactorRefLevAdj
             (ViSession instrumentHandle, ViInt32 reserved, ViBoolean refLevAdj);
ViStatus _VI_FUNC rsemi_ConfigureDisplayTransducerState (ViSession instrumentHandle,
                                                         ViInt32 reserved,
                                                         ViBoolean state);
ViStatus _VI_FUNC rsemi_QueryTransducerFactorCatalog (ViSession instrumentHandle,
                                                      ViPInt32 numberOfTransducerFactors,
                                                      ViInt32 bufferSize,
                                                      ViChar _VI_FAR transducerFactorsList[]);
ViStatus _VI_FUNC rsemi_DeleteTransducerFactor (ViSession instrumentHandle,
                                                ViInt32 reserved,
                                                ViString transducerName);
ViStatus _VI_FUNC rsemi_GetTransducerActive (ViSession instrumentHandle,
                                             ViChar _VI_FAR activeTransducer[]);
ViStatus _VI_FUNC rsemi_SelectTransducerSet (ViSession instrumentHandle,
                                             ViString transducerSetName,
                                             ViBoolean transducerSetState);
ViStatus _VI_FUNC rsemi_ConfigureTransducerSet (ViSession instrumentHandle,
                                                ViString transducerSetName,
                                                ViString comment, ViInt32 unit,
                                                ViBoolean transducerBreak,
                                                ViInt32 range,
                                                ViReal64 startFrequency,
                                                ViReal64 stopFrequency,
                                                ViString factors);
ViStatus _VI_FUNC rsemi_ConfigureTransducerFactors (ViSession instrumentHandle,
                                                    ViInt32 range,
                                                    ViReal64 startFrequency,
                                                    ViReal64 stopFrequency,
                                                    ViString factors);
ViStatus _VI_FUNC rsemi_QueryTransducerSetCatalog (ViSession instrumentHandle,
                                                   ViPInt32 numberOfTransducerSets,
                                                   ViInt32 bufferSize,
                                                   ViChar _VI_FAR transducerSetsList[]);
ViStatus _VI_FUNC rsemi_DeleteTransducerSet (ViSession instrumentHandle,
                                             ViString transducerSetName);
ViStatus _VI_FUNC rsemi_QueryActiveTransducerSet (ViSession instrumentHandle,
                                                  ViChar _VI_FAR activeTransducerSet[]);
ViStatus _VI_FUNC rsemi_ConnectingRFSwitch (ViSession instrumentHandle,
                                            ViString networkAddress);
ViStatus _VI_FUNC rsemi_ControlRFSwitch (ViSession instrumentHandle, ViInt32 range,
                                         ViBoolean SCPI, ViString command);
ViStatus _VI_FUNC rsemi_ConfigureRFSwitchDataset (ViSession instrumentHandle,
                                                  ViString datasetName,
                                                  ViString comment);
ViStatus _VI_FUNC rsemi_RFSwitchDatasetFileOperations (ViSession instrumentHandle,
                                                       ViInt32 operation,
                                                       ViString filename);
ViStatus _VI_FUNC rsemi_SelectRFSwitchInput (ViSession instrumentHandle,
                                             ViInt32 RFInput);
ViStatus _VI_FUNC rsemi_SelectTransducerRFInputFactor (ViSession instrumentHandle,
                                                       ViInt32 RFInput,
                                                       ViBoolean transducerState);
ViStatus _VI_FUNC rsemi_GetTransducerRFInputActive (ViSession instrumentHandle,
                                                    ViInt32 RFInput,
                                                    ViChar _VI_FAR activeTransducer[]);
ViStatus _VI_FUNC rsemi_SelectTransducerSetRFInput (ViSession instrumentHandle,
                                                    ViInt32 RFInput,
                                                    ViBoolean transducerSetState);
ViStatus _VI_FUNC rsemi_QueryActiveTransducerSetRFInput (ViSession instrumentHandle,
                                                         ViInt32 RFInput,
                                                         ViChar _VI_FAR activeTransducerSet[]);
ViStatus _VI_FUNC rsemi_FileDecimalSeparator (ViSession instrumentHandle,
                                              ViInt32 decimalSeparator);
ViStatus _VI_FUNC rsemi_FileManagerOperations (ViSession instrumentHandle,
                                               ViInt32 operation, ViString source,
                                               ViString destination);
ViStatus _VI_FUNC rsemi_FileDirectory (ViSession instrumentHandle,
                                       ViString directory, ViInt32 bufferSize,
                                       ViChar _VI_FAR output[]);
ViStatus _VI_FUNC rsemi_FileDirectoryPath (ViSession instrumentHandle,
                                           ViString directory, ViInt32 bufferSize,
                                           ViChar _VI_FAR output[]);
ViStatus _VI_FUNC rsemi_DataSetFileOperations (ViSession instrumentHandle,
                                               ViInt32 operation, ViString path);
ViStatus _VI_FUNC rsemi_DataSetFileComment (ViSession instrumentHandle,
                                            ViString comment);
ViStatus _VI_FUNC rsemi_DataSetFileClearAll (ViSession instrumentHandle,
                                             ViString directory);
ViStatus _VI_FUNC rsemi_DataSetFileSelectItems (ViSession instrumentHandle,
                                                ViInt32 itemSelector,
                                                ViBoolean itemState);
ViStatus _VI_FUNC rsemi_DataSetStoreMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rsemi_ConfigureUserSettingsSoftkey (ViSession instrumentHandle,
                                                      ViInt32 softkeyNumber,
                                                      ViString filename,
                                                      ViString label);
ViStatus _VI_FUNC rsemi_NetworkMapDrive (ViSession instrumentHandle,
                                         ViString driveLetter,
                                         ViString hostNameIPAddress,
                                         ViBoolean useOptionalParameters,
                                         ViString userName, ViString password,
                                         ViBoolean reconnectAtLogon);
ViStatus _VI_FUNC rsemi_NetworkDisconnectDrive (ViSession instrumentHandle,
                                                ViString driveLetter);
ViStatus _VI_FUNC rsemi_NetworkUnusedDrivesList (ViSession instrumentHandle,
                                                 ViInt32 arraySize,
                                                 ViChar _VI_FAR unusedDrives[]);
ViStatus _VI_FUNC rsemi_NetworkUsedDrivesList (ViSession instrumentHandle,
                                               ViBoolean showFolderInfo,
                                               ViInt32 arraySize,
                                               ViChar _VI_FAR usedDrives[]);
ViStatus _VI_FUNC rsemi_TestReportDefault (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_TestReportContentsConfiguration (ViSession instrumentHandle,
                                                         ViInt32 arraySize,
                                                         ViInt32 _VI_FAR items[]);
ViStatus _VI_FUNC rsemi_QueryTestReportInformation (ViSession instrumentHandle,
                                                    ViInt32 channelType,
                                                    ViInt32 bufferSize,
                                                    ViChar _VI_FAR information[]);
ViStatus _VI_FUNC rsemi_TestReportHeaderState (ViSession instrumentHandle,
                                               ViBoolean enabled);
ViStatus _VI_FUNC rsemi_TestReportHeaderLine (ViSession instrumentHandle,
                                              ViInt32 line, ViString title,
                                              ViString text, ViInt32 visibility);
ViStatus _VI_FUNC rsemi_TestReportHeaderLogo (ViSession instrumentHandle,
                                              ViString logo, ViInt32 visibility);
ViStatus _VI_FUNC rsemi_ConfigureTestReportGeneralProperties
             (ViSession instrumentHandle, ViBoolean titleEnabled,
              ViBoolean showPageCountEnabled,
              ViBoolean printerFriendlyColorsEnabled, ViBoolean timeStampEnabled);
ViStatus _VI_FUNC rsemi_TestReportTitle (ViSession instrumentHandle, ViString title,
                                         ViString description, ViInt32 pageSize);
ViStatus _VI_FUNC rsemi_TestReportTemplateOperations (ViSession instrumentHandle,
                                                      ViInt32 operation,
                                                      ViString path);
ViStatus _VI_FUNC rsemi_TestReportTemplateCatalog (ViSession instrumentHandle,
                                                   ViPInt32 numberOfTempplates,
                                                   ViInt32 bufferSize,
                                                   ViChar _VI_FAR templateList[]);
ViStatus _VI_FUNC rsemi_TestReportDataSetsConfiguration (ViSession instrumentHandle,
                                                         ViInt32 selector,
                                                         ViInt32 dataset);
ViStatus _VI_FUNC rsemi_TestReportDataSetSelect (ViSession instrumentHandle,
                                                 ViInt32 dataset, ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureHardcopyDevice (ViSession instrumentHandle,
                                                 ViInt32 device,
                                                 ViInt32 destination,
                                                 ViInt32 pageOrientation);
ViStatus _VI_FUNC rsemi_HardcopyAbort (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_HardcopyOutput (ViSession instrumentHandle, ViInt32 output);
ViStatus _VI_FUNC rsemi_HardcopyPrint (ViSession instrumentHandle, ViInt32 device,
                                       ViInt32 items);
ViStatus _VI_FUNC rsemi_HardcopyPrintNext (ViSession instrumentHandle,
                                           ViInt32 device);
ViStatus _VI_FUNC rsemi_HardcopySetFileName (ViSession instrumentHandle,
                                             ViString name);
ViStatus _VI_FUNC rsemi_HardcopyGetPrinterList (ViSession instrumentHandle,
                                                ViInt32 bufferSize,
                                                ViChar _VI_FAR printerList[]);
ViStatus _VI_FUNC rsemi_HardcopySetPrinter (ViSession instrumentHandle,
                                            ViInt32 device, ViString printerName);
ViStatus _VI_FUNC rsemi_HardcopyComment (ViSession instrumentHandle,
                                         ViString comment);
ViStatus _VI_FUNC rsemi_HardcopyTimeDate (ViSession instrumentHandle,
                                          ViInt32 device,
                                          ViBoolean timeAndDateStamp);
ViStatus _VI_FUNC rsemi_HardcopyColor (ViSession instrumentHandle, ViBoolean color,
                                       ViInt32 defaultSetting);
ViStatus _VI_FUNC rsemi_ConfigureHardcopyColor (ViSession instrumentHandle,
                                                ViInt32 colorMap, ViReal64 TINT,
                                                ViReal64 SATURATION,
                                                ViReal64 BRIGHTNESS);
ViStatus _VI_FUNC rsemi_ConfigureHardcopyColorByPredefined
             (ViSession instrumentHandle, ViInt32 colorMap,
              ViInt32 predefinedColors);
ViStatus _VI_FUNC rsemi_ConfigureControlLinesState (ViSession instrumentHandle,
                                                    ViInt32 reserved,
                                                    ViBoolean state);
ViStatus _VI_FUNC rsemi_ConfigureOutputControlLines (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViString userPorts);
ViStatus _VI_FUNC rsemi_GetControlLines (ViSession instrumentHandle,
                                         ViInt32 reserved, ViInt32 lines,
                                         ViChar _VI_FAR userPorts[]);
ViStatus _VI_FUNC rsemi_ServiceConfigureInput (ViSession instrumentHandle,
                                               ViInt32 reserved, ViInt32 input);
ViStatus _VI_FUNC rsemi_ServiceConfigurePulsedInput (ViSession instrumentHandle,
                                                     ViInt32 reserved,
                                                     ViBoolean reserved2,
                                                     ViReal64 frequency);
ViStatus _VI_FUNC rsemi_ServiceConfigureNoise (ViSession instrumentHandle,
                                               ViBoolean noise);
ViStatus _VI_FUNC rsemi_ConfigureCalibrationFreqRF (ViSession instrumentHandle,
                                                    ViReal64 frequency,
                                                    ViInt32 RFSpectrum);
ViStatus _VI_FUNC rsemi_ConfigureCalibrationFreqMW (ViSession instrumentHandle,
                                                    ViInt32 distance);
ViStatus _VI_FUNC rsemi_ConfigureCalAutoPowerReduction (ViSession instrumentHandle,
                                                        ViBoolean automaticPowerReduction);
ViStatus _VI_FUNC rsemi_ConfigureCalKitAdditionalDir (ViSession instrumentHandle,
                                                      ViString additionalDirectory);
ViStatus _VI_FUNC rsemi_ConfigureCalibrationFreqMicrowave
             (ViSession instrumentHandle, ViReal64 frequency);
ViStatus _VI_FUNC rsemi_ServiceHWInfo (ViSession instrumentHandle,
                                       ViInt32 arraySize, ViChar _VI_FAR HWInfo[]);
ViStatus _VI_FUNC rsemi_ServiceVersionInfo (ViSession instrumentHandle,
                                            ViInt32 arraySize,
                                            ViChar _VI_FAR versionInfo[]);
ViStatus _VI_FUNC rsemi_SetStatusRegisterValue (ViSession instrumentHandle,
                                                ViInt32 registerOperation,
                                                ViInt32 questionableRegister,
                                                ViInt32 enable, ViInt32 PTransition,
                                                ViInt32 NTransition);
ViStatus _VI_FUNC rsemi_GetStatusRegisterValue (ViSession instrumentHandle,
                                                ViInt32 registerOperation,
                                                ViInt32 questionableRegister,
                                                ViInt32 registerPart,
                                                ViPInt32 registerValue);
ViStatus _VI_FUNC rsemi_SetAttributeViInt32 (ViSession instrumentHandle,
                                             ViString repeatedCapabilityName,
                                             ViUInt32 attributeID,
                                             ViInt32 attributeValue);
ViStatus _VI_FUNC rsemi_SetAttributeViReal64 (ViSession instrumentHandle,
                                              ViString repeatedCapabilityName,
                                              ViUInt32 attributeID,
                                              ViReal64 attributeValue);
ViStatus _VI_FUNC rsemi_SetAttributeViString (ViSession instrumentHandle,
                                              ViString repeatedCapabilityName,
                                              ViUInt32 attributeID,
                                              ViString attributeValue);
ViStatus _VI_FUNC rsemi_SetAttributeViBoolean (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViBoolean attributeValue);
ViStatus _VI_FUNC rsemi_SetAttributeViSession (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViSession attributeValue);
ViStatus _VI_FUNC rsemi_GetAttributeRepeatedCapabilityIds
             (ViSession instrumentHandle, ViUInt32 attributeID, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityId_s[]);
ViStatus _VI_FUNC rsemi_GetAttributeRepeatedCapabilityIdNames
             (ViSession instrumentHandle, ViUInt32 attributeID,
              ViString repeatedCapabilityId, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityIdName_s[]);
ViStatus _VI_FUNC rsemi_GetAttributeViInt32 (ViSession instrumentHandle,
                                             ViString repeatedCapabilityName,
                                             ViUInt32 attributeID,
                                             ViPInt32 attributeValue);
ViStatus _VI_FUNC rsemi_GetAttributeViReal64 (ViSession instrumentHandle,
                                              ViString repeatedCapabilityName,
                                              ViUInt32 attributeID,
                                              ViPReal64 attributeValue);
ViStatus _VI_FUNC rsemi_GetAttributeViString (ViSession instrumentHandle,
                                              ViString repeatedCapabilityName,
                                              ViUInt32 attributeID,
                                              ViInt32 bufferSize,
                                              ViChar _VI_FAR attributeValue[]);
ViStatus _VI_FUNC rsemi_GetAttributeViBoolean (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViPBoolean attributeValue);
ViStatus _VI_FUNC rsemi_GetAttributeViSession (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViPSession attributeValue);
ViStatus _VI_FUNC rsemi_CheckAttributeViInt32 (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViInt32 attributeValue);
ViStatus _VI_FUNC rsemi_CheckAttributeViReal64 (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViReal64 attributeValue);
ViStatus _VI_FUNC rsemi_CheckAttributeViString (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViString attributeValue);
ViStatus _VI_FUNC rsemi_CheckAttributeViBoolean (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViBoolean attributeValue);
ViStatus _VI_FUNC rsemi_CheckAttributeViSession (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViSession attributeValue);
ViStatus _VI_FUNC rsemi_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ConfigureErrorChecking (ViSession instrumentHandle,
                                                ViBoolean optionChecking,
                                                ViBoolean rangeChecking,
                                                ViBoolean statusChecking);
ViStatus _VI_FUNC rsemi_self_test (ViSession instrumentHandle,
                                   ViPInt16 selfTestResult,
                                   ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rsemi_SelfTestResults (ViSession instrumentHandle,
                                         ViInt32 bufferSize,
                                         ViChar _VI_FAR results[]);
ViStatus _VI_FUNC rsemi_revision_query (ViSession instrumentHandle,
                                        ViChar _VI_FAR instrumentDriverRevision[],
                                        ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rsemi_SystemVersion (ViSession instrumentHandle, ViInt32 length,
                                       ViChar _VI_FAR systemVersion[]);
ViStatus _VI_FUNC rsemi_error_query (ViSession instrumentHandle, ViPInt32 errorCode,
                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rsemi_error_message (ViSession instrumentHandle,
                                       ViStatus errorCode,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rsemi_ErrorList (ViSession instrumentHandle, ViInt32 bufferSize,
                                   ViChar _VI_FAR errors[]);
ViStatus _VI_FUNC rsemi_ClearInstrumentErrors (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ClearRemoteErrors (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_DisplayRemoteErrors (ViSession instrumentHandle,
                                             ViBoolean displayRemoteErrors);
ViStatus _VI_FUNC rsemi_Preset (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_PresetMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rsemi_ConfigureCalibrationAutoAveraging
             (ViSession instrumentHandle, ViInt32 averaging);
ViStatus _VI_FUNC rsemi_SetTimeout (ViSession instrumentHandle,
                                    ViUInt32 OPCTimeout);
ViStatus _VI_FUNC rsemi_GetTimeout (ViSession instrumentHandle, ViPUInt32 timeout);
ViStatus _VI_FUNC rsemi_SetVISATimeout (ViSession instrumentHandle,
                                        ViUInt32 VISATimeout);
ViStatus _VI_FUNC rsemi_GetVISATimeout (ViSession instrumentHandle,
                                        ViPUInt32 VISATimeout);
ViStatus _VI_FUNC rsemi_ClearStatus (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_IDQueryResponse (ViSession instrumentHandle,
                                         ViChar _VI_FAR IDQueryResponse[]);
ViStatus _VI_FUNC rsemi_ProcessAllPreviousCommands (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_QueryOPC (ViSession instrumentHandle, ViPInt32 OPC);
ViStatus _VI_FUNC rsemi_SetFastSweepMode (ViSession instrumentHandle,
                                          ViInt32 fastSweepMode);
ViStatus _VI_FUNC rsemi_GetError (ViSession instrumentHandle, ViPStatus code,
                                  ViInt32 bufferSize, ViChar _VI_FAR description[]);
ViStatus _VI_FUNC rsemi_ClearError (ViSession instrumentHandle);
ViStatus _VI_FUNC rsemi_ReadToFileFromInstrument (ViSession instrumentHandle,
                                                  ViString source,
                                                  ViString destination);
ViStatus _VI_FUNC rsemi_WriteFromFileToInstrument (ViSession instrumentHandle,
                                                   ViString source,
                                                   ViString destination);
ViStatus _VI_FUNC rsemi_WriteInstrData (ViSession instrumentHandle,
                                        ViString writeBuffer);
ViStatus _VI_FUNC rsemi_ReadInstrData (ViSession instrumentHandle,
                                       ViInt32 numberOfBytesToRead,
                                       ViChar _VI_FAR readBuffer[],
                                       ViPUInt32 numBytesRead);
ViStatus _VI_FUNC rsemi_QueryViBoolean (ViSession instrumentHandle,
                                        ViString command, ViPBoolean value);
ViStatus _VI_FUNC rsemi_QueryViInt32 (ViSession instrumentHandle, ViString command,
                                      ViPInt32 value);
ViStatus _VI_FUNC rsemi_QueryViReal64 (ViSession instrumentHandle, ViString command,
                                       ViPReal64 value);
ViStatus _VI_FUNC rsemi_QueryViString (ViSession instrumentHandle, ViString command,
                                       ViInt32 bufferSize, ViChar _VI_FAR value[]);
ViStatus _VI_FUNC rsemi_close (ViSession instrumentHandle);

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSEMI_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSEMI_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSEMI_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSEMI_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSEMI_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)

#define RSEMI_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSEMI_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSEMI_ERRMSG_INCORRECT_STATE     "Instrument in incorrect state"
#define RSEMI_ERRMSG_INCORRECT_RESPONSE      "Response incorrect; report problem to R&S support!"
#define RSEMI_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"

#define RSEMI_ERROR_CODES_AND_MSGS \
    {RSEMI_WARN_MEASURE_UNCALIBRATED,  RSEMI_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSEMI_WARN_OVER_RANGE,            RSEMI_WARNMSG_OVER_RANGE},\
    {RSEMI_ERROR_INCORRECT_STATE ,   RSEMI_ERRMSG_INCORRECT_STATE },\
    {RSEMI_ERROR_INCORRECT_RESPONSE,     RSEMI_ERRMSG_INCORRECT_RESPONSE},\
    {RSEMI_ERROR_MAX_TIME_EXCEEDED,    RSEMI_ERRMSG_MAX_TIME_EXCEEDED}

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSEMI_HEADER */
